package JBMSTours;
import java.sql.*;
import JBMSTours.JCalendar;
import COM.cloudscape.util.JDBCDisplayUtil;



/**
 * Look at the <a href="../JBMSTours/AdminHelper.java">Source</a>.<p>
 * This class allows you to try out a number of different administrative-type
 * activities such as:
 * <ul>
 * <li>checking a database's consistency
 * <li>backing up a database
 * <li>turning on built-in users
 * <li>turning off built-in users
 * <li>making some major changes to data that call some triggers
 * <li>forcing a deadlock situation and using the lock diagnostics vtis
 * </ul>
 * When you run this class, you should give it an additional argument specifying the
 * action that you want:
 * <ul>
 * <li>check_consistency
 * <li>back_up
 * <li>built-in_users_on
 * <li>built-in_users_off
 * <li>rearrange_hotels
 * <li>force_deadlock (see specific instructions below in <a href="#forceDeadlock">forceDeadlock</a>)
 * </ul>
 * <p>This class has a main() method and can be run from the command-line.
 * For complete instructions on how to run such a class, see the <a href="../example.html#running">example instructions</a>.
 *
 */
public class AdminHelper {

    public ApplicationMode mymode;
	public static final String ARG1 = "check_consistency";
	public static final String ARG2 = "back_up";
	public static final String ARG3 = "built-in_users_on";
	public static final String ARG4 = "built-in_users_off";
	public static final String ARG5 = "rearrange_hotels";
	public static final String ARG6 = "force_deadlock";
	
	private static final int NUMBEROFARGS = 8;
	private static final String LEGALARGUMENTS = ARG1 + " | " + ARG2 + " | " + ARG3 + " | " + ARG4 +
	    " | " + ARG5 + " | " + ARG6;
	private static final String USAGESTRING = "Usage: java JBMSTours.AdminHelper [ hostname portnumber [r] ] " + LEGALARGUMENTS;

   


    /**
     * Entry point 
     *
     * @param args    legal arguments for this app (see USAGESTRING)
     */
    public static void main(String[] args) {

	/* testing for the client mode information (hostname and portnum)*/
	  int l = args.length;
	  String[] tempargs = args;
	  if (l > 1) {
		  tempargs = new String[l-1];
		  for (int i = 0; i < l-1; i++) {
			  tempargs[i] = args[i];
		  }
	  }
	  else {

		  tempargs = new String[0];
	  }
		  
	
      ApplicationMode runmode = new ApplicationMode(tempargs);
        (new AdminHelper()).go(runmode, args);
    }

    void go(ApplicationMode amode, String[] args) {
        System.out.println("AdminHelper starting");
        mymode = amode;
        try {
			int n = parseArguments(args);
            Connection conn = mymode.connectToCloudscape();
			if (n == 1)
				checkConsistencyOfAllTables(conn);
			if (n == 2) {
                backUpDatabase(conn);
			}

			if (n == 3) {
				turnOnBuiltInUsers(conn);
			}

			if (n == 4) {

				turnOffBuiltInUsers(conn);
			}
			if (n == 5) {

				changeSomeHotels(conn);
			}

			if (n == 6) {

				DeadlockForcer fd1 = new DeadlockForcer(1);
				DeadlockForcer fd2 = new DeadlockForcer(2);
				DeadlockForcer fd3 = new DeadlockForcer(3);

				Thread one = new Thread(fd1);
				Thread two = new Thread(fd2);
				Thread three = new Thread(fd3);
				three.setPriority(Thread.MIN_PRIORITY);
				one.start();
				two.start();
				three.start();
				while (one.isAlive()) {

					Thread.currentThread().sleep(500);
				}
				while (two.isAlive()) {

					Thread.currentThread().sleep(500);
				}
				while (three.isAlive()) {

					Thread.currentThread().sleep(500);
				}
				
				//forceDeadlock(conn, mymode, 1);
			} 

			conn.commit();
			conn.close();
			mymode.quitCloudscape();

        } catch (Throwable e) {
            System.out.println("exception thrown:");
            CreateToursDB.errorPrint(e);
        }
        System.out.println("AdminHelper finished");
    }


	private int parseArguments(String args[]) throws Exception {

		int length = args.length;
		if (length == 0) {
			System.out.println(USAGESTRING);
			throw new Exception("");
		}
		String arg = args[length-1];
		if (arg.equalsIgnoreCase(ARG1))
			return 1;
		if (arg.equalsIgnoreCase(ARG2))
			return 2;
		if (arg.equalsIgnoreCase(ARG3))
			return 3;
		if (arg.equalsIgnoreCase(ARG4))
			return 4;
		if (arg.equalsIgnoreCase(ARG5))
			return 5;
		if (arg.equalsIgnoreCase(ARG6))
			return 6;
		System.out.println(USAGESTRING);
		throw new Exception("Illegal arguments.");
			
	}


    /**
     * Runs the consistency checker.
     *
     * @param conn    a connection to the database.
	 *
	 * @exception SQLException if there is a database error.
     */

	public static void checkConsistencyOfAllTables(Connection conn) throws SQLException {
	
		//check consistency of all tables in the database
		Statement s = conn.createStatement();
		ResultSet rs = s.executeQuery("SELECT schemaname, tablename, " +
									  "ConsistencyChecker.checkTable(schemaname, tablename) " +
									  "FROM sys.sysschemas s, sys.systables t " +
									  "WHERE s.schemaid = t.schemaid");
		boolean consistent = true;
		boolean allconsistent = true;
		while (rs.next()) {
			consistent = rs.getBoolean(3);
			if (!consistent) {
				allconsistent = false;
				System.out.println(rs.getString(1) + "." + rs.getString(2) + " is not consistent.");
			}
		}
		rs.close();
		if (allconsistent)
			System.out.println("All tables are consistent.");
		s.close();
	}

    /**
     * Back up the database.
     *
     * @param conn    a connection to the database.
	 *
	 * @exception SQLException if there is a database error
     */
	public static void backUpDatabase(Connection conn) throws SQLException {

		String backupdirectory = "mybackup" + JCalendar.getToday();
		PreparedStatement ps = conn.prepareStatement("CALL Factory.getDatabaseOfConnection().backup(CAST (? AS java.lang.String))");
		ps.setString(1, backupdirectory);
		ps.executeUpdate();
		ps.close();
		System.out.println("backed up database to " + backupdirectory);
	}

    /**
     * Turn on built-in user authentication and work with user authorization.
     *
     * @param conn    a connection to the database.
	 *
	 * @exception SQLException if there is a database error
     */
	public static void turnOnBuiltInUsers(Connection conn) throws SQLException {
		System.out.println("Turning on authentication.");

		Statement s = conn.createStatement();
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.connection.requireAuthentication', 'true')");

		System.out.println("Confirming requireAuthentication:");
		ResultSet rs = s.executeQuery("VALUES PropertyInfo.getDatabaseProperty('cloudscape.connection.requireAuthentication')");
		rs.next();
		System.out.println(rs.getString(1));

		System.out.println("Setting authentication scheme to Cloudscape.");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.authentication.provider', 'CLOUDSCAPE')");

		System.out.println("Creating some sample users, including sa with a password of cloud3x9");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.user.sa', 'cloud3x9')");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.user.guest', 'java5w6x')");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.user.mary', 'little7xylamb')");

		System.out.println("Setting default connection mode to no access (user authorization).");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.database.defaultConnectionMode', 'noAccess')");
		System.out.println("Confirming default connection mode:");
		rs = s.executeQuery("VALUES PropertyInfo.getDatabaseProperty('cloudscape.database.defaultConnectionMode')");
		rs.next();
		System.out.println(rs.getString(1));
		System.out.println("Defining read-write users.");
		
		s.executeUpdate("CALL UserUtility.add('sa', UserUtility->FULL_ACCESS_PERMISSION)");
		s.executeUpdate("CALL UserUtility.add('mary', UserUtility->FULL_ACCESS_PERMISSION)");
		
		System.out.println("Defining read-only users.");
		s.executeUpdate("CALL UserUtility.add('guest', UserUtility->READ_ACCESS_PERMISSION)");

		System.out.println("Confirming full-access users:.");
		rs = s.executeQuery("VALUES PropertyInfo.getDatabaseProperty('cloudscape.database.fullAccessUsers')");
		rs.next();
		System.out.println(rs.getString(1));
		System.out.println("Confirming read-only users:");
		rs = s.executeQuery("VALUES PropertyInfo.getDatabaseProperty('cloudscape.database.readOnlyAccessUsers')");
		rs.next();
		System.out.println(rs.getString(1));
		
		//we would set the following property to TRUE only when we were ready to deploy.
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.database.propertiesOnly', 'false')");
		s.close();

	}

	/**
     * Turn off built-in user authentication and user authorization.
     *
     * @param conn    a connection to the database.
	 *
	 * @exception SQLException if there is a database error

     */
	public static void turnOffBuiltInUsers(Connection conn) throws SQLException {

		Statement s = conn.createStatement();
		System.out.println("Turning off authentication.");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.connection.requireAuthentication', 'false')");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.authentication.provider', null)");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.user.sa', null)");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.user.guest', null)");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.user.mary', null)");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.database.defaultConnectionMode', 'fullAccess')");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.database.fullAccessUsers', null)");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.database.readOnlyAccessUsers', null)");
		s.executeUpdate("CALL PropertyInfo.setDatabaseProperty("+
						"'cloudscape.database.propertiesOnly', 'false')");

		System.out.println("Confirming requireAuthentication:");
		ResultSet rs = s.executeQuery("VALUES PropertyInfo.getDatabaseProperty('cloudscape.connection.requireAuthentication')");
		rs.next();
		System.out.println(rs.getString(1));
		System.out.println("Confirming default connection mode:");
		rs = s.executeQuery("VALUES PropertyInfo.getDatabaseProperty('cloudscape.database.defaultConnectionMode')");
		rs.next();
		System.out.println(rs.getString(1));

		
		System.out.println("Turned off all the user-related properties.");
		s.close();
	}

    /**
     * Delete  some hotels and insert some new ones (will cause some complex triggers
	 * to fire).
     *
     * @param conn    a connection to the database.
	 *
	 * @exception SQLException if there is a database error
     */

	public static void changeSomeHotels(Connection conn) throws SQLException {

		Statement s = conn.createStatement();
		System.out.println("Adding some new hotels, and deleting some others. Any affected tours "+
						   "will automatically be re-booked by some triggers.");
		String insertString ="INSERT INTO hotels (hotel_id, hotel_name, city_id, tour_level, normal_rate, "+
			"high_season_rate, number_rooms_in_block, high_season_begin, high_season_end) "+
            "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
		PreparedStatement insertNewHotels = conn.prepareStatement(insertString);


		//first, add some new hotels
		

		insertNewHotels.setInt(1, 301);
		insertNewHotels.setString(2, "Hotel Van Dijk");
		insertNewHotels.setInt(3, 1);
		insertNewHotels.setShort(4, (short) 1);
		insertNewHotels.setObject(5, new java.math.BigDecimal(30).setScale(2));
		insertNewHotels.setObject(6, new java.math.BigDecimal(60).setScale(2));
		insertNewHotels.setInt(7, 12);
		insertNewHotels.setShort(8, (short) java.util.Calendar.MARCH);
		insertNewHotels.setShort(9, (short) java.util.Calendar.OCTOBER);
		insertNewHotels.executeUpdate(); 
		
		insertNewHotels.setInt(1, 302);
		insertNewHotels.setString(2, "Hotel Io");
		insertNewHotels.setInt(3, 1);
		insertNewHotels.setShort(4, (short) 2);
		insertNewHotels.setObject(5, new java.math.BigDecimal(55).setScale(2));
		insertNewHotels.setObject(6, new java.math.BigDecimal(90).setScale(2));
		insertNewHotels.setInt(7, 12);
		insertNewHotels.setShort(8, (short) java.util.Calendar.MARCH);
		insertNewHotels.setShort(9, (short) java.util.Calendar.OCTOBER);
		insertNewHotels.executeUpdate(); 
		
		insertNewHotels.setInt(1, 333);
		insertNewHotels.setString(2, "Bay View Hotel");
		insertNewHotels.setInt(3, 11);
		insertNewHotels.setShort(4, (short) 3);
		insertNewHotels.setObject(5, new java.math.BigDecimal(100).setScale(2));
		insertNewHotels.setObject(6, new java.math.BigDecimal(140).setScale(2));
		insertNewHotels.setInt(7, 12);
		insertNewHotels.setShort(8, (short) -1);
		insertNewHotels.setShort(9, (short) -1);
		insertNewHotels.executeUpdate(); 
		
		insertNewHotels.setInt(1, 415);
		insertNewHotels.setString(2, "Villa Botticelli");
		insertNewHotels.setInt(3, 39);
		insertNewHotels.setShort(4, (short) 1);
		insertNewHotels.setObject(5, new java.math.BigDecimal(30).setScale(2));
		insertNewHotels.setObject(6, new java.math.BigDecimal(55).setScale(2));
		insertNewHotels.setInt(7, 12);
		insertNewHotels.setShort(8, (short) java.util.Calendar.MARCH);
		insertNewHotels.setShort(9, (short) java.util.Calendar.OCTOBER);
		insertNewHotels.executeUpdate(); 
		
		insertNewHotels.setInt(1, 423);
		insertNewHotels.setString(2, "Hotel Bandeirantes");
		insertNewHotels.setInt(3, 41);
		insertNewHotels.setShort(4, (short) 3);
		insertNewHotels.setObject(5, new java.math.BigDecimal(130).setScale(2));
		insertNewHotels.setObject(6, new java.math.BigDecimal(150).setScale(2));
		insertNewHotels.setInt(7, 12);
		insertNewHotels.setShort(8, (short) java.util.Calendar.OCTOBER);
		insertNewHotels.setShort(9, (short) java.util.Calendar.FEBRUARY);
		insertNewHotels.executeUpdate();
		conn.commit();
		System.out.println("Added five new hotels.");
		//now delete some hotels
		System.out.println("Now deleting some hotels. Some triggers may fire.");
		s.executeUpdate("DELETE FROM Hotels WHERE hotel_id IN (VALUES 1, 2, 33, 115, 123)");
		conn.commit();
		System.out.println("Hotels successfully deleted. Affected tours have been rebooked.");
	}

    /**
     * Uses threads with separate connections to force a deadlock
	 * (which displays deadlock info) and query the lock diagnostics VTIs.<p>
	 * The first two threads should deadlock. One of them will be chosen as
	 * the victim and display the
	 * deadlock error message. The third thread will dump information from the
	 * lock diagnostics VTIs.
	 * 
     * @param conn    a connection to the database.
	 *
	 * @exception Throwable if there is a database error
     */

	public static void forceDeadlock(Connection conn, ApplicationMode am, int role) throws Throwable {
		if (role == 1) {
			Connection conn1 = am.connectToCloudscape();
			Statement s1 = conn1.createStatement();
  			/// if this code may encounter a deadlock, put the whole thing in a try/catch block
			// then try again if the deadlock victim exception was thrown
			try {
 				s1.executeUpdate("UPDATE HotelAvailability SET rooms_taken = rooms_taken + 1 WHERE hotel_id = 9");
				System.out.println("exclusive lock on some rows in hotelavailability table.");
				try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
				System.out.println("Now will try to lock rows in FlightAvailability.");
				s1.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = 0 WHERE flight_id = 'AA1116'");
			}
			catch (SQLException se) {
				if (se.getSQLState().equals("40001")) {
					System.out.println("force_deadlock_a was chosen as a victim. Here's the error message:");
					JBMSTours.CreateToursDB.SQLExceptionPrint(se);
					//but in a real application, we would not want to just give up; we would
					// try again at least once at this point.
					System.out.println("We'll try the transaction again.");
					s1.executeUpdate("UPDATE HotelAvailability SET rooms_taken = rooms_taken + 1 WHERE hotel_id = 9");
					System.out.println("exclusive lock on some rows in hotelavailability table.");
					try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
					System.out.println("Now will try to lock rows in FlightAvailability.");
					s1.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = 0 WHERE flight_id = 'AA1116'");
					
					
				}
				else
					throw se;
				
				
			}
			//we don't really want to make this change, though, because we want to be able to run
			// the program again.
			conn1.rollback();
			s1.close();
			conn1.close();
		}
		
		if (role == 2) {
			Connection conn2 = am.connectToCloudscape();
			Statement s = conn2.createStatement();
  			/// if this code may encounter a deadlock, put the whole thing in a try/catch block
			// then try again if the deadlock victim exception was thrown
			try {
				s.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = economy_seats_taken " +
								"+ 1 WHERE flight_id = 'AA1116'");
				System.out.println("exclusive lock on some rows in flightavailability table.");
				try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
				System.out.println("Now will try to lock rows in HotelAvailability.");
				s.executeUpdate("UPDATE HotelAvailability SET rooms_taken = 0 WHERE hotel_id = 9");
			}
			catch (SQLException se) {
				if (se.getSQLState().equals("40001")) {
					System.out.println("force_deadlock_b was chosen as a victim. Here's the error message:");
					JBMSTours.CreateToursDB.SQLExceptionPrint(se);
					//but in a real application, we would not want to just give up; we would
					// try again at least once at this point.
					System.out.println("We'll try the transaction again.");
					s.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = economy_seats_taken " +
									"+ 1 WHERE flight_id = 'AA1116'");
					System.out.println("exclusive lock on some rows in flightavailability table.");
					try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
					System.out.println("Now will try to lock rows in HotelAvailability.");
					s.executeUpdate("UPDATE HotelAvailability SET rooms_taken = 0 WHERE hotel_id = 9");
					
				}
				else
					throw se;
			}
			//we don't really want to make this change, though, because we want to be able to run
			// the program again.
			conn2.rollback();
			s.close();
			conn2.close();
			
		}
		
		if (role == 3) {
			Connection conn4 = am.connectToCloudscape();
			Statement s = conn.createStatement();
			try {Thread.sleep(13000L); } catch (InterruptedException e ) {}
			s.executeQuery("SELECT Locks.xid, Locks.Type, TableName, Mode, Lockname, State " +
						   "FROM LOCKS, NEW TransactionTable() AS Trans WHERE Locks.xid = Trans.xid " +
						   "AND TABLENAME IN (VALUES 'HOTELAVAILABILITY', 'FLIGHTAVAILABILITY')");
			System.out.println("Current locks on HotelAvailability and FlightAvailability:");
			JDBCDisplayUtil.DisplayResults(System.out, s, conn4);
			s.executeQuery("SELECT XID, SQL_TEXT FROM NEW TransactionTable() AS Trans WHERE XID IN " +
						   "(SELECT XID FROM Locks WHERE state = 'WAIT')");
			JDBCDisplayUtil.DisplayResults(System.out, s, conn4);
			conn4.commit();
			s.close();
			conn4.close();
		}
		
	}

	public class DeadlockForcer implements Runnable {

		int role;
		ApplicationMode am;
		public DeadlockForcer(int role) {
			this.role = role;
			am = mymode;
			System.out.println(role);
		}
		public void run() {
			try {
				if (role == 1) {
					Connection conn1 = am.connectToCloudscape();
					Statement s1 = conn1.createStatement();
					/// if this code may encounter a deadlock, put the whole thing in a try/catch block
					// then try again if the deadlock victim exception was thrown
					try {
						s1.executeUpdate("UPDATE HotelAvailability SET rooms_taken = rooms_taken + 1 WHERE hotel_id = 9");
						System.out.println("Thread one has an exclusive lock on some rows in hotelavailability table.");
						try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
						System.out.println("Now it will try to lock rows in FlightAvailability.");
						s1.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = 0 WHERE flight_id = 'AA1116'");
					}
					catch (SQLException se) {
						if (se.getSQLState().equals("40001")) {
							System.out.println("Thread one was chosen as a victim. Here's the error message:");
							printSQLMessage(se);
							//but in a real application, we would not want to just give up; we would
							// try again at least once at this point.
							System.out.println("Thread one will try the transaction again.");
							s1.executeUpdate("UPDATE HotelAvailability SET rooms_taken = rooms_taken + 1 WHERE hotel_id = 9");
							System.out.println("Thread one has exclusive lock on some rows in hotelavailability table.");
							try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
							System.out.println("Thread one will try to lock rows in FlightAvailability.");
							s1.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = 0 WHERE flight_id = 'AA1116'");
							
							
						}
						else
							throw se;
						
						
					}
					//we don't really want to make this change, though, because we want to be able to run
					// the program again.
					conn1.rollback();
					s1.close();
					conn1.close();
				}
				
				if (role == 2) {
					Connection conn2 = am.connectToCloudscape();
					Statement s = conn2.createStatement();
					/// if this code may encounter a deadlock, put the whole thing in a try/catch block
					// then try again if the deadlock victim exception was thrown
					try {
						s.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = economy_seats_taken " +
										"+ 1 WHERE flight_id = 'AA1116'");
						System.out.println("Thread two has exclusive lock on some rows in flightavailability table.");
						try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
						System.out.println("Thread two will try to lock rows in HotelAvailability.");
						s.executeUpdate("UPDATE HotelAvailability SET rooms_taken = 0 WHERE hotel_id = 9");
					}
					catch (SQLException se) {
						if (se.getSQLState().equals("40001")) {
							System.out.println("Thread two was chosen as a victim. Here's the error message:");
							printSQLMessage(se);
							//but in a real application, we would not want to just give up; we would
							// try again at least once at this point.
							System.out.println("Thread two will try the transaction again.");
							s.executeUpdate("UPDATE FlightAvailability SET economy_seats_taken = economy_seats_taken " +
											"+ 1 WHERE flight_id = 'AA1116'");
							System.out.println("Thread two has exclusive lock on some rows in flightavailability table.");
							try {Thread.sleep(9000L); } catch (InterruptedException e ) {}
							System.out.println("Thread two will try to lock rows in HotelAvailability.");
							s.executeUpdate("UPDATE HotelAvailability SET rooms_taken = 0 WHERE hotel_id = 9");
							
						}
						else
							throw se;
					}
					//we don't really want to make this change, though, because we want to be able to run
					// the program again.
					conn2.rollback();
					s.close();
					conn2.close();
				
				}
				
				if (role == 3) {
					Connection conn4 = am.connectToCloudscape();
					Statement s = conn4.createStatement();
					try {Thread.sleep(13000L); } catch (InterruptedException e ) {}
					System.out.println("Thread three scanning Locks table");
					s.executeQuery("SELECT Locks.xid, Locks.Type, TableName, Mode, Lockname, State " +
								   "FROM LOCKS, NEW TransactionTable() AS Trans WHERE Locks.xid = Trans.xid " +
								   "AND TABLENAME IN (VALUES 'HOTELAVAILABILITY', 'FLIGHTAVAILABILITY')");
					System.out.println("Current locks on HotelAvailability and FlightAvailability:");
					JDBCDisplayUtil.DisplayResults(System.out, s, conn4);
					s.executeQuery("SELECT XID, SQL_TEXT FROM NEW TransactionTable() AS Trans WHERE XID IN " +
								   "(SELECT XID FROM Locks WHERE state = 'WAIT')");
					JDBCDisplayUtil.DisplayResults(System.out, s, conn4);
					conn4.commit();
					s.close();
					conn4.close();
				}
				
				
				
			}
			catch (Throwable t) {
				JBMSTours.CreateToursDB.errorPrint(t);
				
			}
		}

		private void printSQLMessage(SQLException se) {
			System.out.println("SQLState:   " + se.getSQLState());
			System.out.println("Error Code: " + se.getErrorCode());
			System.out.println("Message:  " + se.getMessage());
			

		}
	}
	
	
}
	
