package JBMSTours;
import java.sql.*;


/**
 * Look at the <a href="../JBMSTours/ArchiveData.java">Source</a>.<p>
 * This class archives data out of the HotelBookings table into a mirror
 * table in the <i>History</i> database and deletes
 * old data from the FlightAvailability table. It 
 * provides an example of:
 * <ul>
 * <li>executing database-side methods
 * <li>using read-write VTIs to write data to an external database; one of the
 * database-side methods called by this program uses the read-write VTIs. For more information,
 * see the source for JBMSTours.serializabletypes.HotelStay.
 * </ul>
 *
 * <p>This class has a main() method and can be run from the command-line.
 * For complete instructions on how to run it, see the <a href="../example.html#running">example instructions</a>.
 *
 */


public class ArchiveData {

    public ApplicationMode mymode;


    /**
     * Entry point into archiving data. 
     *
     * @param args    ignored
     */
    public static void main(String[] args) {
		
		// testing for the client mode information (hostname and portnum)
		ApplicationMode runmode = new ApplicationMode(args);
        (new ArchiveData()).go(runmode);
    }
	
    void go(ApplicationMode amode) {
        System.out.println("ArchiveData starting");
        mymode = amode;
        try {
			
            Connection conn = mymode.connectToCloudscape();

			//Creating a statement lets us issue commands against the connection.
            Statement s = conn.createStatement();
            PreparedStatement ps;
            JCalendar aDate;
            aDate = new JCalendar(); //an array of dates
			
			s.execute("CALL HotelStay.makeHistoryDatabase()");
			System.out.println("Created the History database.");

			// archive some of the records the first way--with a method that uses JDBC
			// connections to two databases to transfer data from one to the other.
			// You could call the method directly in the application; you don't have to
			// execute it as a database-side method, the way we have here.

			// archive all records that start on or before the twelfth day in our
			// array of dates. (Ideally, you wouldn't want to archive
			// any records unless the dates were already past. )
            String archiveRecords = "CALL HotelStay."+
				"archiveRecords(CAST (? as DATE))";
            ps = conn.prepareStatement(archiveRecords);
            ps.setDate(1, aDate.getDay(12));
            ps.executeUpdate();
            ps.close();
			System.out.println("Called the first archiveRecords method.");

			
            // archive some records with a database-side method.
			// The method called (JBMSTours.serializabletypes.HotelStay.archiveRecordsREadWriteVTI)
			// uses a read-write VTI class to write records before the
			// 20th day in our array of dates to an
			// external Cloudscape database, History. See HotelStay.
            archiveRecords = "CALL HotelStay."+
				"archiveRecordsReadWriteVTI(getCurrentConnection(), ?)";
            ps=conn.prepareStatement(archiveRecords);
			ps.setDate(1, aDate.getDay(20));
			ps.executeUpdate();
            System.out.println("Called the archiveRecordsReadWriteVTI method.");
			ps.close();
			
            // Get rid of some old data using a method alias.
            // The method cleanOutFlightAvailability in FlightBuilder has 
            // a method alias defined for it, so we can just call the
            // method alias.
			
            String cleanFlightA = "CALL CLEANOUTFLIGHTAVAILABILITY(getCurrentConnection())";
            s.execute(cleanFlightA);
            System.out.println("Cleaned out old entries from the FlightAvailability table.");
            s.close();
			conn.commit();
			conn.close();
            mymode.quitCloudscape();
			
			
        } catch (Throwable e) {
            System.out.println("exception thrown:");
            CreateToursDB.errorPrint(e);
        }
        System.out.println("ArchiveData finished");
    }
	
}



