
package JBMSTours;
import java.sql.*;
import java.util.Hashtable;


/**
 * Look at the <a href="../JBMSTours/CreateSchema.java">Source</a>.
 * Creates the schema for the database.
 * 
 * @see CreateToursDB
 */  

public class CreateSchema {

	private Statement s;
	private Hashtable classAliases;
	private Hashtable classAliasComments;
	private Hashtable tables;
	private Hashtable tableComments;
	private Hashtable indexes;
	private Hashtable indexComments;
	private Hashtable views;
	private Hashtable viewComments;
	private Hashtable otherAliases;
	private Hashtable otherAliasComments;
	private Hashtable storedPreparedStatements;
	private Hashtable spsComments;
	private Hashtable triggers;
	private Hashtable triggerComments;
	private Hashtable logic;
	private Hashtable logicComments;
	public static int CLASSALIASCOUNT = 18;
	public static int TABLECOUNT = 15;
	public static int INDEXCOUNT = 6;
	public static int VIEWCOUNT = 2;
	public static int OTHERALIASCOUNT = 6;
    public static int SPSSTATEMENTCOUNT = 13;
    public static int TRIGGERCOUNT = 4;
	public static int LOGICCOUNT = 1;
	
	private boolean insertableAsSQL=true; 
	
	public CreateSchema() {

		classAliases = new Hashtable();
		classAliasComments = new Hashtable();
		tables = new Hashtable();
		tableComments = new Hashtable();
		indexes = new Hashtable();
		indexComments = new Hashtable();
		views = new Hashtable();
		viewComments = new Hashtable();
		otherAliases = new Hashtable();
		otherAliasComments = new Hashtable();
		storedPreparedStatements = new Hashtable();
		spsComments = new Hashtable();
		triggers = new Hashtable();
		triggerComments = new Hashtable();
		logic = new Hashtable();
		logicComments = new Hashtable();


		tables.put(new Integer(1), 
				   "CREATE TABLE Countries ("+
				   "country varchar(26) CONSTRAINT COUNTRIES_UNIQUE_NAMES UNIQUE, " +
				   "country_ISO_code char(2) CONSTRAINT COUNTRIES_PK PRIMARY KEY, "+
				   "region varchar(26) CONSTRAINT Countries_UC " +
				   "CHECK (country_ISO_code.equals(country_ISO_code.toUpperCase())))");
		
		tableComments.put(new Integer(1), "Created table Countries");
		
		tables.put(new Integer(2), "CREATE TABLE Cities ("+
				   "city_id int CONSTRAINT CITIES_PK PRIMARY KEY, " +
				   "city SERIALIZE(City), " +
				   "country_ISO_code CHAR(2) CONSTRAINT countries_fk REFERENCES Countries)" +
				   "PROPERTIES cloudscape.storage.pageSize=8192, " +
				   "cloudscape.storage.pageReservedSpace=10 " +
				   "SET LOCKING = TABLE");
		
		tableComments.put(new Integer(2), "Created table Cities");
		
		tables.put(new Integer(3), "CREATE TABLE hotels ("+
				   "hotel_id int CONSTRAINT hotels_PK PRIMARY KEY,  "+
				   "hotel_name VARCHAR(40) NOT NULL, " + 
				   "city_id int NOT NULL CONSTRAINT cities_fk REFERENCES Cities, " +
				   "tour_level SMALLINT CONSTRAINT level_check CHECK (tour_level IN " +
				   "  (Tour->ECONOMYTOURLEVEL, Tour->STANDARDTOURLEVEL, " +
				   "   Tour->FIRSTCLASSTOURLEVEL)), " + 
				   "normal_rate DECIMAL(6,2) NOT NULL, " + 
				   "high_season_rate DECIMAL(6,2) NOT NULL, " + 
				   "number_rooms_in_block INT NOT NULL, " + 
				   "high_season_begin SMALLINT DEFAULT Hotel->NOHIGHSEASON " +
				   "   CONSTRAINT begin_check CHECK " +
				   "   (high_season_begin BETWEEN Hotel->NOHIGHSEASON AND " +
				   "   Calendar->DECEMBER), " + 
				   "high_season_end SMALLINT DEFAULT Hotel->NOHIGHSEASON "+
				   "   CONSTRAINT end_check CHECK " +
				   "   (high_season_end BETWEEN Hotel->NOHIGHSEASON AND " +
				   "   Calendar->DECEMBER))");
		
		tableComments.put(new Integer(3), "Created table Hotels");
		
		tables.put(new Integer(4), "CREATE TABLE HotelAvailability ("+
				   "hotel_id INT CONSTRAINT hotels_fk REFERENCES Hotels, "+
				   "booking_date DATE,  "+
				   "rooms_taken INT DEFAULT 0," +
				   "CONSTRAINT HOTELAVAILABILITY_PK PRIMARY KEY (hotel_id, booking_date))");
		
		tableComments.put(new Integer(4), "Created table HotelAvailability");
		
		tables.put(new Integer(5), "CREATE TABLE People ("+
				   "person_id INT DEFAULT AUTOINCREMENT CONSTRAINT PEOPLE_PK PRIMARY KEY,  "+
				   "person SERIALIZE(Person) CONSTRAINT has_parent CHECK (person.parentInTable(getCurrentConnection())))");
		
		tableComments.put(new Integer(5), "Created table People");
		
		
		tables.put(new Integer(6), "CREATE TABLE Groups(" +
				   "group_id INT DEFAULT AUTOINCREMENT CONSTRAINT Groups_PK PRIMARY KEY, " +
				   "number_kids INT, " +
				   "number_adults INT, " +
				   "number_people INT CONSTRAINT people_check CHECK(number_people=number_kids+number_adults), " +
				   "main_person INT, " +
				   "number_rooms INT, " +
				   "city_id INT, " +
				   "address VARCHAR(100), " +
				   "phone VARCHAR(15), " +
				   "tour_level SMALLINT CONSTRAINT level_check2 CHECK (tour_level IN " +
				   "(Tour->ECONOMYTOURLEVEL, Tour->STANDARDTOURLEVEL, " +
				   "Tour->FIRSTCLASSTOURLEVEL)), " +
				   "budget DECIMAL(11,2), " +
				   "running_total DECIMAL(11,2) CONSTRAINT spending_check CHECK (running_total <= budget))");
		
		tableComments.put(new Integer(6), "Created table Groups");
	    
		tables.put(new Integer(7), "CREATE TABLE HotelBookings ("+
				   "hotel_id INT CONSTRAINT hotel_foreign_key2 REFERENCES Hotels,  "+
				   "group_id INT CONSTRAINT groups_foreign_key REFERENCES Groups,  "+
				   "arrival DATE,  "+
				   "departure DATE,  "+
				   "number_rooms INT, "+ 
				   "total_cost DECIMAL(10,2), " +
				   "CONSTRAINT HOTELBOOKINGS_PK PRIMARY KEY (hotel_id, group_id, arrival))");
		
		tableComments.put(new Integer(7), "Created table HotelBookings");
		
		tables.put(new Integer(8), "CREATE TABLE Groups_People (group_id int,  "+
				   "person_id int,  "+
				   "CONSTRAINT GROUPS_PEOPLE_PK PRIMARY KEY (group_id, person_id))");
		
		tableComments.put(new Integer(8), "Created table Groups_People");
		
		tables.put(new Integer(9), "CREATE TABLE Flights (flight_id char(6),  "+
				   "segment_number INT,  "+
				   "orig_airport CHAR(3), "+ 
				   "depart_time TIME,  "+
				   "dest_airport CHAR(3), "+ 
				   "arrive_time TIME, "+ 
				   "meal char(1) CONSTRAINT MEAL_CONSTRAINT CHECK (meal IN ('B', 'L', 'D', 'S')),  "+
				   "flying_time DOUBLE PRECISION, "+ 
				   "miles INT,  "+
				   "aircraft VARCHAR(6),  "+
				   "CONSTRAINT FLIGHTS_PK PRIMARY KEY (flight_id, segment_number))");
		
		tableComments.put(new Integer(9), "Created table Flights");
		
		tables.put(new Integer(10), "CREATE TABLE FlightAvailability (flight_id CHAR(6),  "+
				   "segment_number int,  "+
				   "flight_date DATE,  "+
				   "economy_seats_taken INT DEFAULT 0,  "+
				   "business_seats_taken INT DEFAULT 0,  "+
				   "firstclass_seats_taken INT DEFAULT 0, "+ 
				   "CONSTRAINT FLIGHTAVAILABILITY_PK PRIMARY KEY (flight_id, segment_number, flight_date), "+
				   "CONSTRAINT flights_foreign_key2 FOREIGN KEY(flight_id, segment_number) REFERENCES Flights)");
		
		tableComments.put(new Integer(10), "Created table FlightAvailability");
		
		tables.put(new Integer(11), "CREATE TABLE FlightBookings (flight_id CHAR(6), "+
				   "segment_number INT, " + 
				   "group_id INT CONSTRAINT groups_foreign_key2 REFERENCES Groups,  "+
				   "travel_date DATE,  "+
				   "segment_two_flight_id CHAR(6),  "+
				   "segment_two_segment_number INT,  "+
				   "number_seats INT,  "+
				   "fixed_rate DECIMAL(10,2), "+ 
				   "travel_level VARCHAR(15), "+ 
				   "CONSTRAINT FLIGHTBOOKINGS_PK PRIMARY KEY (flight_id, segment_number, group_id, travel_date)" +
				   ", CONSTRAINT flights_foreign_key FOREIGN KEY (flight_id, segment_number) REFERENCES Flights" +
				   ")");
		
		tableComments.put(new Integer(11), "Created table FlightBookings");
		
		tables.put(new Integer(12), "CREATE TABLE Airlines("+
				   "airline CHAR(2) CONSTRAINT AIRLINES_PK PRIMARY KEY,  "+
				   "airline_full VARCHAR(24), " +
				   "basic_rate DOUBLE PRECISION,  "+
				   "distance_discount double PRECISION,  "+
				   "business_level_factor DOUBLE PRECISION,  "+
				   "firstclass_level_factor DOUBLE PRECISION, "+ 
				   "economy_seats INT,  "+
				   "business_seats INT,  "+
				   "firstclass_seats INT)");
		
		tableComments.put(new Integer(12), "Created table Airlines");
		
		//improved to work in a multi-user situation.
		tables.put(new Integer(13), "CREATE TABLE FlightObjects (" +
				   "flight_id VARCHAR(21), " +
				   "flight_object SERIALIZE (Flight), " +
				   "group_id INT, " + 
				   "CONSTRAINT FlightObjects_pk PRIMARY KEY(flight_id, group_id),  " +
				   "CONSTRAINT groups_foreign_key4 FOREIGN KEY (group_id) REFERENCES Groups)");
		
		//we can set a special page size for this table only so that
		//we can store large images on it
		
		tableComments.put(new Integer(13), "Created table FlightObjects");
		
		tables.put(new Integer(14), "CREATE TABLE CustomizedTours("+
				   "group_id INT CONSTRAINT CUSTOMIZEDTOURS_PK PRIMARY KEY, "+
				   "customized_tour SERIALIZE(Tour) NOT NULL, " +
				   "getTotalCost DECIMAL(7,2)" +
				   ", CONSTRAINT groups_foreign_key3 FOREIGN KEY (group_id) REFERENCES Groups) " + 
				   "PROPERTIES cloudscape.storage.pageSize=8192, " +
				   "cloudscape.storage.pageReservedSpace=0");
		
		tableComments.put(new Integer(14), "Created table CustomizedTours");
		
		tables.put(new Integer(15), "CREATE TABLE maps (country_ISO_code CHAR(2) " +
				   "CONSTRAINT country_foreign_key2 REFERENCES Countries ,  " +
				   "mapIsBig boolean, " +
				   "map SERIALIZE(Picture)," +
				   "thumbnail BIT VARYING(52800),"	+	
				   "CONSTRAINT maps_pk PRIMARY KEY (country_ISO_code, mapIsBig)) " +
				   "PROPERTIES cloudscape.storage.pageSize=65536, " +
				   "cloudscape.storage.pageReservedSpace=0");
		
		tableComments.put(new Integer(15), "Created table Maps");
		
		indexes.put(new Integer(1), "CREATE BTREE INDEX OrigIndex ON Flights(orig_airport)");
		
		indexComments.put(new Integer(1), "Created index OrigIndex");
		
		indexes.put(new Integer(2), "CREATE BTREE INDEX DestIndex ON Flights(dest_airport)");
		
		indexComments.put(new Integer(2), "Created index DestIndex");
		
		indexes.put(new Integer(3), "CREATE UNIQUE BTREE INDEX Hotels_Uniqueness on Hotels (city_id, tour_level, hotel_name)");
		
		indexComments.put(new Integer(3), "Created index Hotels_Uniqueness");
		
		
		indexes.put(new Integer(4), "CREATE BTREE INDEX HotelDates ON HotelAvailability (booking_date)");
		
		indexComments.put(new Integer(4), "Created index HotelDates");
		
		indexes.put(new Integer(5), "CREATE BTREE INDEX HotelDates2 ON HotelBookings (arrival)");
		
		indexComments.put(new Integer(5), "Created index HotelDates2");
		
		indexes.put(new Integer(6), "CREATE BTREE INDEX TourCosts ON CustomizedTours (getTotalCost)");
		
		indexComments.put(new Integer(6), "Created index on CustomizedTours");
		
		views.put(new Integer(1), "CREATE VIEW Segments_SeatBookings " +
				  "(flight_id, segment_number, number_seats, travel_date) " +
				  "AS SELECT flight_id, segment_number, number_seats, travel_date " +
				  "FROM FlightBookings "+
				  "UNION ALL "+
				  "SELECT segment_two_flight_id AS flight_id, "+
				  "segment_two_segment_number AS segment_number, "+
				  "number_seats, travel_date "+
				  "FROM FlightBookings "+
				  "WHERE segment_two_flight_id IS NOT NULL");
		
		viewComments.put(new Integer(1), "Created view Segments_SeatBookings");
		
		views.put(new Integer(2), "CREATE VIEW Locks AS SELECT * FROM NEW LockTable() AS locks");
		
		viewComments.put(new Integer(2), "Created view Locks");
		
		otherAliases.put(new Integer(1), "CREATE METHOD ALIAS findCity FOR " +
						 "City.findCity");
		
		otherAliasComments.put(new Integer(1), "Created method alias findCity");
		
		otherAliases.put(new Integer(2), "CREATE METHOD ALIAS cleanOutFlightAvailability FOR " +
						 "JBMSTours.FlightBuilder.cleanOutFlightAvailability");
		
		otherAliasComments.put(new Integer(2), "Created method alias cleanOutFlightAvailability");
		
		otherAliases.put(new Integer(3), "CREATE METHOD ALIAS CURRENT_JDATE FOR " +
						 "JCalendar.getToday");
		
		otherAliasComments.put(new Integer(3), "Created method alias CURRENT_JDATE");
		
		otherAliases.put(new Integer(4), "CREATE METHOD ALIAS DATE_DIF FOR " +
						 "JCalendar.getDateDifference");
		
		otherAliasComments.put(new Integer(4), "Created method alias DATE_DIF");
		
		otherAliases.put(new Integer(5), "CREATE METHOD ALIAS TIME_DIF FOR " +
						 "JCalendar.getTheTimeDifference");
		
		otherAliasComments.put(new Integer(5), "Created method alias TIME_DIF");
		
		otherAliases.put(new Integer(6), "CREATE AGGREGATE MaxButONE FOR JBMSTours.aggregates.MaxButOneDef");
		otherAliasComments.put(new Integer(6), "Created aggregate MaxButONE");
		
		
		
		
		
		
		/* creates a statement that gets direct flights--non stop and one-stop flights--
           between two cities. This query uses a join on two subquery 
           results instead of an IN list with a subquery so
           that it is optimizable*/
		
		storedPreparedStatements.put(new Integer(1), "CREATE STATEMENT getDirectFlights AS " + 
									 "SELECT orig_flights.flight_id " + 
									 "FROM (select flight_id from flights " + 
									 "WHERE orig_airport = ?) orig_flights, " + 
									 "(select flight_id from flights WHERE dest_airport = ?) " + 
									 "dest_flights WHERE orig_flights.flight_id = dest_flights.flight_id " +
									 "USING VALUES ('SFO', 'SCL') ");
		
		spsComments.put(new Integer(1), "Created statement getDirectFlights");
		
		//creates a statement that gets information about all the segments in a flight
		storedPreparedStatements.put(new Integer(2), "CREATE STATEMENT getFlightInfo AS " + 
									 "SELECT flight_id, segment_number, orig_airport, " + 
									 "depart_time, dest_airport, arrive_time, " + 
									 "flying_time, miles " + "FROM Flights WHERE flight_id = ? " +
									 "USING VALUES ('AA1111')");
		
		spsComments.put(new Integer(2), "Created statement getFlightInfo");
		
		//creates a statement that inserts a Flight object into the FlightObject table
		storedPreparedStatements.put(new Integer(3), "CREATE STATEMENT insertFlightObject AS " + 
									 "INSERT INTO FlightObjects VALUES (?, ?, ?)");
		
		spsComments.put(new Integer(3), "Created statement insertFlightObject");
		
		// allow positive or negative difference between flight times
		String betweenClause = "BETWEEN -" + FlightBuilder.LAYOVER_TOLERANCE + " AND " + 
			FlightBuilder.LAYOVER_TOLERANCE;
		
		spsComments.put(new Integer(4), "Created statement insertFlightObject");
		//a complex statement that uses the SQL92 "derived table" feature to help
		//construct a two-part transfer flight. 
		
		storedPreparedStatements.put(new Integer(4), "CREATE STATEMENT getFullTransferFlightInOneBlow AS " + 
									 "SELECT firstleg.flight_id, firstleg.segment_number, " + 
									 "secondleg.flight_id, secondleg.segment_number " + 
									 "FROM (SELECT flight_id, segment_number, arrive_time, dest_airport " + 
									 "FROM Flights WHERE orig_airport = ?) firstleg, " + 
									 "(SELECT flight_id, segment_number, orig_airport, depart_time " + 
									 "FROM Flights WHERE dest_airport = ?) secondleg " + 
									 "WHERE firstleg.dest_airport = secondleg.orig_airport AND " + 
									 "firstleg.flight_id <> secondleg.flight_id AND " + 
									 "secondleg.depart_time.getHours() - firstleg.arrive_time.getHours() " + 
									 betweenClause +
									 " USING VALUES ('SFO', 'SCL')");
		
		spsComments.put(new Integer(4), "Created statement getFullTransferFlightInOneBlow");
		
		// a statement that gets full information about a particular flight segment.
		storedPreparedStatements.put(new Integer(5), "CREATE STATEMENT getFullFlightInfo AS " + 
									 "SELECT flight_id, segment_number, orig_airport, " + 
									 "depart_time, dest_airport, arrive_time, " + "flying_time, miles " + 
									 "FROM Flights " + "WHERE flight_id = ? AND segment_number = ? " +
									 "USING VALUES ('AA1111', 1)");
		
		spsComments.put(new Integer(5), "Created statement getFullFlightInfo");
		
		storedPreparedStatements.put(new Integer(6), "CREATE STATEMENT findAvailableHotel AS " +
									 "SELECT * FROM hotels "+
									 "WHERE city_id = ?  AND tour_level = ?  " +
									 "AND hotel_id NOT IN  " +
									 "    (SELECT hotel_id FROM HotelAvailability  " +
									 "    WHERE (hotels.number_rooms_in_block - rooms_taken) < ? " + 
									 "    AND booking_date >= ? AND booking_date < ? ) " +
									 "USING VALUES (50, 1, 10, DATE'1999-01-01', DATE'1999-01-01')");
	
		spsComments.put(new Integer(6), "Created statement findAvailableHotel");
		
		
		//used by the CustomerFlight class to find a flight
		storedPreparedStatements.put(new Integer(7), "CREATE STATEMENT proposeAFlight AS " +
									 "SELECT flight_object, "+ 
									 "    flight_object.getTotalDuration() AS Duration "+ 
									 "FROM FlightObjects "+
									 "WHERE group_id = ? AND flight_object->orig_airport = ? "+
									 
									 "AND flight_object->dest_airport = ? "+ 
									 "ORDER BY Duration "+
									 "USING VALUES (2, 'SFO', 'JFK')");
		spsComments.put(new Integer(7), "Created statement proposeAFlight");
		
		storedPreparedStatements.put(new Integer(8), "CREATE STATEMENT flightAvailabilityCursorEconomy AS "+
									 "SELECT economy_seats_taken, flight_id, segment_number FROM Flightavailability "+
									 "WHERE ((flight_id = ? AND segment_number = ? )   "+
									 "OR (flight_id = ? AND segment_number = ? ))   "+
									 "AND flight_date = ? "+
									 "FOR UPDATE OF economy_seats_taken "+
									 "USING VALUES ('AA1700', 1, CURRENT_DATE)");
		spsComments.put(new Integer(8), "Created statement flightAvailabilityCursorEconomy");
		
		storedPreparedStatements.put(new Integer(9), "CREATE STATEMENT flightAvailabilityCursorBusiness AS  "+
									 "SELECT business_seats_taken, flight_id, segment_number FROM Flightavailability "+
									 "WHERE ((flight_id = ? AND segment_number = ? )   "+
									 "OR (flight_id = ? AND segment_number = ? ))   "+
									 "AND flight_date = ? "+
									 "FOR UPDATE OF business_seats_taken "+
									 "USING VALUES ('AA1700', 1, CURRENT_DATE)");
		spsComments.put(new Integer(9), "Created statement flightAvailabilityCursorBusiness");
		
		storedPreparedStatements.put(new Integer(10), "CREATE STATEMENT flightAvailabilityCursorFirstClass AS  "+
									 "SELECT firstclass_seats_taken, flight_id, segment_number FROM Flightavailability "+
									 "WHERE ((flight_id = ? AND segment_number = ? )   "+
									 "OR (flight_id = ? AND segment_number = ? ))   "+
									 "AND flight_date = ? "+
									 "FOR UPDATE OF firstclass_seats_taken "+
									 "USING VALUES ('AA1700', 1, CURRENT_DATE)");
		spsComments.put(new Integer(10), "Created statement flightAvailabilityCursorFirstClass");
		
		
		storedPreparedStatements.put(new Integer(11), "CREATE STATEMENT getCityById AS " +
									 "SELECT city " +
									 "FROM Cities " +
									 "WHERE city_id = ? " +
									 "USING VALUES (50)");
		spsComments.put(new Integer(11), "Created statement getCityById");
		
		//used by the HotelStay class to find available hotels
		storedPreparedStatements.put(new Integer(12), "CREATE STATEMENT findAnotherAvailableHotel AS " +
									 "SELECT * FROM hotels "+
									 "WHERE city_id = ?  AND tour_level = ?  " +
									 "AND hotel_id <> ? " +
									 "AND hotel_id NOT IN  " +
									 "(SELECT hotel_id FROM HotelAvailability  " +
									 "WHERE (hotels.number_rooms_in_block - rooms_taken) < ? " + 
									 "AND booking_date >= ? AND booking_date < ? ) " +
									 "USING VALUES (50, 1, 10, DATE'1999-01-01', DATE'1999-01-01')");
		
		spsComments.put(new Integer(12), "Created statement findAnotherAvailableHotel");
		
		//used by HotelsCascadingDelete2 Trigger
		storedPreparedStatements.put(new Integer(13), "CREATE STATEMENT badBookingsCursor AS " +
									 "SELECT * FROM HotelBookings "+
									 "WHERE hotel_id = ? FOR UPDATE "+
									 "USING VALUES 100");
		
		spsComments.put(new Integer(13), "Created statement badBookingsCursor");
		
		
		
		classAliases.put(new Integer(1), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Adult");
		classAliasComments.put(new Integer(1), "Created alias for JBMSTours.serializabletypes.Adult");
		classAliases.put(new Integer(2), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.City");
		classAliasComments.put(new Integer(2), "Created alias for JBMSTours.serializabletypes.City");
		classAliases.put(new Integer(3), "CREATE CLASS ALIAS FOR JBMSTours.Hotel");
		classAliasComments.put(new Integer(3), "Created alias for JBMSTours.Hotel");
		classAliases.put(new Integer(4), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.HotelStay");
		classAliasComments.put(new Integer(4), "Created alias for JBMSTours.serializabletypes.HotelStay");
		classAliases.put(new Integer(5), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Flight");
		classAliasComments.put(new Integer(5), "Created alias for JBMSTours.serializabletypes.Flight");
		classAliases.put(new Integer(6), "CREATE CLASS ALIAS FOR JBMSTours.FlightBuilder");
		classAliasComments.put(new Integer(6), "Created alias for JBMSTours.FlightBuilder");
		classAliases.put(new Integer(7), "CREATE Class alias JGROUP FOR JBMSTours.Group");
		classAliasComments.put(new Integer(7), "Created alias JGROUP for JBMSTours.Group");	
		classAliases.put(new Integer(8), "CREATE CLASS ALIAS FOR JBMSTours.inserters.InsertCities");
		classAliasComments.put(new Integer(8), "Created alias for JBMSTours.inserters.InsertCities");
		classAliases.put(new Integer(9), "CREATE CLASS ALIAS FOR JBMSTours.inserters.InsertCountries");
		classAliasComments.put(new Integer(9), "Created alias for JBMSTours.inserters.InsertCountries");
		classAliases.put(new Integer(10), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Location");
		classAliasComments.put(new Integer(10), "Created alias for JBMSTours.serializabletypes.Location");
		classAliases.put(new Integer(11), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Person");
		classAliasComments.put(new Integer(11), "Created alias for JBMSTours.serializabletypes.Person");
		classAliases.put(new Integer(12), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Picture");
		classAliasComments.put(new Integer(12), "Created alias for JBMSTours.serializabletypes.Picture");
		classAliases.put(new Integer(13), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Tour");
		classAliasComments.put(new Integer(13), "Created alias for JBMSTours.serializabletypes.Tour");
		classAliases.put(new Integer(14), "CREATE CLASS ALIAS FOR JBMSTours.serializabletypes.Child");
		classAliasComments.put(new Integer(14), "Created alias for JBMSTours.serializabletypes.Child");
		classAliases.put(new Integer(15), "CREATE CLASS ALIAS FOR JBMSTours.triggers.TriggerActions");
		classAliasComments.put(new Integer(15), "Created alias for JBMSTours.triggers.TriggerActions");
		classAliases.put(new Integer(16), "CREATE CLASS ALIAS FOR JBMSTours.vti.jdbc1_2.jarvti");
		classAliasComments.put(new Integer(16), "Created alias for JBMSTours.vti.jdbc1_2.jarvti");
		classAliases.put(new Integer(17), "CREATE CLASS ALIAS FOR JBMSTours.JCalendar");
		classAliasComments.put(new Integer(17), "Created alias for JBMSTours.JCalendar");
		classAliases.put(new Integer(18), "CREATE CLASS ALIAS FOR java.util.Calendar");
		classAliasComments.put(new Integer(18), "Created alias for java.util.Calendar");
		
		
		triggers.put(new Integer(1), "CREATE TRIGGER HotelsCascadingDelete1 "+
					 "BEFORE DELETE "+
					 "ON Hotels "+
					 "FOR EACH STATEMENT "+
					 "DELETE FROM HotelAvailability WHERE hotel_id IN "+ 
					 "(SELECT hotel_id from NEW TriggerOldTransitionRows() AS DeletedHotels)");
		
		triggerComments.put(new Integer(1), "Created trigger HotelsCascadingDelete1");
		
		triggers.put(new Integer(2), "CREATE TRIGGER HotelsCascadingDelete2 " +
					 "BEFORE DELETE " +
					 "ON Hotels "+
					 "FOR EACH ROW "+
					 "CALL TriggerActions.deleteOrRedoHotelBooking(getCurrentConnection(), CURRENT_JDATE())");
		triggerComments.put(new Integer(2), "Created trigger HotelsCascadingDelete2");
		
		triggers.put(new Integer(3), "CREATE TRIGGER pseudoMethodIndexInsert "+
					 "AFTER "+
					 "INSERT "+
					 "ON CustomizedTours "+ 
					 "FOR EACH STATEMENT "+
					 "UPDATE CustomizedTours SET getTotalCost = customized_tour.getTotalCost() "+
					 "WHERE group_id IN (select group_id FROM NEW)");
		triggerComments.put(new Integer(3), "Created trigger pseudoMethodIndexInsert");
		triggers.put(new Integer(4), "CREATE TRIGGER pseudoMethodIndexUpdate "+
					 "AFTER "+
					 "UPDATE OF customized_tour "+ 
					 "ON CustomizedTours "+
					 "FOR EACH STATEMENT "+
					 "UPDATE CustomizedTours SET getTotalCost = customized_tour.getTotalCost() "+
					 "WHERE group_id IN (select group_id FROM NEW)");
		triggerComments.put(new Integer(4), "Created trigger pseudoMethodIndexUpdate");
		
		
		
		logic.put(new Integer(1), "CALL PropertyInfo.setDatabaseProperty('cloudscape.database.classpath', 'APP.ToursLogic')");
		logicComments.put(new Integer(1), "Enabled database class loading by setting database classpath.");
	}
	
	
	/**
	 * Creates the class aliases in the database. Do this first, so that
	 * we can reference the aliases in the schema.
	 *
	 * @param     conn       Connection 
	 *
	 * @return    boolean if the creation worked
	 *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createClassAliases(Connection conn) throws SQLException {
		
	    return executeStatements(conn, classAliases, classAliasComments, CLASSALIASCOUNT);
	}
    /**
     * Creates the tables  the database. 
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createTables(Connection conn) throws SQLException {
		
	    return executeStatements(conn, tables, tableComments, TABLECOUNT);
	}
    /**
     * Creates the indexes in the database.
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createIndexes(Connection conn) throws SQLException {
		
	    return executeStatements(conn, indexes, indexComments, INDEXCOUNT);
	}
    /**
     * Creates the views in the database. 
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createViews(Connection conn) throws SQLException {
		
	    return executeStatements(conn, views, viewComments, VIEWCOUNT);
	}
    /**
     * Creates the other aliases (method aliases, aggregates) in the database. 
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createOtherAliases(Connection conn) throws SQLException {
		
	    return executeStatements(conn, otherAliases, otherAliasComments, OTHERALIASCOUNT);
			}


	/**
     * Creates the main database objects (all except stored prepared statements,
	 * which we should create later, after data is loaded.);
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createMainDatabaseObjects(Connection conn) throws SQLException {
		
	
		if (createClassAliases(conn) &&
			createTables(conn) &&
			createIndexes(conn) &&
			createViews(conn) &&
			createOtherAliases(conn))
			return true;
        else
			return false;
	}
	
    /**
     * we create the stored prepared statements in a separate method, because
     * we want to create them only after we have loaded the data. The statements
     * won't be optimized correctly if the tables are empty
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	
	public boolean createStoredPreparedStatements(Connection conn) throws SQLException {
		
		conn.setAutoCommit(true);
		s = conn.createStatement();
		for (int i = 1; i <=SPSSTATEMENTCOUNT; i++) {
			
			s.executeUpdate((String) storedPreparedStatements.get(new Integer(i)));
			System.out.println((String) spsComments.get(new Integer(i)));
		}
		
		
		s.close();
		conn.setAutoCommit(false);
	    if (conn != null)
			return true;
	    return false;
		
	}
	
    /**
     * Don't create triggers until after we load data.
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createTriggers(Connection conn) throws SQLException {
		
		conn.setAutoCommit(true);
		s = conn.createStatement();
		for (int i = 1; i <=TRIGGERCOUNT; i++) {
			
			s.executeUpdate((String) triggers.get(new Integer(i)));
			System.out.println((String) triggerComments.get(new Integer(i)));
		}
		
		
		s.close();
		conn.setAutoCommit(false);
	    if (conn != null)
			return true;
	    return false;
		
	}
	


    /**
     * Store logic in the database. Do this only in pre-building database.
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createDatabaseClasspath(Connection conn) throws SQLException {

		Statement s = conn.createStatement();
		for (int i = 1; i <=LOGICCOUNT; i++) {
			
			s.executeUpdate((String) logic.get(new Integer(i)));
			System.out.println((String) logicComments.get(new Integer(i)));


		}
		
		s.close();
	    if (conn != null)
			return true;
	    return false;
		
		}
		
		

	/**
     * Creates a script that rebuilds the database schema.
     *
     * @param     conn       Connection 
     *
     * @return    boolean 
     *
     * @exception java.sql.SQLException an error occurred.
     */
	
	public boolean createSQLScript(Connection conn) throws SQLException {

		createScriptForStatements(classAliases, CLASSALIASCOUNT);
		createScriptForStatements(tables, TABLECOUNT);
		createScriptForStatements(indexes, INDEXCOUNT);
		createScriptForStatements(views, VIEWCOUNT);
		createScriptForStatements(otherAliases, OTHERALIASCOUNT);
		createScriptForStatements(storedPreparedStatements, SPSSTATEMENTCOUNT);
		createScriptForStatements(triggers, TRIGGERCOUNT);
		return insertableAsSQL;
	}



    /**
     * Creates database objects given the hashtables and count.
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	private static boolean executeStatements(Connection conn, Hashtable dbos, Hashtable comments, int count) throws SQLException {

		Statement st = conn.createStatement();
		for (int i = 1; i <=count; i++) {
			
			st.executeUpdate((String) dbos.get(new Integer(i)));
			System.out.println((String) comments.get(new Integer(i)));
			
		}
		
	    st.close();
	    if (conn != null)
			return true;
	    return false;
			
	}

    /**
     * Creates a script for the database objects given the hashtable and count.
     *
     * @param     conn       Connection 
     *
     * @return    boolean if the creation worked
     *
     * @exception java.sql.SQLException an error occurred.
     */
	private static void createScriptForStatements(Hashtable dbos, int count) {


		for (int i = 1; i <=count; i++) {
			
			System.out.println((String) dbos.get(new Integer(i)) + ";");
		}

	}



}
















