package JBMSTours;

import java.sql.*;
import JBMSTours.inserters.*;

/**
 * Look at the <a href="../JBMSTours/CreateScript.java">Source</a>.<p>
 * Run this program and redirect the output to a .sql file to create a script
 *  that you can run within ij to re-create the clean database in any name of your
 *  choosing. ToursDB must already be built to run this program. It creates all
 *  the tables but only re-populates the core tables, as if you ran CreateToursDB.
 *  The SQL script this program makes will take much longer to
 *  run than CreateToursDB because it does not use prepared statements.
 *
 * <p>This class has a main() method and can be run from the command-line.
 * For complete instructions on how to run it, see the <a href="../example.html#running">example instructions</a>.
 *
 */
public class CreateScript 
{
    /**
     *  Whether you are running in embedded or client/server mode.
     **/
    public ApplicationMode mymode;

    /**
     * Entry point into archiving data.
     *
     * @param args    ignored
     */
    public static void main(String[] args)
    {
        ApplicationMode runmode = new ApplicationMode(args);
        (new CreateScript()).go(runmode);
    }

    /**
     *
     **/
    void go(ApplicationMode amode)
    {
        System.out.println("--CreateScript starting");
        mymode = amode;
        try
        {
            Connection conn = mymode.connectToCloudscape();
            /*
             ** Creating a statement lets us issue commands against
             ** the connection.
             */
            CreateSchema cs = new CreateSchema();
            cs.createSQLScript(conn);
            InsertCountries ic;
            ic = new InsertCountries();
            ic.createSQLScript(conn);
            InsertFlights ifl;
            ifl = new InsertFlights();
            ifl.createSQLScript(conn);
            Inserters im = new InsertMaps();
            im.createSQLScript(conn);
            Inserters ict = new InsertCities();
            ict.createSQLScript(conn);
            Inserters ih = new InsertHotels();
            ih.createSQLScript(conn);
            Inserters ia = new InsertAvailability(400,true);
            ia.createSQLScript(conn);
            conn.commit();
            conn.close();
            mymode.quitCloudscape();
        }
        catch(Throwable e)
        {
            System.out.println("exception thrown:");
            e.printStackTrace();
            CreateToursDB.errorPrint(e);
        }
        System.out.println("--CreateScript finished");
        System.out.println("--You now have a SQL script that you can run within ij.");
        System.out.println("You may need to comment out the first few lines.");
    }

}

