package JBMSTours;
import java.sql.*;


/**
 * Look at the <a href="../JBMSTours/GenerateReport.java">source</a>.<p>
 * This class executes some queries that include aggregate functions.
 * Aggregates are good for generating reports, 
 * because they tell you information about
 * maximum, minimum, sum, averages.
 *
 * <p>This class has a main() method and can be run from the command-line.
 * For complete instructions on how to run it, see the <a href="../example.html#running">example instructions</a>.
 *
 */
public class GenerateReport {

    public ApplicationMode mymode;

    public static void main(String[] args) {


	/* testing for the client mode information (hostname and portnum)*/
      ApplicationMode runmode = new ApplicationMode(args);
        (new GenerateReport()).go(runmode);
    }

    void go(ApplicationMode amode) {
        System.out.println("GenerateReport starting");
        mymode = amode;
        try {


            Connection conn = mymode.connectToCloudscape();

            /*
                Creating a statement lets us issue commands against
                the connection.
             */
            Statement s = conn.createStatement();
            ResultSet rs;

            String getHottestCityInEachRegion = 
                "SELECT MAX(city.showTemperature()), Countries.Region "+
                "FROM Cities JOIN Countries " +
                "ON Cities.country_ISO_code = Countries.country_ISO_code " +
                "GROUP BY Region";

			String getSecondHottestCityInEachRegion = 
                "SELECT MaxButONE(city.showTemperature()), Countries.Region "+
                "FROM Cities JOIN Countries " +
                "ON Cities.country_ISO_code = Countries.country_ISO_code " +
                "GROUP BY Region";

            String getHottestCityInEachHotRegion = 
                "SELECT MAX(city.showTemperature()), Region "+
                "FROM Cities JOIN Countries " +
                "ON Cities.country_ISO_code = Countries.country_ISO_code " +
                "GROUP BY Region " + 
                "HAVING AVG(city.showTemperature()) > 70.0";

            String getNumberOfCitiesPerRegion = 
                "SELECT COUNT(*), Region FROM Cities JOIN Countries " +
                "ON Cities.country_ISO_code = Countries.country_ISO_code " +
                "GROUP BY Region";

            String getNumberOfCitiesPerCountry = 
                "SELECT country, COUNT(city_id) "+
                "FROM Countries LEFT OUTER JOIN Cities "+
                "ON Cities.country_ISO_code = Countries.country_ISO_code " +
                "GROUP BY country";

            
            String getTotalCostOfAllTours = 
                "SELECT SUM(customized_tour.getTotalCost().doubleValue()) "+
                "FROM CustomizedTours";

            String getAverageCostOfaHotelStay = 
                "SELECT AVG(total_cost) FROM HotelBookings";

            String getTotalSeatsBookedPerAirline = 
                "SELECT airline_full AS Carrier, "+
                "SUM(number_seats) AS Total_Seats "+
                "FROM airlines, Segments_SeatBookings "+
                "WHERE flight_id.substring(0,2).equals(airline) " +
                "GROUP BY airline_full";


            String getAverageMileageOfTours = 
                "SELECT AVG(customized_tour.getTotalMilesTraveled()) "+
                "FROM CustomizedTours";

            String getSecondLongestFlight = 
                "SELECT MaxButONE(miles) "+
                "FROM Flights";

            String getGroupThatSpentMostMoney = 
                "SELECT customized_tour.getGroup(getCurrentConnection()).getInfo(getCurrentConnection()) "+
                "FROM customizedTours "+
                "WHERE customized_tour.getTotalCost().doubleValue() = "+
                    "(SELECT MAX(customized_tour.getTotalCost().doubleValue())"+
                    "FROM customizedtours)";

            System.out.println();
            System.out.println("Hottest Average Temperature in each Region");
            rs = s.executeQuery(getHottestCityInEachRegion);
            while (rs.next()) {
                System.out.println("Region: " + rs.getString(2) + " " 
                    + rs.getDouble(1));
            }
            rs.close();

			System.out.println();
			System.out.println("Second Hottest Average Temperature in each Region");
            rs = s.executeQuery(getSecondHottestCityInEachRegion);
            while (rs.next()) {
                System.out.println("Region: " + rs.getString(2) + " " 
                    + rs.getDouble(1));
            }
            rs.close();

            System.out.println();
            System.out.println("Number of Cities per Region");
            rs = s.executeQuery(getNumberOfCitiesPerRegion);
            while (rs.next()) {
                System.out.println("Region " + rs.getString(2) + ": " 
                    + rs.getInt(1));
            }
            rs.close();

            System.out.println();
            rs = s.executeQuery(getTotalCostOfAllTours);
            rs.next(); 
            System.out.println("Total cost of all tours booked: " 
                + rs.getDouble(1));
            rs.close();

            System.out.println();
            rs = s.executeQuery(getAverageCostOfaHotelStay);
            rs.next(); 
            System.out.println("Average Cost of a HotelStay: " 
                + rs.getBigDecimal(1, 2));
            rs.close();


            System.out.println();
            System.out.println("Information about the group that spent the most");
            rs = s.executeQuery(getGroupThatSpentMostMoney);
            rs.next();
            System.out.println(rs.getString(1));
       
            rs.close();

            System.out.println();
            System.out.println("Distance of the second-longest flight");
            rs = s.executeQuery(getSecondLongestFlight);
            rs.next();
            System.out.println(rs.getString(1));
       
            rs.close();

            System.out.println();
            System.out.println("Total Number of Seats Booked, per Airline");
            rs = s.executeQuery(getTotalSeatsBookedPerAirline);
            while (rs.next()) {
                System.out.println("Airline: " + rs.getString(1) + ": " + rs.getInt(2));
            }
            rs.close();

            s.close();
			conn.commit();
			conn.close();
            mymode.quitCloudscape();             


        } catch (Throwable e) {
            System.out.println("exception thrown:");
            CreateToursDB.errorPrint(e);
        }


         System.out.println("Generate Report finished");
    }

}
