package JBMSTours;

import java.sql.Date;
import java.sql.Time;
import java.util.Calendar;
import java.util.GregorianCalendar;

/** 
 * Look at the <a href="../JBMSTours/JCalendar.java">Source</a>.<p>
 * This class creates an array of 64 dates beginning with TODAY.
 *
 * Used by BuildATour to come up with dates in the next 64 days and so build a 
 * database with current data.<p>
 * The static methods of this class make it easier to work with java.sql.Dates.
 * For example, some of the methods allow you to add and 
 * subtract dates and times, since that's not built into 
 * the Java core classes. 
 */
public class JCalendar {

    public static int NUMDAYS=64;
	private Calendar calendar = new GregorianCalendar();
	private Date today;
    private  Date[] sqlday;

    public JCalendar() {
        Long testDate = Long.getLong("JBMSTours.testDate");
        if (testDate != null) {
            TourDate.setNow(testDate.longValue());
		}
		TourDate tmpDate = new TourDate();
		calendar.setTime(tmpDate);
		today = new Date(calendar.getTime().getTime());
		
        sqlday = new java.sql.Date[NUMDAYS];
        setArray();
    }

    /**
     * Utility for loading up an array of days.
     */
    private void setArray() {

		sqlday[0] = today;
		for (int i = 1; i < NUMDAYS; i++ ) {
			calendar.add(Calendar.DAY_OF_YEAR, 1);
			sqlday[i] = new Date(calendar.getTime().getTime());
		}       
	}
	
  
    /**
     * Get a particular day.
     *
     * @param i    the date
     *
     * @return the day
     */
    public java.sql.Date getDay(int	 i) {
	   
        return this.sqlday[i];
    }

    /**
     * Increment the given date by one day.
     *
     * @param theDate    the date to increment
     *
     * @return    the new date (theDate + 1 day)
     */
    public static java.sql.Date incrementDate(java.sql.Date theDate) {
		Calendar scalendar = new GregorianCalendar();
        scalendar.setTime(theDate);
        scalendar.add(Calendar.DAY_OF_YEAR, 1);
        return new java.sql.Date(scalendar.getTime().getTime());
    }


    /**
     * Get the difference between two java.sql.Dates using their UTC values.
     * If the second date is later than the first date, returns a negative number.
	 *
     * @param later    the first date
	 * @param earlier  the second date
     *
     * @return    int 
     */
    public static int getDateDifference(Date later, Date earlier) {
        double difference = 0;
		long millisecondsinoneday = 24*60*60*1000;
		long l = later.getTime();
		long e = earlier.getTime();
		difference = (double) ((double) (l - e)/ (double)millisecondsinoneday);
		difference = Util.round(difference, 1);
		return (int) difference;
    }



    /** 
     * Returns the difference between two times as a Time. If end is 
     * before beginning, assumes only one rotation of clock. 
     *
     * @param start    the start time
     * @param end      the end time
     *
     * @return         the difference as a java.sql.Time
     */
	  public static Time getTheTimeDifference(java.sql.Time start, java.sql.Time end) {

		  long difference = 0;
		  long endt = end.getTime();
		  long startt = start.getTime();
		  difference = endt - startt;
		  //we need to add this offset to the constructor of Time
		  long offset = new java.sql.Timestamp(70, 0, 1, 0, 0, 0, 0).getTime();
		  return new Time(difference+offset);
		  
    }

	
    /** 
     * Returns the difference between two times as a double. If end is 
     * before beginning, assumes only one rotation of clock.
     *
     * @param start    the start time
     * @param end    the end time
     *
     * @return    the difference as a double
     */
    public static double getTimeDifference(java.sql.Time start, java.sql.Time end) {

		Time timedif = getTheTimeDifference(start, end);
		 
        double forceDecimal = (double) (timedif.getMinutes()/60.0);

        return (double) (timedif.getHours() + forceDecimal);
    }

    /** 
     * Returns java.sql.Date representing the current date or a testing
	 * date (if one has been set).
     *
     * @return    today
	 * If there is a system property called JBMSTours.testDate, we
	 * are in test mode, and that property is a String that represents
	 * the value of "now".  This allows us to get consistent results
	 * while testing this application.  If this property is not set,
	 * the results depend on today's date.
	 *
	 * The value of the property is specified as the number of milliseconds
	 * since January 1, 1970, 00:00:00 GMT.
	 *
	 */
	
	public static Date getToday() {
		Calendar scalendar = new GregorianCalendar();
        Long testDate = Long.getLong("JBMSTours.testDate");
        if (testDate != null) {
            TourDate.setNow(testDate.longValue());
		}
		TourDate tmpDate = new TourDate();
		scalendar.setTime(tmpDate);
		Date today = new Date(scalendar.getTime().getTime());
		return today;
	}


	
    /** 
     * Returns the day of the month for the given date.
	 *
	 * @param     d            The given date.
     *
     * @return    today
	 *
	 */
	public static int getDate(Date d) {
		Calendar scalendar = new GregorianCalendar();
		scalendar.setTime(d);
		return scalendar.get(Calendar.DAY_OF_MONTH);

	}

    /** 
     * Returns the actual year for the given date (NOT year-1900).
	 *
	 * @param     d            The given date.
     *
     * @return    today
	 *
	 */
	public static int getYear(Date d) {
		Calendar scalendar = new GregorianCalendar();
		scalendar.setTime(d);
		return scalendar.get(Calendar.YEAR);

	}
    /** 
     * Returns the month
	 *
	 * @param     d            The given date.
     *
     * @return    today
	 *
	 */
	public static int getMonth(Date d) {
		Calendar scalendar = new GregorianCalendar();
		scalendar.setTime(d);
		return scalendar.get(Calendar.MONTH);

	}
}

