package JBMSTours;

import java.awt.*;
import java.awt.event.*;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.io.File;
import java.io.InputStream;



/**
 *  Look at the <a href="../JBMSTours/PictureFrame.java">Source</a>.<p>
 *  The frame for the picture, which loads the image and places
 *  it onto the canvas. Uses minimal AWT code.. Used by Cloudview to display
 *  Picture objects.
 *  
 **/
public class PictureFrame extends Frame 
{
    /**
     *  The image.
     **/
    Image image;
    /**
     *  Constructor. Takes a name and byte array.
	 *
	 * @exception    Exception if there's a problem creating the PictureFrame.
     **/
    public PictureFrame(String name, byte[] im) throws Exception
    {
        super("Picture Frame: " + name);
        addNotify();
        // to create the Insets
        /*
           This lets the window close when the dispose
           window control is pressed.
         */
        addWindowListener(new WindowCloser());
        image = getToolkit().createImage(im);
        trackSizeAndShow();
    }

    /**
     * Takes the name and a URL.
	 *
	 * @exception Exception if there's a problem creating the PictureFrame.
     **/
    public PictureFrame(String name, String url) throws Exception
    {
        super("Picture Frame - " + name);
        addNotify();
        // to create the Insets
        /*
           This lets the window close when the dispose
           window control is pressed.
         */
        addWindowListener(new WindowCloser());
        image = getToolkit().getImage(new URL(url));
        trackSizeAndShow();
    }

    /**
     * A utility method.
	 *
	 * @exception    Exception if there's a problem creating the PictureFrame.
     **/
    public void trackSizeAndShow() throws Exception
    {
        /*
           make sure we have the image before it gets painted
         */
        MediaTracker tracker = new MediaTracker(this);
        tracker.addImage(image,0);
        tracker.waitForID(0);
        if(tracker.isErrorID(0))
            throw new Exception("Unable to load image");
        /*
           add the borders to the image size using the insets
         */
        Insets insets = new Insets(0,0,0,0);
        this.setSize(insets.left + insets.right + image.getWidth(this),insets.top + insets.bottom + image.getHeight(this));
        show();
    }

    /**
     *  Paint the picture.
     **/
    public void paint(Graphics g)
    {
        update(g);
    }

    /**
     * Update it.
     **/
    public void update(Graphics g)
    {
        Insets insets = new Insets(0,0,0,0);
        g.drawImage(image,insets.left,insets.top,this);
    }

}

/**
   The class to control window disposal.
 */
class WindowCloser extends WindowAdapter 
{
    /**
     *
     **/
    public void windowClosing(WindowEvent we)
    {
        we.getWindow().dispose();
    }

}







