package JBMSTours;
import java.sql.Date;
import java.sql.Time;

/**
 * This is a utility class with static methods for doing various unrelated
 * things.
 */
public class Util {

    /**
     * Round a double to the given precision.  Round positive numbers up,
     * and negative numbers down.
     *
     * @param valueToRound  The double to round
     * @param roundPrecision    The precision to round the number to.
     *                          For example, if you want to round a
     *                          number to the nearest hundredth, the value
     *                          of this parameter should be 0.01.  It is
     *                          possible to round to precisions that
     *                          are not powers of 10.
     *
     * @return  The rounded value.
     */
    public static double round(double valueToRound, double roundPrecision) {
        long    roundedSignificantDigits;

        if (valueToRound > 0.0)
            valueToRound += (roundPrecision / 2.0);
        else
            valueToRound -= (roundPrecision / 2.0);

        roundedSignificantDigits = truncate(valueToRound / roundPrecision);

        return ((double) roundedSignificantDigits) * roundPrecision;
    }

    /**
     * NOTE: This cast is done in a method to work around a Cafe 1.8 JIT bug
     * where it would get incorrect results if the cast were done in line.
     *
     * @param valueToTruncate	A double to truncate to a long.
     *
     * @return	The given parameter cast to a long.
     */
    private static long truncate(double valueToTruncate) {
        return (long) valueToTruncate;
    }

    /**
     * Does a System.out.println unless a property is set.
     *
     * Allows you to avoid printing out messages for database-side
     * methods, when application and server are running in different
     * JVMs (client/server scenario or synchronization scenario).
     * In those situations, set <i>JBMSTours.databaseSide</i> to true before
     * starting up the server or the source database.
     *
     * @param	The string to print.
     */
    public static void println(Object s) {

        String p = System.getProperty("JBMSTours.databaseSide");
        if (p == null)
	  p = "false";
        if (p.equals("false")) {
	  System.out.println(s);
	}
    }

    /**
     * Does a System.out.println unless a property is set.
     *
     * Allows you to avoid printing out messages for database-side
     * methods, when application and server are running in different
     * JVMs (client/server scenario or synchronization scenario).
     * In those situations, set <i>JBMSTours.databaseSide</i> to true before
     * starting up the server or the source database.
     *
     */
    public static void println() {
		
        String p = System.getProperty("JBMSTours.databaseSide");
        if (p == null)
			p = "false";
        if (p.equals("false")) {
			System.out.println();
		}

    }



    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param s	a String
     *
     * @return	The String wrapped in quotation marks.
     */

	public static String wrapAsString(String s) {

		return "\"" + s + "\"";
	}

    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param s	a String
     *
     * @return	The String wrapped in single quotation marks.
     */

	public static String wrapAsStringSQ(String s) {

		return "'" + parseForApostrophes(s) + "'";
	}

    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param s	a String
     *
     * @return	The String wrapped in quotation marks and a comma.
     */

	public static String wrapAsStringWithComma(String s) {

		return "\"" + s + "\", ";
	}

    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param s	a String
     *
     * @return	The String wrapped in single quotation marks and a comma.
     */
		public static String wrapAsStringWithCommaSQ(String s) {

		return "'" + parseForApostrophes(s) + "', ";
	}


    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param s	a String
     *
     * @return	The string returned without any quotation marks,but with a comma.
     */
		public static String wrapAsJavaExpressionWithComma(String s) {

		return s + ", ";
	}


	
    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param i	an int
     *
     * @return	The int plus a comma
     */

	public static String wrapIntWithComma(int i) {

		return  i + ", ";
	}
	
    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param s	a short
     *
     * @return	The short plus a comma
     */

	public static String wrapShortWithComma(short s) {

		return  s+ ", ";
	}
	
    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param d a date
     *
     * @return	AN SQL represenation of the date.
     */

	
	public static String wrapAsSQLDate(Date d) {

		return  "DATE'" + d.toString() + "'";
	}
	
    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param t a time
     *
     * @return	AN SQL represenation of the time.
     */

	public static String wrapAsSQLTime(Time t) {

		return  "TIME'" + t.toString() + "'";
	}
	
    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param d a date
     *
     * @return	AN SQL represenation of the date plus a comma.
     */

	public static String wrapAsSQLDateWithComma(Date d) {

		return  wrapAsSQLDate(d) + ", ";
	}


    /**
     * Used for extracting data into an SQL script or into Java
	 * program for re-insert (CreateScript).
     *
     * @param d a date
     *
     * @return	AN SQL represenation of the date plus a comma.
     */

	public static String wrapAsSQLTimeWithComma(Time t) {

		return  wrapAsSQLTime(t) + ", ";
	}

	private static String parseForApostrophes(String s) {
		
		StringBuffer sb = new StringBuffer("");
		int length = s.length();
		for (int i = 0; i < length; i++) {
			if (s.charAt(i) != '\'')
				sb.append(s.charAt(i));
			else
				sb.append("''");
		}
		return sb.toString();
		
	}
	/*demonstrates using INOUT parameters with a call statement*/
	public static void doubleMyInt(int[] i) {

		i[0] *=2;

		/* the user will retrieve this value as an INOUT
		   parameter.*/
		
	}

	
    /**
     * Return the line separator for the OS.
	 *
     * @return	The line separator.
     */


	public static String lineSeparator() {

		return System.getProperty("line.separator");

	}
 
}









