package JBMSTours.aggregates;
import COM.cloudscape.aggregates.Aggregator;
import COM.cloudscape.aggregates.AggregateDefinition;
import COM.cloudscape.types.TypeDescriptor;
import java.io.IOException;
import java.sql.Types;


/**
 * Look at the <a href="../JBMSTours/aggregates/MaxButOneDef.java">Source</a>.<p>
 *
 * Defines the aggregators for an aggregate (MaxButONE). This aggregate
 * returns the runnner up value
 * for the column (not the max, but the value right
 * after that). If the column only contains 0 or 1 rows, it returns a NULL.
 * <p>You may need to use DISTINCT in conjunction with the aggregate.
 * <p>As implemented, works only for INTs and DOUBLE PRECISIONs.
 * <p>
 * We implement Externalizable to save space in case we
 * are written out.
 */
public class MaxButOneDef implements AggregateDefinition
{

	
	/**
	 * Niladic constructor
	 */	
	public MaxButOneDef()
	{
	}

	/////////////////////////////////////////////////////////////////
	//
	// AGGREGATE DEFINITION
	//
	/////////////////////////////////////////////////////////////////
	
	/**
	 * @param inputType	the input type descriptor
	 * @param aggregatorClassName	output parameter, filled in
	 *		with the class name that implements COM.cloudscape.aggregates.Aggregator
	 *
	 * @return the output type descriptor (which may or may not
	 *		be the same as the input type -- it is ok to simply
	 *		return the input type).  Null is returned
	 *		if the aggregate cannot process the input type.
	 *
	 * @see COM.cloudscape.types.TypeDescriptor
	 */
	public	TypeDescriptor getAggregator(TypeDescriptor inputType,
							StringBuffer aggregatorClassName)
	{
        //for now, support only INTEGER and DOUBLE
		int mytype = inputType.getJDBCTypeId();
		switch (mytype)
		{
			case Types.INTEGER:
				aggregatorClassName.append("JBMSTours.aggregates.MaxButOneIntegerAggregator");	
				break;

			case Types.DOUBLE:
				aggregatorClassName.append("JBMSTours.aggregates.MaxButOneDoubleAggregator");	
				break;

			default:
				return null;
		}
		return inputType;
	}
}
