package JBMSTours.inserters;
import java.sql.*;
import java.lang.Math;
import JBMSTours.JCalendar;
import JBMSTours.Util;

/**
 *   Inserts some random date-specific data into the HotelAvailability and
 *   Flight Availability tables. Called by CreateToursDB.
 *  
 */  
public class InsertAvailability  implements Inserters {

    private PreparedStatement insert1;
    private PreparedStatement insert2;
    private String insertString1;
    private String insertString2;
    private int rowsInserted;
    private boolean insertableAsSQL=true;
    int maxrows;
    boolean upToDateData = true;
    JCalendar myCalendar;


    //////////////////
    // constructor
    //////////////////

    public InsertAvailability(int rowlimit, boolean nonreplication) {

		insertString1 ="INSERT INTO flightavailability VALUES (?, ?, ?, ?, ?, ?)";

		insertString2 = "INSERT INTO hotelavailability VALUES (?, ?, ?)";
		rowsInserted = 0;
		maxrows = rowlimit;
		upToDateData = nonreplication;
		
    }
    
	
	/**
     * Inserts data into the 
     * FlightAvailability and HotelAvailability tables.
     *
     * @param conn     the name of the connection
     *
     * @exception SQLException  Thrown if there is a SQL error.
     *
     */
    public boolean insert (Connection conn) throws SQLException {
		
        if (!prepareStatements(conn))
			return false;
		
		if (upToDateData) {
			int maxpertable = maxrows/2;
			myCalendar = new JBMSTours.JCalendar();
			
			Statement getFlightInfo = conn.createStatement();
			ResultSet rs1 = getFlightInfo.executeQuery("SELECT flight_id, segment_number FROM Flights");
			
			
			int i = 0;
			int row=0;
			int randomrow = 0;
			
			
			/* as long as the result set is open and we haven't exceed the maximum
			   number of rows to update, insert some seemingly random data into the 
			   flightavailability table using those flight_ids and segment_numbers.
			   this data is "up to date" with when the db was built*/ 
			while (rs1.next() && rowsInserted < maxpertable) {
				
				row++;
				randomrow = getNextOnClock(7, randomrow);
                int secondrandom=0;
				int thirdrandom = 0;
				int fourthrandom=0;
				int fifthrandom = 0;
				
				if (row % (randomrow+1) == 0) {
					for (i = 0; i < JBMSTours.JCalendar.NUMDAYS; i++)  {
						
						secondrandom = getNextOnClock(11, secondrandom);
						thirdrandom = getNextOnClock(14, secondrandom);
						fourthrandom = getNextOnClock(5, secondrandom);
						fifthrandom = getNextOnClock(2, secondrandom);
						
						if (i % (secondrandom + 1) == 0 && rowsInserted < maxpertable) {
					thirdrandom=
						rowsInserted += makeFlightAvailabilityEntry(rs1.getString(1), rs1.getInt(2), myCalendar.getDay(i),
																	thirdrandom, fourthrandom, fifthrandom);


					
						}
					}
				}
			}
				
			
	
			rs1.close();
					
			row=0;
			/* get all hotel_ids from Hotels table*/
			ResultSet rs2 = getFlightInfo.executeQuery("SELECT hotel_id FROM Hotels");
			
			/* as long as the result set is open and we haven't exceed the maximum
			   number of rows to update, insert some random data into the 
			   hotelavailability table using those hotel_ids.*/ 
			randomrow=0;
			while (rs2.next() && rowsInserted < maxrows) {
				row++;  
				randomrow = getNextOnClock(8, randomrow);
				
				if (row % (randomrow+1) == 0) {
					int secondrandom=0;
					int thirdrandom = 0;
					
			
					for (i = 0; i < JBMSTours.JCalendar.NUMDAYS; i++)  {
						secondrandom=getNextOnClock(15, secondrandom);
						thirdrandom=getNextOnClock(5, thirdrandom);
						
						if (i % (secondrandom + 1) == 0 && rowsInserted < maxrows) {
							rowsInserted += makeHotelAvailabilityEntry(rs2.getInt(1), myCalendar.getDay(i), thirdrandom);
						}
					}

				}
			}
			rs2.close();

			
		}
		
		else {					// put in entirely static data
			
			rowsInserted += makeHotelAvailabilityEntry(10, new Date(100, 6, 2), 4);
			rowsInserted += makeHotelAvailabilityEntry(10, new Date(100, 6, 16), 5);
			rowsInserted += makeHotelAvailabilityEntry(10, new Date(100, 6, 28), 6);
			rowsInserted += makeHotelAvailabilityEntry(10, new Date(100, 7, 10), 4);
			rowsInserted += makeHotelAvailabilityEntry(10, new Date(100, 7, 20), 6);
			rowsInserted += makeHotelAvailabilityEntry(11, new Date(100, 6, 8), 7);
			rowsInserted += makeHotelAvailabilityEntry(11, new Date(100, 6, 20), 4);
			rowsInserted += makeHotelAvailabilityEntry(11, new Date(100, 6, 30), 4);
			rowsInserted += makeHotelAvailabilityEntry(11, new Date(100, 7, 14), 5);
			rowsInserted += makeHotelAvailabilityEntry(11, new Date(100, 7, 24), 6);
			rowsInserted += makeHotelAvailabilityEntry(12, new Date(100, 6, 10), 6);
			rowsInserted += makeHotelAvailabilityEntry(12, new Date(100, 6, 22), 8);
			rowsInserted += makeHotelAvailabilityEntry(12, new Date(100, 7, 4), 4);
			rowsInserted += makeHotelAvailabilityEntry(12, new Date(100, 7, 17), 7);
			rowsInserted += makeHotelAvailabilityEntry(12, new Date(100, 7, 28), 6);
			rowsInserted += makeHotelAvailabilityEntry(13, new Date(100, 6, 14), 8);
			rowsInserted += makeHotelAvailabilityEntry(13, new Date(100, 6, 24), 4);
			rowsInserted += makeHotelAvailabilityEntry(13, new Date(100, 7, 8), 6);
			rowsInserted += makeHotelAvailabilityEntry(13, new Date(100, 7, 18), 8);
			rowsInserted += makeHotelAvailabilityEntry(13, new Date(100, 8, 3), 6);
			rowsInserted += makeHotelAvailabilityEntry(30, new Date(100, 6, 2), 8);
			rowsInserted += makeHotelAvailabilityEntry(30, new Date(100, 6, 16), 8);
			rowsInserted += makeHotelAvailabilityEntry(30, new Date(100, 7, 28), 7);
			rowsInserted += makeHotelAvailabilityEntry(31, new Date(100, 6, 7), 7);
			rowsInserted += makeHotelAvailabilityEntry(31, new Date(100, 6, 22), 8);
			rowsInserted += makeHotelAvailabilityEntry(31, new Date(100, 7, 29), 4);
			rowsInserted += makeHotelAvailabilityEntry(32, new Date(100, 6, 12), 7);
			rowsInserted += makeHotelAvailabilityEntry(32, new Date(100, 7, 2), 5);
			rowsInserted += makeHotelAvailabilityEntry(32, new Date(100, 8, 1), 8);
			rowsInserted += makeHotelAvailabilityEntry(33, new Date(100, 6, 14), 9);
			rowsInserted += makeHotelAvailabilityEntry(33, new Date(100, 7, 12), 7);
			rowsInserted += makeHotelAvailabilityEntry(40, new Date(100, 6, 4), 8);
			rowsInserted += makeHotelAvailabilityEntry(40, new Date(100, 6, 20), 8);
			rowsInserted += makeHotelAvailabilityEntry(40, new Date(100, 7, 14), 9);
			rowsInserted += makeHotelAvailabilityEntry(40, new Date(100, 8, 3), 4);
			rowsInserted += makeHotelAvailabilityEntry(41, new Date(100, 6, 8), 6);
			rowsInserted += makeHotelAvailabilityEntry(41, new Date(100, 6, 22), 8);
			rowsInserted += makeHotelAvailabilityEntry(41, new Date(100, 7, 16), 5);
			rowsInserted += makeHotelAvailabilityEntry(41, new Date(100, 8, 4), 7);
			rowsInserted += makeHotelAvailabilityEntry(42, new Date(100, 6, 10), 8);
			rowsInserted += makeHotelAvailabilityEntry(42, new Date(100, 6, 26), 8);
			rowsInserted += makeHotelAvailabilityEntry(42, new Date(100, 7, 20), 8);
			rowsInserted += makeHotelAvailabilityEntry(43, new Date(100, 6, 2), 7);
			rowsInserted += makeHotelAvailabilityEntry(43, new Date(100, 6, 11), 8);
			rowsInserted += makeHotelAvailabilityEntry(43, new Date(100, 7, 12), 5);
			rowsInserted += makeHotelAvailabilityEntry(43, new Date(100, 7, 27), 5);
			rowsInserted += makeHotelAvailabilityEntry(75, new Date(100, 6, 10), 8);
			rowsInserted += makeHotelAvailabilityEntry(75, new Date(100, 6, 20), 5);
			rowsInserted += makeHotelAvailabilityEntry(75, new Date(100, 7, 10), 5);
			rowsInserted += makeHotelAvailabilityEntry(75, new Date(100, 8, 1), 6);
			rowsInserted += makeHotelAvailabilityEntry(76, new Date(100, 6, 14), 6);
			rowsInserted += makeHotelAvailabilityEntry(76, new Date(100, 6, 23), 8);
			rowsInserted += makeHotelAvailabilityEntry(76, new Date(100, 7, 12), 5);
			rowsInserted += makeHotelAvailabilityEntry(77, new Date(100, 6, 2), 7);
			rowsInserted += makeHotelAvailabilityEntry(77, new Date(100, 6, 15), 9);
			rowsInserted += makeHotelAvailabilityEntry(77, new Date(100, 6, 27), 8);
			rowsInserted += makeHotelAvailabilityEntry(77, new Date(100, 7, 26), 6);
			rowsInserted += makeHotelAvailabilityEntry(78, new Date(100, 6, 3), 7);
			rowsInserted += makeHotelAvailabilityEntry(78, new Date(100, 6, 17), 5);
			rowsInserted += makeHotelAvailabilityEntry(78, new Date(100, 7, 2), 9);
			rowsInserted += makeHotelAvailabilityEntry(78, new Date(100, 7, 27), 7);
			rowsInserted += makeHotelAvailabilityEntry(105, new Date(100, 6, 17), 7);
			rowsInserted += makeHotelAvailabilityEntry(105, new Date(100, 7, 2), 8);
			rowsInserted += makeHotelAvailabilityEntry(105, new Date(100, 7, 20), 4);
			rowsInserted += makeHotelAvailabilityEntry(106, new Date(100, 6, 2), 7);
			rowsInserted += makeHotelAvailabilityEntry(106, new Date(100, 6, 20), 8);
			rowsInserted += makeHotelAvailabilityEntry(106, new Date(100, 7, 4), 7);
			rowsInserted += makeHotelAvailabilityEntry(106, new Date(100, 7, 21), 8);
			rowsInserted += makeHotelAvailabilityEntry(107, new Date(100, 6, 4), 8);
			rowsInserted += makeHotelAvailabilityEntry(107, new Date(100, 6, 23), 6);
			rowsInserted += makeHotelAvailabilityEntry(107, new Date(100, 7, 11), 5);
			rowsInserted += makeHotelAvailabilityEntry(107, new Date(100, 7, 26), 6);
			rowsInserted += makeHotelAvailabilityEntry(108, new Date(100, 6, 14), 4);
			rowsInserted += makeHotelAvailabilityEntry(108, new Date(100, 6, 30), 9);
			rowsInserted += makeHotelAvailabilityEntry(108, new Date(100, 7, 16), 7);
			rowsInserted += makeHotelAvailabilityEntry(108, new Date(100, 7, 27), 6);
			rowsInserted += makeHotelAvailabilityEntry(120, new Date(100, 6, 2), 5);
			rowsInserted += makeHotelAvailabilityEntry(120, new Date(100, 6, 24), 4);
			rowsInserted += makeHotelAvailabilityEntry(120, new Date(100, 7, 7), 6);
			rowsInserted += makeHotelAvailabilityEntry(120, new Date(100, 7, 25), 6);
			rowsInserted += makeHotelAvailabilityEntry(121, new Date(100, 6, 8), 4);
			rowsInserted += makeHotelAvailabilityEntry(121, new Date(100, 6, 26), 5);
			rowsInserted += makeHotelAvailabilityEntry(121, new Date(100, 7, 8), 5);
			rowsInserted += makeHotelAvailabilityEntry(121, new Date(100, 8, 1), 6);
			rowsInserted += makeHotelAvailabilityEntry(122, new Date(100, 6, 12), 9);
			rowsInserted += makeHotelAvailabilityEntry(122, new Date(100, 6, 28), 7);
			rowsInserted += makeHotelAvailabilityEntry(122, new Date(100, 7, 17), 7);
			rowsInserted += makeHotelAvailabilityEntry(123, new Date(100, 6, 20), 5);
			rowsInserted += makeHotelAvailabilityEntry(123, new Date(100, 7, 2), 7);
			rowsInserted += makeHotelAvailabilityEntry(123, new Date(100, 7, 22), 8);
			rowsInserted += makeHotelAvailabilityEntry(125, new Date(100, 6, 10), 6);
			rowsInserted += makeHotelAvailabilityEntry(125, new Date(100, 6, 28), 9);
			rowsInserted += makeHotelAvailabilityEntry(125, new Date(100, 7, 17), 5);
			rowsInserted += makeHotelAvailabilityEntry(125, new Date(100, 8, 1), 7);
			rowsInserted += makeHotelAvailabilityEntry(126, new Date(100, 6, 22), 7);
			rowsInserted += makeHotelAvailabilityEntry(126, new Date(100, 6, 30), 7);
			rowsInserted += makeHotelAvailabilityEntry(126, new Date(100, 7, 20), 6);
			rowsInserted += makeHotelAvailabilityEntry(127, new Date(100, 6, 2), 5);
			rowsInserted += makeHotelAvailabilityEntry(127, new Date(100, 6, 26), 7);
			rowsInserted += makeHotelAvailabilityEntry(127, new Date(100, 7, 2), 8);
			rowsInserted += makeHotelAvailabilityEntry(127, new Date(100, 7, 26), 6);
			rowsInserted += makeHotelAvailabilityEntry(128, new Date(100, 6, 8), 5);
			rowsInserted += makeHotelAvailabilityEntry(128, new Date(100, 6, 27), 5);
			rowsInserted += makeHotelAvailabilityEntry(128, new Date(100, 7, 11), 4);
			rowsInserted += makeHotelAvailabilityEntry(128, new Date(100, 7, 28), 6);
			rowsInserted += makeHotelAvailabilityEntry(135, new Date(100, 7, 2), 5);
			rowsInserted += makeHotelAvailabilityEntry(135, new Date(100, 7, 20), 5);
			rowsInserted += makeHotelAvailabilityEntry(136, new Date(100, 6, 2), 9);
			rowsInserted += makeHotelAvailabilityEntry(136, new Date(100, 7, 4), 8);
			rowsInserted += makeHotelAvailabilityEntry(136, new Date(100, 7, 26), 6);
			rowsInserted += makeHotelAvailabilityEntry(137, new Date(100, 6, 20), 5);
			rowsInserted += makeHotelAvailabilityEntry(137, new Date(100, 7, 8), 7);
			rowsInserted += makeHotelAvailabilityEntry(137, new Date(100, 7, 29), 8);
			rowsInserted += makeHotelAvailabilityEntry(138, new Date(100, 6, 26), 7);
			rowsInserted += makeHotelAvailabilityEntry(138, new Date(100, 7, 12), 5);
			rowsInserted += makeHotelAvailabilityEntry(150, new Date(100, 6, 10), 5);
			rowsInserted += makeHotelAvailabilityEntry(150, new Date(100, 6, 30), 5);
			rowsInserted += makeHotelAvailabilityEntry(150, new Date(100, 7, 26), 8);
			rowsInserted += makeHotelAvailabilityEntry(151, new Date(100, 6, 14), 6);
			rowsInserted += makeHotelAvailabilityEntry(151, new Date(100, 7, 2), 4);
			rowsInserted += makeHotelAvailabilityEntry(151, new Date(100, 7, 28), 5);
			rowsInserted += makeHotelAvailabilityEntry(152, new Date(100, 6, 18), 7);
			rowsInserted += makeHotelAvailabilityEntry(152, new Date(100, 7, 19), 5);
			rowsInserted += makeHotelAvailabilityEntry(152, new Date(100, 7, 31), 9);
			rowsInserted += makeHotelAvailabilityEntry(153, new Date(100, 6, 2), 8);
			rowsInserted += makeHotelAvailabilityEntry(153, new Date(100, 6, 26), 4);
			rowsInserted += makeHotelAvailabilityEntry(153, new Date(100, 7, 20), 6);
			rowsInserted += makeHotelAvailabilityEntry(153, new Date(100, 8, 3), 7);
			rowsInserted += makeHotelAvailabilityEntry(160, new Date(100, 6, 2), 7);
			rowsInserted += makeHotelAvailabilityEntry(160, new Date(100, 6, 18), 9);
			rowsInserted += makeHotelAvailabilityEntry(160, new Date(100, 7, 12), 8);
			rowsInserted += makeHotelAvailabilityEntry(160, new Date(100, 8, 1), 6);
			rowsInserted += makeHotelAvailabilityEntry(161, new Date(100, 6, 11), 7);
			rowsInserted += makeHotelAvailabilityEntry(161, new Date(100, 6, 22), 8);
			rowsInserted += makeHotelAvailabilityEntry(161, new Date(100, 7, 16), 7);
			rowsInserted += makeHotelAvailabilityEntry(162, new Date(100, 6, 12), 4);
			rowsInserted += makeHotelAvailabilityEntry(162, new Date(100, 7, 4), 6);
			rowsInserted += makeHotelAvailabilityEntry(162, new Date(100, 7, 17), 6);
			rowsInserted += makeHotelAvailabilityEntry(163, new Date(100, 6, 13), 5);
			rowsInserted += makeHotelAvailabilityEntry(163, new Date(100, 7, 8), 8);
			rowsInserted += makeHotelAvailabilityEntry(163, new Date(100, 7, 27), 6);
			rowsInserted += makeHotelAvailabilityEntry(180, new Date(100, 6, 24), 8);
			rowsInserted += makeHotelAvailabilityEntry(180, new Date(100, 7, 12), 6);
			rowsInserted += makeHotelAvailabilityEntry(180, new Date(100, 8, 1), 7);
			rowsInserted += makeHotelAvailabilityEntry(181, new Date(100, 6, 2), 9);
			rowsInserted += makeHotelAvailabilityEntry(181, new Date(100, 6, 29), 5);
			rowsInserted += makeHotelAvailabilityEntry(181, new Date(100, 7, 13), 4);
			rowsInserted += makeHotelAvailabilityEntry(182, new Date(100, 6, 8), 4);
			rowsInserted += makeHotelAvailabilityEntry(182, new Date(100, 7, 5), 8);
			rowsInserted += makeHotelAvailabilityEntry(182, new Date(100, 7, 14), 7);
			rowsInserted += makeHotelAvailabilityEntry(183, new Date(100, 6, 12), 5);
			rowsInserted += makeHotelAvailabilityEntry(183, new Date(100, 7, 10), 8);
			rowsInserted += makeHotelAvailabilityEntry(183, new Date(100, 7, 20), 6);
			rowsInserted += makeHotelAvailabilityEntry(210, new Date(100, 6, 8), 6);
			rowsInserted += makeHotelAvailabilityEntry(210, new Date(100, 6, 18), 7);
			rowsInserted += makeHotelAvailabilityEntry(210, new Date(100, 7, 4), 6);
			rowsInserted += makeHotelAvailabilityEntry(210, new Date(100, 7, 30), 5);
			rowsInserted += makeHotelAvailabilityEntry(211, new Date(100, 6, 2), 5);
			rowsInserted += makeHotelAvailabilityEntry(211, new Date(100, 6, 9), 9);
			rowsInserted += makeHotelAvailabilityEntry(211, new Date(100, 6, 26), 7);
			rowsInserted += makeHotelAvailabilityEntry(211, new Date(100, 7, 11), 7);
			rowsInserted += makeHotelAvailabilityEntry(211, new Date(100, 8, 1), 5);
			rowsInserted += makeHotelAvailabilityEntry(212, new Date(100, 6, 5), 8);
			rowsInserted += makeHotelAvailabilityEntry(212, new Date(100, 6, 11), 8);
			rowsInserted += makeHotelAvailabilityEntry(212, new Date(100, 6, 30), 6);
			rowsInserted += makeHotelAvailabilityEntry(212, new Date(100, 7, 16), 7);
			rowsInserted += makeHotelAvailabilityEntry(213, new Date(100, 6, 6), 6);
			rowsInserted += makeHotelAvailabilityEntry(213, new Date(100, 6, 14), 4);
			rowsInserted += makeHotelAvailabilityEntry(213, new Date(100, 7, 2), 5);
			rowsInserted += makeHotelAvailabilityEntry(213, new Date(100, 7, 20), 7);
			rowsInserted += makeHotelAvailabilityEntry(230, new Date(100, 6, 8), 7);
			rowsInserted += makeHotelAvailabilityEntry(230, new Date(100, 7, 4), 8);
			rowsInserted += makeHotelAvailabilityEntry(230, new Date(100, 7, 26), 6);
			rowsInserted += makeHotelAvailabilityEntry(231, new Date(100, 6, 13), 6);
			rowsInserted += makeHotelAvailabilityEntry(231, new Date(100, 7, 8), 6);
			rowsInserted += makeHotelAvailabilityEntry(231, new Date(100, 8, 4), 9);
			rowsInserted += makeHotelAvailabilityEntry(232, new Date(100, 6, 2), 4);
			rowsInserted += makeHotelAvailabilityEntry(232, new Date(100, 6, 26), 8);
			rowsInserted += makeHotelAvailabilityEntry(232, new Date(100, 7, 11), 7);
			rowsInserted += makeHotelAvailabilityEntry(233, new Date(100, 6, 5), 5);
			rowsInserted += makeHotelAvailabilityEntry(233, new Date(100, 6, 27), 8);
			rowsInserted += makeHotelAvailabilityEntry(233, new Date(100, 7, 16), 7);
			rowsInserted += makeHotelAvailabilityEntry(240, new Date(100, 6, 17), 8);
			rowsInserted += makeHotelAvailabilityEntry(240, new Date(100, 7, 2), 6);
			rowsInserted += makeHotelAvailabilityEntry(240, new Date(100, 7, 22), 8);
			rowsInserted += makeHotelAvailabilityEntry(241, new Date(100, 6, 18), 6);
			rowsInserted += makeHotelAvailabilityEntry(241, new Date(100, 7, 14), 5);
			rowsInserted += makeHotelAvailabilityEntry(241, new Date(100, 7, 23), 6);
			rowsInserted += makeHotelAvailabilityEntry(242, new Date(100, 6, 2), 7);
			rowsInserted += makeHotelAvailabilityEntry(242, new Date(100, 6, 21), 8);
			rowsInserted += makeHotelAvailabilityEntry(242, new Date(100, 7, 17), 8);
			rowsInserted += makeHotelAvailabilityEntry(243, new Date(100, 6, 14), 5);
			rowsInserted += makeHotelAvailabilityEntry(243, new Date(100, 6, 26), 4);
			rowsInserted += makeHotelAvailabilityEntry(243, new Date(100, 7, 20), 7);
			rowsInserted += makeHotelAvailabilityEntry(245, new Date(100, 6, 12), 9);
			rowsInserted += makeHotelAvailabilityEntry(246, new Date(100, 6, 22), 9);
			rowsInserted += makeHotelAvailabilityEntry(247, new Date(100, 6, 2), 8);
			rowsInserted += makeHotelAvailabilityEntry(247, new Date(100, 6, 29), 6);
			rowsInserted += makeHotelAvailabilityEntry(248, new Date(100, 6, 4), 7);
			rowsInserted += makeHotelAvailabilityEntry(248, new Date(100, 7, 5), 9);
			
			
			
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 2), 15, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 14), 7, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 17), 8, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 23), 15, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 24), 15, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 28), 13, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 6, 30), 16, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 7, 8), 6, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 7, 11), 10, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 7, 12), 9, 8, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 7, 20), 5, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 7, 28), 12, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 7, 29), 8, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1120", 1, new Date(100, 8, 4), 15, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 2), 7, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 8), 10, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 10), 18, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 16), 11, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 18), 15, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 19), 9, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 24), 18, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 27), 13, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 28), 8, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 6, 30), 7, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 7, 7), 17, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 7, 8), 6, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 7, 13), 10, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 7, 14), 13, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 7, 17), 12, 8, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1124", 1, new Date(100, 7, 20), 7, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 6, 2), 16, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 6, 5), 11, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 6, 14), 12, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 6, 20), 14, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 6, 26), 16, 8, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 6, 30), 5, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 7, 20), 12, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1126", 1, new Date(100, 7, 28), 14, 8, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 6, 2), 8, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 6, 18), 13, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 6, 20), 10, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 6, 24), 6, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 6, 26), 5, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 7, 12), 15, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 7, 20), 5, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 7, 28), 5, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 8, 1), 9, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1134", 1, new Date(100, 8, 2), 17, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 2), 14, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 4), 7, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 10), 9, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 12), 14, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 20), 7, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 27), 18, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 6, 30), 12, 6, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 7, 4), 4, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 7, 7), 11, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 7, 8), 10, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1137", 2, new Date(100, 7, 12), 14, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 2), 10, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 3), 14, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 10), 14, 5, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 19), 15, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 20), 7, 5, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 26), 12, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 6, 29), 6, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 7, 11), 14, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 7, 14), 17, 8, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 7, 20), 17, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 7, 23), 11, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 7, 26), 14, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 7, 28), 14, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 8, 1), 4, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1138", 1, new Date(100, 8, 4), 5, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 6, 2), 8, 8, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 6, 6), 6, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 6, 8), 18, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 6, 18), 17, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 6, 24), 11, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 7, 1), 7, 3, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 7, 4), 15, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 7, 8), 6, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1140", 1, new Date(100, 7, 10), 7, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 2), 13, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 5), 7, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 7), 17, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 11), 12, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 14), 14, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 17), 8, 5, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 22), 18, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 6, 30), 6, 8, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 7, 2), 17, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 7, 8), 18, 8, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 7, 12), 4, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 7, 20), 17, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 7, 23), 5, 6, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1141", 1, new Date(100, 7, 28), 14, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 6, 2), 6, 6, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 6, 10), 14, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 6, 14), 17, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 6, 28), 16, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 6, 30), 13, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 7, 2), 12, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 7, 8), 8, 8, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 7, 10), 8, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 7, 14), 11, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 7, 26), 11, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 8, 1), 17, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1143", 1, new Date(100, 8, 3), 16, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 2), 18, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 11), 13, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 17), 17, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 22), 9, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 26), 5, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 27), 17, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 6, 30), 16, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 4), 12, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 5), 5, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 8), 8, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 10), 9, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 20), 7, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 21), 8, 3, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 26), 6, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 7, 28), 16, 5, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1147", 1, new Date(100, 8, 1), 5, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 6, 2), 13, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 6, 13), 17, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 6, 24), 12, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 6, 26), 15, 8, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 6, 28), 14, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 7, 8), 17, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 7, 12), 14, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 7, 16), 14, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 7, 28), 5, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1150", 1, new Date(100, 8, 4), 10, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 2), 13, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 4), 15, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 8), 9, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 11), 9, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 12), 5, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 14), 17, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 15), 8, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 6, 29), 9, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 7, 2), 16, 3, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 7, 4), 12, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 7, 5), 7, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 7, 9), 8, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 7, 22), 5, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1151", 1, new Date(100, 7, 26), 12, 6, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 6, 2), 12, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 6, 9), 15, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 6, 13), 7, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 6, 20), 17, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 6, 26), 17, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 7, 5), 12, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 7, 17), 17, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 7, 18), 11, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 7, 20), 11, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1154", 1, new Date(100, 7, 28), 15, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 6, 2), 15, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 6, 10), 18, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 6, 20), 5, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 6, 22), 11, 3, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 6, 30), 9, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 8), 15, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 14), 10, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 16), 10, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 17), 12, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 20), 8, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 22), 11, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 26), 9, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1161", 1, new Date(100, 7, 27), 8, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 6, 2), 17, 6, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 6, 7), 5, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 6, 11), 7, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 6, 16), 17, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 6, 24), 18, 7, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 7, 10), 10, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 7, 14), 6, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 7, 27), 7, 3, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1169", 1, new Date(100, 8, 1), 14, 3, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 2), 13, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 10), 16, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 14), 16, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 16), 9, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 17), 8, 4, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 20), 14, 5, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 22), 15, 7, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 6, 27), 13, 5, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 8), 4, 8, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 10), 4, 4, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 16), 6, 6, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 17), 7, 5, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 20), 10, 4, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 26), 13, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 27), 6, 3, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 28), 16, 8, 5);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 7, 29), 16, 3, 4);
			rowsInserted += makeFlightAvailabilityEntry("AA1172", 1, new Date(100, 8, 2), 6, 7, 3);
			rowsInserted += makeFlightAvailabilityEntry("AA1178", 1, new Date(100, 6, 2), 18, 4, 4);
			
			
			
		}
		
		
		Util.println("Inserted " + (rowsInserted) + " rows into the FlightAvailability and HotelAvailability tables.");
		if (rowsInserted == maxrows)
			return true;
		else
			return false;
		
    }
	
	
	
	public boolean prepareStatements (Connection conn) throws SQLException {
		
		insert1 = conn.prepareStatement(insertString1);
		insert2 = conn.prepareStatement(insertString2);
		
		if (insert1 != null && insert2 != null)
			return true;
		return false;
		
		
	}
	
	
	
	
	public int makeFlightAvailabilityEntry(String a, int b, Date c, int d, int e, int f) throws SQLException { 
		
		insert1.setString(1, a);
		insert1.setInt(2, b); 
		insert1.setDate(3, c);
		insert1.setInt(4, d);
		insert1.setInt(5, e);
		insert1.setInt(6, f);
		
		
		return insert1.executeUpdate();
		
	}
	
	public int makeHotelAvailabilityEntry(int a, Date b, int c) throws SQLException {
		
		insert2.setInt(1, a);
		insert2.setDate(2, b);
		insert2.setInt(3, c);
		
		return insert2.executeUpdate();
		
	}
	
	public void confirmInsert(Connection conn) throws SQLException {
        int count = 0;
        Statement s = conn.createStatement();
		
        Util.println("Show all the FlightAvailability and HotelAvailability data inserted: ");
		
        ResultSet rs = s.executeQuery("SELECT flight_id, segment_number, flight_date FROM FlightAvailability");
        while (rs.next()) {
			
			Util.println(rs.getString(1) + ", segment number " + rs.getInt(2) + ", booking_date " + rs.getDate(3));
			count++;
        }
        rs.close();
		
		
		
        Util.println();
        Util.println(count + " records retrieved from FlightAvailabilty table");
        Util.println();
        count = 0;
		
		
        rs = s.executeQuery("SELECT hotel_id, booking_date FROM HotelAvailability");
        while (rs.next()) {
			
			Util.println(rs.getInt(1) + ",  " + rs.getDate(2));
			count++;
        }
        rs.close();
		
		
        Util.println();
        Util.println(count + " records retrieved from HotelAvailabilty table");
        Util.println();
		
        s.close();
		
		
	}
	
	public void extractDataForReInsert(Connection conn) throws SQLException {
		
		Statement s = conn.createStatement();
		ResultSet rs = s.executeQuery(
									  "select hotel_id, booking_date, rooms_taken from hotelavailability");
		while (rs.next()) {
			
			Util.println("rowsInserted += makeHotelAvailabilityEntry(" +
						 Util.wrapIntWithComma(rs.getInt(1)) +
						 "java.sql.Date.valueOf(" +
						 Util.wrapAsString(rs.getDate(2).toString()) +
						 "), " + 
						 rs.getInt(3) +
						 ");");
		}
		
		rs.close();
		
		rs = s.executeQuery("SELECT flight_id, segment_number, flight_date, economy_seats_taken, business_seats_taken, firstclass_seats_taken FROM FlightAvailability");
		while (rs.next()) {
			
			Util.println("rowsInserted += makeFlightAvailabilityEntry("+
						 Util.wrapAsStringWithComma(rs.getString(1)) +
						 Util.wrapIntWithComma(rs.getInt(2)) +
						 "java.sql.Date.valueOf(" +
						 Util.wrapAsString(rs.getDate(3).toString()) +
						 "), " + Util.wrapIntWithComma(rs.getInt(4)) +
						 Util.wrapIntWithComma(rs.getInt(5)) +
						 rs.getInt(6) + 
						 ");");
		}
		rs.close();
		
		
		
	}
	
	public boolean createSQLScript(Connection conn) throws SQLException {
		
		Statement s = conn.createStatement();
		ResultSet rs = s.executeQuery(
									  "select hotel_id, booking_date, rooms_taken from hotelavailability");
		while (rs.next()) {
			
			Util.println("INSERT INTO HOTELAVAILABILITY VALUES (" +
                         Util.wrapIntWithComma(rs.getInt(1)) +
						 Util.wrapAsSQLDateWithComma(rs.getDate(2)) +
                         rs.getInt(3) +
						 ");");
		}
		
		rs.close();
		
		rs = s.executeQuery("SELECT flight_id, segment_number, flight_date, economy_seats_taken, business_seats_taken, firstclass_seats_taken FROM FlightAvailability");
		while (rs.next()) {
			
			
			Util.println("INSERT INTO FLIGHTAVAILABILITY VALUES (" +
						 Util.wrapAsStringWithCommaSQ(rs.getString(1)) +
						 Util.wrapIntWithComma(rs.getInt(2)) +
						 Util.wrapAsSQLDateWithComma(rs.getDate(3)) +
						 Util.wrapIntWithComma(rs.getInt(4)) +
						 Util.wrapIntWithComma(rs.getInt(5)) +
						 rs.getInt(6) + 
						 ");");
		}
		rs.close();
		
		
		
		return insertableAsSQL;
	}
	
	
	private static int getNextOnClock(int max, int current) {
		if (current < max)
			return current+1;
		else
			return 0;
		
	}
	
	
	
}








