package JBMSTours.inserters;

import java.sql.*;
import JBMSTours.serializabletypes.City;
import JBMSTours.serializabletypes.Location;
import JBMSTours.serializabletypes.TimeZone;
import JBMSTours.Util;
import java.util.Calendar;
import java.util.GregorianCalendar;
/**
 * Look at the <a href="../JBMSTours/InsertCities.java">Source</a>.<p>
 * Basic "inserter" class for City objects.
 * Initializes an array of City objects before inserting them.
 * Note: the location and weather information is not guaranteed to be accurate.
 *
 */
public class InsertCities implements Inserters {


    private PreparedStatement insert;
    private String insertString;
    private int rowsInserted;
    public static int NUMCITIES = 87;
    private boolean insertableAsSQL = false;
    public City[] theCities;    
    public InsertCities() {

		insertString = 
            "INSERT INTO Cities VALUES(?, ?, ?)";
		
        theCities = new City[NUMCITIES];
		
		theCities[0] = new City(1, "Amsterdam", "Dutch", "NL", "AMS");
		theCities[0].setLocation(52, 21, "N", 4, 55, "E");
		theCities[0].setTemperatures(40, 52, 69, 56);
		theCities[0].setTimeZone(1, 2, "LSM", "LSO");
	   
        theCities[1] = new City(2, "Athens", "Greek", "GR", "ATH");
        theCities[1].setLocation(37, 59, "N", 23, 44, "E");
        theCities[1].setTemperatures(40, 52, 69, 56);
        theCities[1].setTimeZone(2, 3, "LSM", "LSO");

        theCities[2] = new City(3, "Auckland", "English", "NZ", "AKL");
        theCities[2].setLocation(36, 52, "S", 174, 46, "E");
        theCities[2].setTemperatures(73, 67, 56, 63);
        theCities[2].setTimeZone(12, 13, "FSO", "SSM");


        theCities[3] = new City(4, "Beirut", "Arabic", "LB", "BEY");
        theCities[3].setLocation(33, 53, "N", 35, 30, "E");
        theCities[3].setTemperatures(62, 72, 87, 81);
        theCities[3].setTimeZone(2, 3, "FSM", "TSO");

        theCities[4] = new City(5, "Bogota", "Spanish", "CO", "BOG");
        theCities[4].setLocation(4, 36, "N", 74, 5, "W");
        theCities[4].setTemperatures(67, 67, 64, 66);
        theCities[4].setTimeZone(-5);

        theCities[5] = new City(6, "Bombay", "Hindi", "IN", "BOM");
        theCities[5].setLocation(18, 58, "N", 72, 50, "E");
        theCities[5].setTemperatures(88, 93, 88, 93);
        theCities[5].setTimeZone(5.5);


        theCities[6] = new City(7, "Budapest", "Hungarian", "HU", "BUD");
        theCities[6].setLocation(47, 30, "N", 19, 5, "E");
        theCities[6].setTemperatures(35, 62, 82, 61);
        theCities[6].setTimeZone(1, 2, "LSM", "LSO");


        theCities[7] = new City(8, "Buenos Aires", "Spanish", "AR", "BUE");
        theCities[7].setLocation(34, 36, "S", 58, 27, "W");
        theCities[7].setTemperatures(67, 67, 64, 66);
        theCities[7].setTimeZone(-3, -2, "LSO", "FSM");


        theCities[8] = new City(9, "Cairo", "Arabic", "EG", "CAI");
        theCities[8].setLocation(30, 3, "N", 31, 15, "E");
        theCities[8].setTemperatures(65, 83, 96, 86);
        theCities[8].setTimeZone(2, 3, "FFM", "LWS");


        theCities[9] = new City(10, "Calcutta", "Bengali", "IN", "CCU");
        theCities[9].setLocation(22, 32, "N", 88, 22, "E");
        theCities[9].setTemperatures(80, 97, 90, 89);
        theCities[9].setTimeZone(5.5);

        theCities[10] = new City(11, "Cape Town", "English", "ZA", "CPT");
        theCities[10].setLocation(33, 55, "S", 18, 25, "E");
        theCities[10].setTemperatures(78, 72, 63, 70);
        theCities[10].setTimeZone(2);

        theCities[11] = new City(12, "Caracas", "Spanish", "VE", "CCS");
        theCities[11].setLocation(10, 30, "N", 66, 55, "W");
        theCities[11].setTemperatures(75, 81, 78, 79);
        theCities[11].setTimeZone(-4);

        theCities[12] = new City(13, "Casablanca", "Arabic", "MA", "CAS");
        theCities[12].setLocation(33, 35, "N", 7, 35, "W");
        theCities[12].setTemperatures(63, 69, 79, 76);
        theCities[12].setTimeZone(0);

        theCities[13] = new City(14, "Copenhagen", "Danish", "DK", "CPH");
        theCities[13].setLocation(55, 40, "N", 12, 35, "E");
        theCities[13].setTemperatures(36, 50, 72, 53);
        theCities[13].setTimeZone(1, 2, "LSM", "LSO");

        theCities[14] = new City(15, "Dublin", "English", "IE", "DUB");
        theCities[14].setLocation(53, 20, "N", 6, 15, "W");
        theCities[14].setTemperatures(47, 54, 67, 57);
        theCities[14].setTimeZone(0, 1, "LSM", "LSO");

        theCities[15] = new City(16, "Geneva", "French", "CH", "GVA");
        theCities[15].setLocation(46, 12, "N", 6, 10, "E");
        theCities[15].setTemperatures(39, 58, 77, 58);
        theCities[15].setTimeZone(1, 2, "LSM", "LSO");

        theCities[16] = new City(17, "Hong Kong", "Chinese", "CN", "HKG");
        theCities[16].setLocation(22, 15, "N", 114, 10, "E");
        theCities[16].setTemperatures(64, 75, 87, 81);
        theCities[16].setTimeZone(8);

        theCities[17] = new City(18, "Istanbul", "Turkish", "TR", "IST");
        theCities[17].setLocation(41, 1, "N", 28, 58, "E");
        theCities[17].setTemperatures(45, 61, 81, 67);
        theCities[17].setTimeZone(2, 3, "LSM", "LSO");

        theCities[18] = new City(19, "Jakarta", "Indonesian", "ID", "JKT");
        theCities[18].setLocation(6, 10, "S", 106, 48, "E");
        theCities[18].setTemperatures(84, 87, 87, 87);
        theCities[18].setTimeZone(7);

        theCities[19] = new City(20, "Kabul", "Pashto", "AF", "KBL");
        theCities[19].setLocation(34, 31, "N", 69, 12, "E");
        theCities[19].setTemperatures(36, 66, 92, 73);
        theCities[19].setTimeZone(5);

        theCities[20] = new City(21, "Karachi", "Punjabi", "PK", "KHI");
        theCities[20].setLocation(24, 52, "N", 67, 3, "E");
        theCities[20].setTemperatures(77, 90, 91, 91);
        theCities[20].setTimeZone(5);

        theCities[21] = new City(22, "Lagos", "English", "NG", "LOS");
        theCities[21].setLocation(6, 27, "N", 3, 23, "E");
        theCities[21].setTemperatures(88, 89, 83, 85);
        theCities[21].setTimeZone(1);

        theCities[22] = new City(23, "Lima", "Spanish", "PE", "LIM");
        theCities[22].setLocation(12, 3, "S", 77, 3, "W");
        theCities[22].setTemperatures(82, 80, 67, 71);
        theCities[22].setTimeZone(-5);

        theCities[23] = new City(24, "Lisbon", "Portuguese", "PT", "LIS");
        theCities[23].setLocation(38, 43, "N", 9, 8, "W");
        theCities[23].setTemperatures(56, 64, 79, 69);
        theCities[23].setTimeZone(0, 1, "LSM", "LSO");

        theCities[24] = new City(25, "London", "English", "GB", "LHR");
        theCities[24].setLocation(51, 30, "N", 0, 7, "W");
        theCities[24].setTemperatures(44, 56, 73, 58);
        theCities[24].setTimeZone(0, 1, "LSM", "LSO");

        theCities[25] = new City(26, "Madrid", "Spanish", "ES", "MAD");
        theCities[25].setLocation(40, 24, "N", 3, 41, "W");
        theCities[25].setTemperatures(47, 64, 87, 66);
        theCities[25].setTimeZone(1, 2, "LSM", "LSO");


        theCities[26] = new City(27, "Manila", "Tagalog", "PH", "MNL");
        theCities[26].setLocation(14, 35, "N", 121, 0, "E");
        theCities[26].setTemperatures(86, 93, 88, 88);
        theCities[26].setTimeZone(8);

        theCities[27] = new City(28, "Melbourne", "English", "AU", "MEL");
        theCities[27].setLocation(37, 50, "S", 145, 0, "E");
        theCities[27].setTemperatures(78, 68, 56, 67);
        theCities[27].setTimeZone(10, 11, "LSO", "TSM");

        theCities[28] = new City(29, "Mexico City", "Spanish", "MX", "MEX");
        theCities[28].setLocation(19, 24, "N", 99, 9, "W");
        theCities[28].setTemperatures(66, 78, 74, 70);
        theCities[28].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[29] = new City(30, "Montreal", "French", "CA", "YUL");
        theCities[29].setLocation(45, 30, "N", 73, 36, "W");
        theCities[29].setTemperatures(21, 50, 78, 54);
        theCities[29].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[30] = new City(31, "Moscow", "Russian", "RU", "SVO");
        theCities[30].setLocation(55, 45, "N", 37, 35, "E");
        theCities[30].setTemperatures(21, 47, 76, 46);
        theCities[30].setTimeZone(3, 4, "LSM", "LSS");

        theCities[31] = new City(32, "Nairobi", "English", "KE", "NBO");
        theCities[31].setLocation(1, 17, "S", 36, 49, "E");
        theCities[31].setTemperatures(77, 75, 69, 76);
        theCities[31].setTimeZone(3);

        theCities[32] = new City(33, "Osaka", "Japanese", "JP", "OSA");
        theCities[32].setLocation(34, 40, "N", 135, 30, "E");
        theCities[32].setTemperatures(47, 65, 87, 72);
        theCities[32].setTimeZone(9);

        theCities[33] = new City(34, "Oslo", "Norwegian", "NO", "OSL");
        theCities[33].setLocation(59, 55, "N", 10, 45, "E");
        theCities[33].setTemperatures(30, 50, 73, 49);
        theCities[33].setTimeZone(1, 2, "LSM", "LSO");

        theCities[34] = new City(35, "Paris", "French", "FR", "CDG");
        theCities[34].setLocation(48, 52, "N", 2, 20, "E");
        theCities[34].setTemperatures(42, 60, 76, 59);
        theCities[34].setTimeZone(1, 2, "LSM", "LSO");

        theCities[35] = new City(36, "Prague", "Czech", "CZ", "PRG");
        theCities[35].setLocation(50, 5, "N", 14, 28, "E");
        theCities[35].setTemperatures(34, 55, 74, 54);
        theCities[35].setTimeZone(1, 2, "LSM", "LSO");

        theCities[36] = new City(37, "Reykjavik", "Icelandic", "IS", "REY");
        theCities[36].setLocation(64, 9, "N", 21, 57, "W");
        theCities[36].setTemperatures(35, 42, 60, 42);
        theCities[36].setTimeZone(0);

        theCities[37] = new City(38, "Rio de Janeiro", "Portuguese", "BR", "GIG");
        theCities[37].setLocation(22, 59, "S", 43, 14, "W");
        theCities[37].setTemperatures(84, 80, 75, 77);
        theCities[37].setTimeZone(-3, -2, "SSO", "SSF");

        theCities[38] = new City(39, "Rome", "Italian", "IT", "FCO");
        theCities[38].setLocation(41, 54, "N", 12, 29, "E");
        theCities[38].setTemperatures(54, 68, 88, 73);
        theCities[38].setTimeZone(1, 2, "LSM", "LSO");

        theCities[39] = new City(40, "Santiago", "Spanish", "CL", "SCL");
        theCities[39].setLocation(33, 27, "S", 70, 40, "W");
        theCities[39].setTemperatures(85, 74, 59, 72);
        theCities[39].setTimeZone(-4, -3, "SSO", "SSM");

        theCities[40] = new City(41, "Sao Paulo", "Portuguese", "BR", "GRU");
        theCities[40].setLocation(23, 32, "S", 46, 37, "W");
        theCities[40].setTemperatures(77, 73, 66, 68);
        theCities[40].setTimeZone(-3, -2, "SSO", "SSF");


        theCities[41] = new City(42, "Seoul", "Korean", "KR", "SEL");
        theCities[41].setLocation(37, 34, "N", 127, 0, "E");
        theCities[41].setTemperatures(32, 62, 84, 67);
        theCities[41].setTimeZone(9);

        theCities[42] = new City(43, "Shanghai", "Chinese", "CN", "SHA");
        theCities[42].setLocation(31, 7, "N", 121, 22, "E");
        theCities[42].setTemperatures(47, 67, 91, 75);
        theCities[42].setTimeZone(8, 9, "SSA", "TSS");

        theCities[43] = new City(44, "Singapore", "Malay", "SG", "SIN");
        theCities[43].setLocation(1, 17, "N", 103, 51, "E");
        theCities[43].setTemperatures(86, 88, 88, 87);
        theCities[43].setTimeZone(8);

        theCities[44] = new City(45, "Stockholm", "Swedish", "SE", "ARN");
        theCities[44].setLocation(49, 20, "N", 18, 3, "E");
        theCities[44].setTemperatures(31, 45, 70, 48);
        theCities[44].setTimeZone(1, 2, "LSM", "LSO");

        theCities[45] = new City(46, "Sydney", "English",  "AU", "SYD");
        theCities[45].setLocation(33, 53, "S", 151, 12, "E");
        theCities[45].setTemperatures(78, 71, 60, 71);
        theCities[45].setTimeZone(10, 11, "LSO", "TSM");

        theCities[46] = new City(47, "Taipei", "Chinese", "TW", "TPE");
        theCities[46].setLocation(25, 3, "N", 121, 30, "E");
        theCities[46].setTemperatures(66, 77, 92, 80);
        theCities[46].setTimeZone(8);

        theCities[47] = new City(48, "Tehran", "Farsi", "IR", "THR");
        theCities[47].setLocation(35, 40, "N", 51, 26, "E");
        theCities[47].setTemperatures(45, 71, 99, 76);
        theCities[47].setTimeZone(3.5);

        theCities[48] = new City(49, "Tokyo", "Japanese", "JP", "NRT");
        theCities[48].setLocation(35, 42, "N", 139, 46, "E");
        theCities[48].setTemperatures(47, 63, 83, 69);
        theCities[48].setTimeZone(9);

        theCities[49] = new City(50, "Toronto", "English", "CA", "YYZ");
        theCities[49].setLocation(43, 40, "N", 79, 23, "W");
        theCities[49].setTemperatures(30, 50, 79, 56);
        theCities[49].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[50] = new City(51, "Warsaw", "Polish", "PL", "WAW");
        theCities[50].setLocation(52, 15, "N", 21, 0, "E");
        theCities[50].setTemperatures(30, 54, 75, 54);
        theCities[50].setTimeZone(1, 2, "LSM", "LSO");

        theCities[51] = new City(52, "Albany", "English", "US", "ALB");
        theCities[51].setLocation(42, 39, "N", 73, 45, "W");
        theCities[51].setTemperatures(21, 24, 34, 46, 58, 67, 72, 70, 61, 50, 40, 27);
        theCities[51].setTimeZone(-5, -6, "FSA", "LSO");

        theCities[52] = new City(53, "Albuquerque", "English", "US", "ABQ");
        theCities[52].setLocation(35, 5, "N", 106, 39, "W");
        theCities[52].setTemperatures(34, 40, 47, 55, 64, 74, 79, 76, 69, 57, 44, 35);
        theCities[52].setTimeZone(-7, -6, "FSA", "LSO");

        theCities[53] = new City(54, "Atlanta", "English", "US", "ATL");
        theCities[53].setLocation(33, 45, "N", 84, 23, "W");
        theCities[53].setTemperatures(41, 45, 54, 62, 69, 76, 79, 78, 73, 62, 53, 45);
        theCities[53].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[54] = new City(55, "Boise", "English", "US", "BOI");
        theCities[54].setLocation(43, 37, "N", 116, 13, "W");
        theCities[54].setTemperatures(29, 36, 43, 49, 58, 67, 74, 73, 63, 52, 40, 30);
        theCities[54].setTimeZone(-7, -6, "FSA", "LSO");

        theCities[55] = new City(56, "Boston", "English", "US", "BOS");
        theCities[55].setLocation(42, 22, "N", 71, 3, "W");
        theCities[55].setTemperatures(29, 30, 39, 48, 58, 68, 74, 72, 65, 55, 45, 34);
        theCities[55].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[56] = new City(57, "Charleston", "English", "US", "CHS");
        theCities[56].setLocation(32, 46, "N", 79, 56, "W");
        theCities[56].setTemperatures(48, 51, 58, 65, 73, 78, 82, 81, 76, 67, 58, 51);
        theCities[56].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[57] = new City(58, "Chicago", "English", "US", "MDW");
        theCities[57].setLocation(41, 50, "N", 87, 41, "W");
        theCities[57].setTemperatures(21, 25, 37, 49, 59, 69, 73, 72, 64, 53, 40, 27);
        theCities[57].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[58] = new City(59, "Cleveland", "English", "US", "CLE");
        theCities[58].setLocation(41, 30, "N", 81, 42, "W");
        theCities[58].setTemperatures(25, 27, 37, 48, 58, 68, 72, 70, 64, 53, 43, 31);
        theCities[58].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[59] = new City(60, "Dallas", "English", "US", "DFW");
        theCities[59].setLocation(32, 47, "N", 96, 49, "W");
        theCities[59].setTemperatures(43, 48, 57, 66, 73, 81, 85, 85, 77, 67, 56, 47);
        theCities[59].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[60] = new City(61, "Denver", "English", "US", "DEN");
        theCities[60].setLocation(39, 44, "N", 104, 59, "W");
        theCities[60].setTemperatures(30, 33, 39, 48, 57, 67, 74, 71, 62, 51, 39, 31);
        theCities[60].setTimeZone(-7, -6, "FSA", "LSO");

        theCities[61] = new City(62, "Des Moines", "English", "US", "DSM");
        theCities[61].setLocation(41, 35, "N", 93, 37, "W");
        theCities[61].setTemperatures(19, 25, 37, 51, 62, 72, 77, 74, 65, 54, 39, 24);
        theCities[61].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[62] = new City(63, "Fairbanks", "English", "US", "FAI");
        theCities[62].setLocation(64, 51, "N", 147, 43, "W");
        theCities[62].setTemperatures(-10, -4, 11, 31, 49, 60, 63, 57, 46, 25, 3, -7);
        theCities[62].setTimeZone(-9, -8, "FSA", "LSO");


        theCities[63] = new City(64, "Helena", "English", "US", "HLN");
        theCities[63].setLocation(46, 36, "N", 112, 2, "W");
        theCities[63].setTemperatures(20, 26, 34, 43, 53, 62, 69, 67, 55, 45, 32, 21);
        theCities[63].setTimeZone(-7, -6, "FSA", "LSO");

        theCities[64] = new City(65, "Honolulu", "English", "US", "HNL");
        theCities[64].setLocation(21, 19, "N", 157, 52, "W");
        theCities[64].setTemperatures(73, 73, 74, 76, 78, 79, 81, 81, 81, 80, 77, 74);
        theCities[64].setTimeZone(-10, -9, "FSA", "LSO");

        theCities[65] = new City(66, "Houston", "English", "US", "HOU");
        theCities[65].setLocation(29, 46, "N", 95, 22, "W");
        theCities[65].setTemperatures(50, 54, 61, 68, 75, 80, 83, 82, 78, 70, 61, 54);
        theCities[65].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[66] = new City(67, "Juneau", "English", "US", "JNU");
        theCities[66].setLocation(58, 18, "N", 134, 24, "W");
        theCities[66].setTemperatures(24, 28, 33, 40, 47, 53, 56, 55, 49, 42, 32, 27);
        theCities[66].setTimeZone(-9, -8, "FSA", "LSO");

        theCities[67] = new City(68, "Kansas City", "English", "US", "MCI");
        theCities[67].setLocation(39, 6, "N", 94, 35, "W");
        theCities[67].setTemperatures(26, 31, 43, 55, 64, 73, 79, 76, 68, 57, 43, 30);
        theCities[67].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[68] = new City(69, "Los Angeles", "English", "US", "LAX");
        theCities[68].setLocation(34, 3, "N", 118, 15, "W");
        theCities[68].setTemperatures(58, 60, 61, 63, 66, 70, 74, 75, 74, 70, 63, 58);
        theCities[68].setTimeZone(-8, -7, "FSA", "LSO");

        theCities[69] = new City(70, "Memphis", "English", "US", "MEM");
        theCities[69].setLocation(35, 8, "N", 90, 3, "W");
        theCities[69].setTemperatures(40, 44, 53, 63, 71, 79, 83, 81, 74, 63, 53, 44);
        theCities[69].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[70] = new City(71, "Miami", "English", "US", "MIA");
        theCities[70].setLocation(25, 47, "N", 80, 14, "W");
        theCities[70].setTemperatures(67, 69, 72, 75, 79, 81, 83, 83, 82, 78, 74, 69);
        theCities[70].setTimeZone(-5, -4, "FSA", "LSO");

		
        theCities[71] = new City(72, "Milwaukee", "English", "US", "MKE");
        theCities[71].setLocation(43, 2, "N", 87, 55, "W");
        theCities[71].setTemperatures(19, 23, 33, 44, 55, 65, 71, 69, 62, 50, 38, 24);
        theCities[71].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[72] = new City(73, "Minneapolis", "English", "US", "MSP");
        theCities[72].setLocation(44, 57, "N", 87, 55, "W");
        theCities[72].setTemperatures(12, 18, 31, 46, 59, 68, 74, 71, 61, 49, 33, 18);
        theCities[72].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[73] = new City(74, "Nashville", "English", "US", "BNA");
        theCities[73].setLocation(36, 10, "N", 86, 47, "W");
        theCities[73].setTemperatures(36, 40, 50, 59, 68, 76, 79, 78, 72, 60, 50, 41);
        theCities[73].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[74] = new City(75, "New Orleans", "English", "US", "MSY");
        theCities[74].setLocation(29, 58, "N", 90, 4, "W");
        theCities[74].setTemperatures(51, 54, 62, 69, 75, 80, 82, 82, 78, 69, 61, 55);
        theCities[74].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[75] = new City(76, "New York", "English", "US", "JFK");
        theCities[75].setLocation(40, 42, "N", 74, 0, "W");
        theCities[75].setTemperatures(32, 34, 42, 53, 63, 72, 77, 76, 68, 58, 48, 37);
        theCities[75].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[76] = new City(77, "Oklahoma City", "English", "US", "OKC");
        theCities[76].setLocation(35, 30, "N", 97, 30, "W");
        theCities[76].setTemperatures(36, 41, 50, 60, 68, 77, 82, 81, 73, 62, 50, 39);
        theCities[76].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[77] = new City(78, "Philadelphia", "English", "US", "PHL");
        theCities[77].setLocation(39, 57, "N", 75, 10, "W");
        theCities[77].setTemperatures(30, 33, 42, 52, 63, 72, 77, 76, 68, 56, 46, 36);
        theCities[77].setTimeZone(-5, -4, "FSA", "LSO");

        theCities[78] = new City(79, "Phoenix", "English", "US", "PHX");
        theCities[78].setLocation(33, 27, "N", 112, 4, "W");
        theCities[78].setTemperatures(54, 58, 62, 70, 79, 88, 94, 92, 86, 75, 62, 54);
        theCities[78].setTimeZone(-7);

        theCities[79] = new City(80, "Saint Louis", "English", "US", "STL");
        theCities[79].setLocation(38, 37, "N", 90, 12, "W");
        theCities[79].setTemperatures(29, 34, 45, 57, 66, 75, 80, 78, 70, 58, 46, 34);
        theCities[79].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[80] = new City(81, "Salt Lake City", "English", "US", "SLC");
        theCities[80].setLocation(40, 45, "N", 111, 53, "W");
        theCities[80].setTemperatures(28, 34, 42, 50, 59, 69, 78, 76, 65, 53, 41, 30);
        theCities[80].setTimeZone(-7, -6, "FSA", "LSO");

        theCities[81] = new City(82, "San Antonio", "English", "US", "SAT");
        theCities[81].setLocation(29, 25, "N", 98, 30, "W");
        theCities[81].setTemperatures(49, 54, 62, 69, 76, 82, 85, 85, 79, 70, 60, 52);
        theCities[81].setTimeZone(-6, -5, "FSA", "LSO");

        theCities[82] = new City(83, "San Diego", "English", "US", "SAN");
        theCities[82].setLocation(32, 43, "N", 117, 9, "W");
        theCities[82].setTemperatures(57, 59, 60, 62, 64, 67, 71, 73, 71, 68, 62, 57);
        theCities[82].setTimeZone(-8, -7, "FSA", "LSO");

        theCities[83] = new City(84, "San Francisco", "English", "US", "SFO");
        theCities[83].setLocation(37, 47, "N", 122, 25, "W");
        theCities[83].setTemperatures(49, 52, 53, 56, 58, 62, 63, 64, 65, 61, 55, 49);
        theCities[83].setTimeZone(-8, -7, "FSA", "LSO");

        theCities[84] = new City(85, "San Juan", "Spanish", "US", "SJU");
        theCities[84].setLocation(18, 28, "N", 66, 7, "W");
        theCities[84].setTemperatures(77, 77, 78, 79, 81, 82, 83, 83, 82, 82, 80, 78);
        theCities[84].setTimeZone(-4);

        theCities[85] = new City(86, "Seattle", "English", "US", "SEA");
        theCities[85].setLocation(47, 36, "N", 122, 20, "W");
        theCities[85].setTemperatures(41, 44, 47, 50, 56, 61, 65, 66, 61, 54, 46, 42);
        theCities[85].setTimeZone(-8, -7, "FSA", "LSO");


        theCities[86] = new City(87, "Washington, DC", "English", "US", "IAD");
        theCities[86].setLocation(38, 54, "N", 72, 2, "W");
        theCities[86].setTemperatures(31, 34, 43, 53, 62, 71, 76, 74, 67, 55, 45, 35);
        theCities[86].setTimeZone(-5, -4, "FSA", "LSO");
    }

    /**
     * Inserter method inserts the cities in the array 
     * using one PreparedStatement executed many times.
     *
     * @param     conn       Connection 
     *
     * @return    boolean    true if number of cities inserted is correct.
     *
     * @exception SQLException  Thrown if there is a SQL error.
     *
     */


    public boolean insert (Connection conn) throws SQLException {

     if (!prepareStatements(conn))
	return false;
 
 
        /*
         * for each city object, we want to set one 
         * remaining field, which we get from the country table
         */

        PreparedStatement ptstmt = conn.prepareStatement(
            "SELECT country FROM Countries WHERE country_ISO_code = ?");

        for (int i = 0; i < NUMCITIES; i++) {

            theCities[i].setDisplayCountry(conn, ptstmt);  
            rowsInserted += makeEntry(theCities[i].city_id, theCities[i], theCities[i].getCountryCode());

	}

        
	Util.println("");
        Util.println(rowsInserted + " rows inserted into CITIES table");
        Util.println("");
	insert.close();

        if (rowsInserted == NUMCITIES) 
            return true;
        else 
	  return false;


    }

  public boolean prepareStatements(Connection conn) throws SQLException {
        insert = conn.prepareStatement(insertString);
	if (insert != null)
	  return true;
	return false;

  }


    private int makeEntry(int a, City b, String c) throws SQLException {
   
        insert.setInt(1, a);
        insert.setObject(2, b);
        insert.setString(3, c);
        int n = insert.executeUpdate();
        return n;
    }  



    /**
     * Shows data inserted to verify. Uses a method invocation to show the city names.
     * query is: <em>select city.getName() from Cities</em>
     *
     * @param     conn       Connection 
     *
     * @exception SQLException  Thrown if there is a SQL error.
     *
     */
    public void confirmInsert (Connection conn) throws SQLException {
        Statement s = conn.createStatement();
        ResultSet rs = s.executeQuery("select city.getName() from Cities");
        while (rs.next()) {
            Util.println(rs.getString(1) + " inserted ");
        }
        Util.println("");
        rs.close();
        s.close();

		// if we're in test mode, test the time zones
        Long testDate = Long.getLong("JBMSTours.testDate");
        if (testDate != null) {
		String dbn = System.getProperty("JBMSTours.dbName");
		if (dbn == null)
			testTimeZones(conn);
		}
		

    }

    public void extractDataForReInsert (Connection conn) throws SQLException {

        Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery("SELECT city_id, city, country_ISO_code from Cities");
        City tempcity;
		Location templocation;
		TimeZone temptimezone;
		double temptemps[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

        while (rs.next()) {
			tempcity = (City) rs.getObject(2);
            templocation = tempcity.getLocation();
			temptimezone = tempcity.getTimeZone();
			temptemps = tempcity.averageTemperature;
			
			Util.println("tempcity = new City(" +
						 Util.wrapIntWithComma(rs.getInt(1)) +
						 Util.wrapAsStringWithComma(tempcity.getName()) +
						 Util.wrapAsStringWithComma(tempcity.getLanguage()) +
						 Util.wrapAsStringWithComma(rs.getString(2))+ 
						 Util.wrapAsString(tempcity.getAirport()) +
						 ");");
			
			Util.println("tempcity.setLocation(" +
						 Util.wrapIntWithComma(templocation.getLatitudeDegrees()) +
						 Util.wrapIntWithComma(templocation.getLatitudeMinutes()) +
						 Util.wrapAsStringWithComma(templocation.getLatitudeDir()) +
						 Util.wrapIntWithComma(templocation.getLongitudeDegrees()) +
						 Util.wrapIntWithComma(templocation.getLongitudeMinutes()) +
						 Util.wrapAsString(templocation.getLongitudeDir()) +
						 ");");
			Util.println("tempcity.setTemperatures(" +
						 temptemps[0] + ", " +
						 temptemps[1] + ", " +
						 temptemps[2] + ", " +
						 temptemps[3] + ", " +
						 temptemps[4] + ", " +
						 temptemps[5] + ", " +
						 temptemps[6] + ", " +
						 temptemps[7] + ", " +
						 temptemps[8] + ", " +
						 temptemps[9] + ", " +
						 temptemps[10] + ", " +
						 temptemps[11] + ", " +
						 Util.wrapAsString("C") +
						 ");");
			Util.println("tempcity.setTimeZone(" +
						 temptimezone.getGMTOffset() + ", " +
						 temptimezone.getDSTGMTOffset() + ", " +
						 Util.wrapAsStringWithComma(temptimezone.getBeginDST()) +
						 Util.wrapAsString(temptimezone.getEndDST()) +
						 ");");

			
			Util.println("rowsInserted += makeEntry(tempcity.city_id, tempcity, tempcity.getCountryCode());");
			
        }
        stmt.close();

    }

  public boolean createSQLScript(Connection conn) throws SQLException {
  Util.println("--Can't make SQL script for complex objects.");
  Util.println("--But this SQL Statement works.");
  Util.println("VALUES (new InsertCities().insert(getCurrentConnection()));");

	return insertableAsSQL;
  }




	private void testTimeZones(Connection conn) throws SQLException {

		GregorianCalendar c = new GregorianCalendar();
		c.set(Calendar.YEAR,2000);
		//SF vs. Dublin
		compareTwoTimeZones(c, Calendar.JANUARY, 1, 14, 8);
		compareTwoTimeZones(c, Calendar.JUNE, 1, 14, 8);
		compareTwoTimeZones(c, Calendar.MARCH, 27, 14, 9);

		//SF vs. Santiago
		compareTwoTimeZones(c, Calendar.MARCH, 26, 39, 4);
		compareTwoTimeZones(c, Calendar.OCTOBER, 15, 39, 4);
		compareTwoTimeZones(c, Calendar.MAY, 1, 39, 3);
		compareTwoTimeZones(c, Calendar.NOVEMBER, 1, 39, 5);

		//SF vs. Beirut
		compareTwoTimeZones(c, Calendar.JANUARY, 1, 3, 10);
		compareTwoTimeZones(c, Calendar.JUNE, 1, 3, 10);
		compareTwoTimeZones(c, Calendar.OCTOBER, 27, 3, 9);

		TimeZone.showAllDSTZones(2000);
		System.out.println();
	}

	private void compareTwoTimeZones(GregorianCalendar c, int month, int day, int cid, int expecting) {
		c.set(Calendar.MONTH, month);
		c.set(Calendar.DATE, day);
		java.util.Date tzdu = c.getTime();
		java.sql.Date tzd = new java.sql.Date(tzdu.getTime());
		System.out.println("Time zone difference, " + theCities[cid].getName() + ", " + theCities[83].getName() + " on");
		System.out.println(tzd + ": " + theCities[cid].getTimeDifference(tzd, theCities[83]) + ", was expecting " +expecting);
	}

}
