package JBMSTours.inserters;

import java.sql.*;
import JBMSTours.Util;

/**
 * InsertCountries is an "inserter" class for the <em>Countries</em> table.
 * It is a good example of how to use a single PreparedStatement to insert
 * multiple rows.
 *
 */
public class InsertCountries implements Inserters{

    private PreparedStatement insert;
    private String insertString;
    private int rowsInserted;
    private static int NUMCOUNTRIES=115;
    private boolean insertableAsSQL=true;

    public InsertCountries () {
        insertString = "INSERT INTO Countries values(?, ?, ?)";
        rowsInserted = 0;
    }

    public boolean insert (Connection conn) throws SQLException {

        // here we prepared the statement once
      if (!prepareStatements(conn))
	return false;

        // and update it several times (in the makeEntry() method)
        rowsInserted +=makeEntry("Afghanistan", "AF", "Asia");
        rowsInserted +=makeEntry("Albania", "AL", "Europe");
        rowsInserted +=makeEntry("Algeria", "DZ", "North Africa");
        rowsInserted +=makeEntry("American Samoa", "AS", "Pacific Islands");
        rowsInserted +=makeEntry("Angola", "AO", "Africa");
        rowsInserted +=makeEntry("Argentina", "AR", "South America");
        rowsInserted +=makeEntry("Armenia", "AM", "Europe");
        rowsInserted +=makeEntry("Australia", "AU", "Australia and New Zealand");
        rowsInserted +=makeEntry("Austria", "AT", "Europe");
        rowsInserted +=makeEntry("Azerbaijan", "AZ", "Central Asia");
        rowsInserted +=makeEntry("Bahamas", "BS", "Caribbean");
        rowsInserted +=makeEntry("Bangladesh", "BD", "Asia");
        rowsInserted +=makeEntry("Barbados", "BB", "Caribbean");
        rowsInserted +=makeEntry("Belgium", "BE", "Europe");
        rowsInserted +=makeEntry("Belize", "BZ", "Central America");
        rowsInserted +=makeEntry("Bermuda", "BM", "Caribbean");
        rowsInserted +=makeEntry("Bolivia", "BO", "South America");
        rowsInserted +=makeEntry("Botswana", "BW", "Africa");
        rowsInserted += makeEntry("Brazil", "BR", "South America");
        rowsInserted +=makeEntry("Bulgaria", "BG", "Europe");
        rowsInserted +=makeEntry("Cambodia", "KH", "Asia");
        rowsInserted +=makeEntry("Cameroon", "CM", "Africa");
        rowsInserted +=makeEntry("Canada", "CA", "North America");
        rowsInserted +=makeEntry("Cape Verde", "CV", "Africa");
        rowsInserted += makeEntry("Chile", "CL", "South America");
        rowsInserted +=makeEntry("China", "CN", "Asia");
        rowsInserted +=makeEntry("Colombia", "CO", "South America");
        rowsInserted +=makeEntry("Congo", "CG", "Africa");
        rowsInserted +=makeEntry("Costa Rica", "CR", "Central America");
        rowsInserted +=makeEntry("Cote d'Ivoire", "CI", "Africa");
        rowsInserted +=makeEntry("Cuba", "CU", "Caribbean");
        rowsInserted +=makeEntry("Czech Republic", "CZ", "Europe");
        rowsInserted +=makeEntry("Denmark", "DK", "Europe");
        rowsInserted +=makeEntry("Dominical Republic", "DO", "Caribbean");
        rowsInserted +=makeEntry("Ecuador", "EC", "South America");
        rowsInserted +=makeEntry("Egypt", "EG", "North Africa");
        rowsInserted +=makeEntry("El Salvador", "SV", "Central America");
        rowsInserted +=makeEntry("Ethiopia", "ET", "North Africa");
        rowsInserted +=makeEntry("Falkland Islands", "FK", "South America");
        rowsInserted +=makeEntry("Fiji", "FJ", "Pacific Islands");
        rowsInserted +=makeEntry("Finland", "FI", "Europe");
        rowsInserted += makeEntry("France", "FR", "Europe");
        rowsInserted +=makeEntry("Georgia", "GE", "Europe");
        rowsInserted +=makeEntry("Germany", "DE", "Europe");
        rowsInserted +=makeEntry("Ghana", "GH", "Africa");
        rowsInserted +=makeEntry("Greece", "GR", "Europe");
        rowsInserted +=makeEntry("Guadeloupe", "GP", "Caribbean");
        rowsInserted +=makeEntry("Guatemala", "GT", "Central America");
        rowsInserted +=makeEntry("Honduras", "HN", "Central America");
        rowsInserted +=makeEntry("Hungary", "HU", "Europe");
        rowsInserted +=makeEntry("Iceland", "IS", "Europe");
        rowsInserted +=makeEntry("India", "IN", "Asia");
        rowsInserted +=makeEntry("Indonesia", "ID", "Asia");
        rowsInserted +=makeEntry("Iran", "IR", "Middle East");
        rowsInserted +=makeEntry("Iraq", "IQ", "Middle East");
        rowsInserted +=makeEntry("Ireland", "IE", "Europe");
        rowsInserted +=makeEntry("Israel", "IL", "Middle East");
        rowsInserted +=makeEntry("Italy", "IT", "Europe");
        rowsInserted +=makeEntry("Jamaica", "JM", "Caribbean");
        rowsInserted +=makeEntry("Japan", "JP", "Asia");
        rowsInserted +=makeEntry("Jordan", "JO", "Middle East");
        rowsInserted +=makeEntry("Kenya", "KE", "Africa");
        rowsInserted +=makeEntry("Korea, Republic of", "KR", "Asia");
        rowsInserted +=makeEntry("Lebanon", "LB", "Middle East");
        rowsInserted +=makeEntry("Lithuania", "LT", "Europe");
        rowsInserted +=makeEntry("Madagascar", "MG", "Africa");
        rowsInserted +=makeEntry("Malaysia", "MY", "Asia");
        rowsInserted +=makeEntry("Mali", "ML", "Africa");
        rowsInserted +=makeEntry("Mexico", "MX", "North America");
        rowsInserted +=makeEntry("Morocco", "MA", "North Africa");
        rowsInserted +=makeEntry("Mozambique", "MZ", "Africa");
        rowsInserted +=makeEntry("Nepal", "NP", "Asia");
        rowsInserted +=makeEntry("Netherlands", "NL", "Europe");
        rowsInserted +=makeEntry("New Zealand", "NZ", "Australia and New Zealand");
        rowsInserted +=makeEntry("Nicaragua", "NI", "Central America");
        rowsInserted +=makeEntry("Nigeria", "NG", "Africa");
        rowsInserted +=makeEntry("Norway", "NO", "Europe");
        rowsInserted +=makeEntry("Pakistan", "PK", "Central Asia");
        rowsInserted +=makeEntry("Paraguay", "PY", "South America");
        rowsInserted +=makeEntry("Peru", "PE", "South America");
        rowsInserted +=makeEntry("Philippines", "PH", "Asia");
        rowsInserted +=makeEntry("Poland", "PL", "Europe");
        rowsInserted +=makeEntry("Portugal", "PT", "Europe");
        rowsInserted +=makeEntry("Russia", "RU", "Europe");
        rowsInserted +=makeEntry("Samoa", "WS", "Pacific Islands");
        rowsInserted +=makeEntry("Senegal", "SN", "Africa");
        rowsInserted +=makeEntry("Sierra Leone", "SL", "Africa");
        rowsInserted +=makeEntry("Singapore", "SG", "Asia");
        rowsInserted +=makeEntry("Slovakia", "SK", "Europe");
        rowsInserted +=makeEntry("South Africa", "ZA", "Africa");
        rowsInserted +=makeEntry("Spain", "ES", "Europe");
        rowsInserted +=makeEntry("Sri Lanka", "LK", "Asia");
        rowsInserted +=makeEntry("Sudan", "SD", "Africa");
        rowsInserted +=makeEntry("Sweden", "SE", "Europe");
        rowsInserted +=makeEntry("Switzerland", "CH", "Europe");
        rowsInserted +=makeEntry("Syrian Arab Republic", "SY", "Middle East");
        rowsInserted +=makeEntry("Taiwan", "TW", "Asia");
        rowsInserted +=makeEntry("Tajikistan", "TJ", "Central Asia");
        rowsInserted +=makeEntry("Tanzania", "TZ", "Africa");
        rowsInserted +=makeEntry("Thailand", "TH", "Asia");
        rowsInserted +=makeEntry("Trinidad and Tobago", "TT", "Caribbean");
        rowsInserted +=makeEntry("Tunisia", "TN", "North Africa");
        rowsInserted +=makeEntry("Turkey", "TR", "Middle East");
        rowsInserted +=makeEntry("Ukraine", "UA", "Europe");
        rowsInserted +=makeEntry("United Kingdom", "GB", "Europe");
        rowsInserted +=makeEntry("United States", "US", "North America");
        rowsInserted +=makeEntry("Uruguay", "UY", "South America");
        rowsInserted +=makeEntry("Uzbekistan", "UZ", "Central Asia");
        rowsInserted +=makeEntry("Venezuela", "VE", "South America");
        rowsInserted +=makeEntry("Viet Nam", "VN", "Asia");
        rowsInserted +=makeEntry("Virgin Islands (British)", "VG", "Caribbean");
        rowsInserted +=makeEntry("Virgin Islands (U.S.)", "VI", "Caribbean");
        rowsInserted +=makeEntry("Yugoslavia", "YU", "Europe");
        rowsInserted +=makeEntry("Zaire", "ZR", "Africa");
        rowsInserted +=makeEntry("Zimbabwe", "ZW", "Africa");

        
	Util.println("");
        Util.println(rowsInserted + " rows inserted into COUNTRY table");
        Util.println("");
	insert.close();
        if (rowsInserted == NUMCOUNTRIES) 
            return true;
        else 
	  return false;
    }



  public boolean prepareStatements(Connection conn) throws SQLException {
        insert = conn.prepareStatement(insertString);
	if (insert != null)
	  return true;
	return false;

  }

    private int makeEntry(String a, String b, String c) throws SQLException {
   
        insert.setString(1, a);
        insert.setString(2, b);
        insert.setString(3, c);
        int n = insert.executeUpdate();
        return n;
    }  


    public void confirmInsert (Connection conn) throws SQLException {
        int count = 0;
        Statement s = conn.createStatement();

        Util.println("Show all the country data inserted: ");

        ResultSet rs = s.executeQuery("select country, region from countries");
        while (rs.next()) {

              Util.println(rs.getString(1) + ", in " + rs.getString(2));
              count++;
        }
        rs.close();
        s.close();

        Util.println();
        Util.println(count + " records retrieved from COUNTRY table");
        Util.println();
    } 

    public void extractDataForReInsert (Connection conn) throws SQLException {

        Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery("SELECT * from Countries");
        while (rs.next()) {
			
            Util.println("rowsInserted +=makeEntry(" +
						 Util.wrapAsStringWithComma(rs.getString(1)) +
						 Util.wrapAsStringWithComma(rs.getString(2)) + 
						 Util.wrapAsString(rs.getString(3)) +
						 ");");
        }
        stmt.close();

    }


	
    public boolean createSQLScript (Connection conn) throws SQLException {
		
        Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery("SELECT * from Countries");
        while (rs.next()) {
			
            Util.println("INSERT INTO COUNTRIES VALUES (" +
						 Util.wrapAsStringWithCommaSQ(rs.getString(1)) +
						 Util.wrapAsStringWithCommaSQ(rs.getString(2)) + 
						 Util.wrapAsStringSQ(rs.getString(3)) +
						 ");");
        }
        stmt.close();
		return insertableAsSQL;

  }

	
}
