package JBMSTours.inserters;

import java.sql.*;
import JBMSTours.Hotel;
import JBMSTours.Util;
import JBMSTours.serializabletypes.Tour;

/**
 * Look at the <a href="../JBMSTours/InsertHotels.java">Source</a>.<p>
 * This class inserts the hotels 
 * (the <em>Hotels</em> table).
 */
public class InsertHotels implements Inserters {

    private PreparedStatement insert1;
	private PreparedStatement insert2;
    private String insertString1;
	private String insertString2;
    private int rowsInserted;
    private boolean insertableAsSQL=true;



    //////////////////
    // constructor
    //////////////////

    public InsertHotels() {






		insertString1 ="INSERT INTO hotels (hotel_id, hotel_name, city_id, tour_level, normal_rate, "+
			"high_season_rate, number_rooms_in_block, high_season_begin, high_season_end) "+
            "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
		insertString2 ="INSERT INTO hotels (hotel_id, hotel_name, city_id, tour_level, normal_rate, "+
			"high_season_rate, number_rooms_in_block) "+
            "VALUES (?, ?, ?, ?, ?, ?, ?)";
		rowsInserted = 0;
		
    }
	
    ///////////////////////////////
    // methods for inserting data
    ///////////////////////////////
	
    /**
     * Inserts a large amount of flight data.
     *
     * @param conn   the name of the connection 
     *
     * @exception SQLException  Thrown if there is a SQL error.
     *
     */
    public boolean insert (Connection conn) throws SQLException {

        if (!prepareStatements(conn))
	  return false;
  

		rowsInserted += fullHotelEntry(1, "Hotel Neutra", 1, Tour.ECONOMYTOURLEVEL,"45.00", "70.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(2, "Hotel Europa", 1, Tour.STANDARDTOURLEVEL,"70.00", "100.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(3, "Hotel Bilderburg", 1, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 5, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(4, "Hotel Rivoli", 2, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(5, "Hotel Aphrodite", 2, Tour.STANDARDTOURLEVEL,"70.00", "95.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(6, "Hotel Inter-Continental", 2, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(7, "Takapuna Motor Lodge", 3, Tour.ECONOMYTOURLEVEL,"45.00", "60.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(8, "Park Towers", 3, Tour.STANDARDTOURLEVEL,"75.00", "85.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(9, "Amersham House", 3, Tour.FIRSTCLASSTOURLEVEL,"105.00", "125.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(10, "Holiday Home", 4, Tour.ECONOMYTOURLEVEL,"25.00", "45.00", 10, java.util.Calendar.MAY, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(11, "Mayflower Lodge", 4, Tour.STANDARDTOURLEVEL,"60.00", "80.00", 10, java.util.Calendar.MAY, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(12, "Grand Hotel Versailles", 4, Tour.FIRSTCLASSTOURLEVEL,"100.00", "110.00", 10, java.util.Calendar.MAY, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(13, "Hotel de Bogota", 5, Tour.ECONOMYTOURLEVEL,"30.00", "35.00", 10);
		rowsInserted += fullHotelEntry(14, "Embassy Suites", 5, Tour.STANDARDTOURLEVEL,"55.00", "75.00", 10);
		rowsInserted += fullHotelEntry(15, "Hotel Tequendama", 5, Tour.FIRSTCLASSTOURLEVEL,"115.00", "125.00", 10);
		rowsInserted += fullHotelEntry(16, "Leela Kempinski Hotel", 6, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10);
		rowsInserted += fullHotelEntry(17, "Ramada Hotel Palm Grove", 6, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10);
		rowsInserted += fullHotelEntry(18, "Oberoi Towers", 6, Tour.FIRSTCLASSTOURLEVEL,"105.00", "110.00", 10);
		rowsInserted += fullHotelEntry(19, "Ramada Grand Hotel", 7, Tour.ECONOMYTOURLEVEL,"45.00", "60.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(20, "Hotel Astoria", 7, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(21, "Budapest Hilton", 7, Tour.FIRSTCLASSTOURLEVEL,"125.00", "150.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(22, "Hotel le Monde", 8, Tour.ECONOMYTOURLEVEL,"40.00", "45.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MAY);
		rowsInserted += fullHotelEntry(23, "Gran Hotel Argentino", 8, Tour.STANDARDTOURLEVEL,"70.00", "90.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MAY);
		rowsInserted += fullHotelEntry(24, "Aspen Towers", 8, Tour.FIRSTCLASSTOURLEVEL,"125.00", "140.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MAY);
		rowsInserted += fullHotelEntry(25, "Hotel of Cairo", 9, Tour.ECONOMYTOURLEVEL,"35.00", "40.00", 10, java.util.Calendar.MAY, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(26, "Hotel Sakkara", 9, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.MAY, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(27, "Sofitel Le Sphinx", 9, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10, java.util.Calendar.MAY, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(28, "Hotel Indiana", 10, Tour.ECONOMYTOURLEVEL,"35.00", "40.00", 10);
		rowsInserted += fullHotelEntry(29, "Kenilworth Hotel", 10, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10);
		rowsInserted += fullHotelEntry(30, "Oberoi Grand Hotel", 10, Tour.FIRSTCLASSTOURLEVEL,"105.00", "115.00", 10);
		rowsInserted += fullHotelEntry(31, "Tudor House Hotel", 11, Tour.ECONOMYTOURLEVEL,"60.00", "70.00", 3);
		rowsInserted += fullHotelEntry(32, "Hotel Metropole", 11, Tour.STANDARDTOURLEVEL,"90.00", "100.00", 10);
		rowsInserted += fullHotelEntry(33, "The Bay", 11, Tour.FIRSTCLASSTOURLEVEL,"115.00", "150.00", 10);
		rowsInserted += fullHotelEntry(34, "Economy Hotel", 12, Tour.ECONOMYTOURLEVEL,"15.00", "25.00", 10);
		rowsInserted += fullHotelEntry(35, "Grand Melia Caracas", 12, Tour.STANDARDTOURLEVEL,"50.00", "70.00", 10);
		rowsInserted += fullHotelEntry(36, "Caracas Hilton", 12, Tour.FIRSTCLASSTOURLEVEL,"125.00", "150.00", 10);
		rowsInserted += fullHotelEntry(37, "Hotel Semiramis", 13, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10);
		rowsInserted += fullHotelEntry(38, "Hotel Toubkal", 13, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10);
		rowsInserted += fullHotelEntry(39, "Forte Grand Royal Mansour", 13, Tour.FIRSTCLASSTOURLEVEL,"105.00", "115.00", 10);
		rowsInserted += fullHotelEntry(40, "Hotel Mercur", 14, Tour.ECONOMYTOURLEVEL,"60.00", "70.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(41, "Hotel Esplanaden", 14, Tour.STANDARDTOURLEVEL,"95.00", "125.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(42, "Hotel Phoenix", 14, Tour.FIRSTCLASSTOURLEVEL,"200.00", "225.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(43, "Hibernian Hotel", 15, Tour.ECONOMYTOURLEVEL,"55.00", "65.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(44, "Lengfield's", 15, Tour.STANDARDTOURLEVEL,"85.00", "100.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(45, "The Towers", 15, Tour.FIRSTCLASSTOURLEVEL,"150.00", "160.00", 6, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(46, "Hotel Grand Pre", 16, Tour.ECONOMYTOURLEVEL,"60.00", "70.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(47, "Lonchamp Hotel", 16, Tour.STANDARDTOURLEVEL,"90.00", "95.00", 12, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(48, "Hotel Inter-Continental", 16, Tour.FIRSTCLASSTOURLEVEL,"160.00", "190.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(49, "Conrad International", 17, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10);
		rowsInserted += fullHotelEntry(50, "Marriott Hotel", 17, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10);
		rowsInserted += fullHotelEntry(51, "Furama Kempinski", 17, Tour.FIRSTCLASSTOURLEVEL,"180.00", "200.00", 10);
		rowsInserted += fullHotelEntry(52, "Hotel ", 18, 1, "20.00", "30.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(53, "Ibrahim Pushta", 18, Tour.STANDARDTOURLEVEL,"45.00", "60.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(54, "Hotel Inter-Continental", 18, Tour.FIRSTCLASSTOURLEVEL,"105.00", "115.00", 6, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(55, "Putri Hotel", 19, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10);
		rowsInserted += fullHotelEntry(56, "Regent Hotel", 19, Tour.STANDARDTOURLEVEL,"65.00", "72.50", 5);
		rowsInserted += fullHotelEntry(57, "Ascott Hotel", 19, Tour.FIRSTCLASSTOURLEVEL,"95.00", "130.00", 3);
		rowsInserted += fullHotelEntry(58, "Hotel of Kabul", 20, Tour.ECONOMYTOURLEVEL,"28.00", "32.00", 3);
		rowsInserted += fullHotelEntry(59, "Hotel standard", 20, Tour.STANDARDTOURLEVEL,"50.00", "60.00", 10);
		rowsInserted += fullHotelEntry(60, "Hotel first class", 20, Tour.FIRSTCLASSTOURLEVEL,"80.00", "90.00", 10);
		rowsInserted += fullHotelEntry(61, "Hotel Karachi", 21, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10);
		rowsInserted += fullHotelEntry(62, "Marriott", 21, Tour.STANDARDTOURLEVEL,"60.00", "70.00", 10);
		rowsInserted += fullHotelEntry(63, "Pearl Continental Hotel", 21, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 5);
		rowsInserted += fullHotelEntry(64, "Sheraton Hotel", 22, Tour.ECONOMYTOURLEVEL,"55.00", "60.00", 10);
		rowsInserted += fullHotelEntry(65, "Bristol Hotel", 22, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10);
		rowsInserted += fullHotelEntry(66, "Le Meridien Lagos", 22, Tour.FIRSTCLASSTOURLEVEL,"105.00", "150.00", 10);
		rowsInserted += fullHotelEntry(67, "La Hacienda", 23, Tour.ECONOMYTOURLEVEL,"40.00", "60.00", 5);
		rowsInserted += fullHotelEntry(68, "Hotel Antara", 23, Tour.STANDARDTOURLEVEL,"65.00", "75.00", 10);
		rowsInserted += fullHotelEntry(69, "Las Americas", 23, Tour.FIRSTCLASSTOURLEVEL,"100.00", "110.00", 10);
		rowsInserted += fullHotelEntry(70, "Lisboa Plaza", 24, Tour.ECONOMYTOURLEVEL,"40.00", "55.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(71, "Best Western", 24, Tour.STANDARDTOURLEVEL,"75.00", "85.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(72, "Ritz Inter-Continental", 24, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(73, "The Howard", 25, Tour.ECONOMYTOURLEVEL,"55.00", "70.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(74, "Royal Norfolk Hotel", 25, Tour.STANDARDTOURLEVEL,"85.00", "105.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(75, "St. James Court", 25, Tour.FIRSTCLASSTOURLEVEL,"150.00", "165.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(76, "Hostal Lopez", 26, Tour.ECONOMYTOURLEVEL,"50.00", "70.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(77, "Sol Alondras", 26, Tour.STANDARDTOURLEVEL,"75.00", "90.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(78, "Santo Mauro Hotel", 26, Tour.FIRSTCLASSTOURLEVEL,"140.00", "160.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(79, "Makati Inn", 27, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10);
		rowsInserted += fullHotelEntry(80, "Royal Palm Hotel", 27, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10);
		rowsInserted += fullHotelEntry(81, "Shangri-La Hotel", 27, Tour.FIRSTCLASSTOURLEVEL,"105.00", "115.00", 10);
		rowsInserted += fullHotelEntry(82, "Colonial Inn", 28, Tour.ECONOMYTOURLEVEL,"45.00", "55.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(83, "All Seasons Crossley", 28, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(84, "Savoy Park Plaza", 28, Tour.FIRSTCLASSTOURLEVEL,"115.00", "130.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(85, "Hotel Camino Real", 29, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(86, "Hotel Isabel", 29, Tour.STANDARDTOURLEVEL,"75.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(87, "Marquis Reforma", 29, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(88, "Via Lavoisier", 30, Tour.ECONOMYTOURLEVEL,"55.00", "65.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(89, "Le Montford", 30, Tour.STANDARDTOURLEVEL,"80.00", "90.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(90, "Chateau Royal", 30, Tour.FIRSTCLASSTOURLEVEL,"150.00", "180.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(91, "Moskva Hotel", 31, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10, java.util.Calendar.MARCH, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(92, "Hotel President", 31, Tour.STANDARDTOURLEVEL,"70.00", "75.00", 10, java.util.Calendar.MARCH, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(93, "Hotel Metropol", 31, Tour.FIRSTCLASSTOURLEVEL,"105.00", "150.00", 10, java.util.Calendar.MARCH, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(94, "Le Meridien Nairobi", 32, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10);
		rowsInserted += fullHotelEntry(95, "Nairobi Hilton", 32, Tour.STANDARDTOURLEVEL,"60.00", "70.00", 10);
		rowsInserted += fullHotelEntry(96, "Hotel Inter-Continental", 32, Tour.FIRSTCLASSTOURLEVEL,"110.00", "130.00", 10);
		rowsInserted += fullHotelEntry(97, "New Hankyu", 33, Tour.ECONOMYTOURLEVEL,"85.00", "95.00", 10);
		rowsInserted += fullHotelEntry(98, "Hankyu International", 33, Tour.STANDARDTOURLEVEL,"105.00", "130.00", 10);
		rowsInserted += fullHotelEntry(99, "Hyatt Regency", 33, Tour.FIRSTCLASSTOURLEVEL,"160.00", "210.00", 10);
		rowsInserted += fullHotelEntry(100, "Hotel Ambassadeur", 34, Tour.ECONOMYTOURLEVEL,"65.00", "95.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(101, "Hotel Norrona", 34, Tour.STANDARDTOURLEVEL,"95.00", "120.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(102, "Foenix Hotel", 34, Tour.FIRSTCLASSTOURLEVEL,"120.00", "160.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(103, "Hotel du Quartier Latin", 35, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(104, "Hotel du Quai Voltaire", 35, Tour.STANDARDTOURLEVEL,"80.00", "95.00", 12, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(105, "Hotel du Louvre", 35, Tour.FIRSTCLASSTOURLEVEL,"165.00", "210.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(106, "Pension Brezina", 36, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 8, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(107, "Hotel Paulinz", 36, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(108, "Hotel Movenpick", 36, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(109, "Harpa Kjarnalundi", 37, Tour.ECONOMYTOURLEVEL,"55.00", "65.00", 10);
		rowsInserted += fullHotelEntry(110, "Edda Pelamork", 37, Tour.STANDARDTOURLEVEL,"78.00", "92.00", 10);
		rowsInserted += fullHotelEntry(111, "Edda Akureri", 37, Tour.FIRSTCLASSTOURLEVEL,"110.00", "140.00", 7);
		rowsInserted += fullHotelEntry(112, "Hotel do Rio", 38, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.FEBRUARY);
		rowsInserted += fullHotelEntry(113, "Olinda Othon", 38, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.FEBRUARY);
		rowsInserted += fullHotelEntry(114, "Copacabana Palace", 38, Tour.FIRSTCLASSTOURLEVEL,"135.00", "160.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.FEBRUARY);
		rowsInserted += fullHotelEntry(115, "Villa Florence", 39, Tour.ECONOMYTOURLEVEL,"45.00", "65.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(116, "Hotel Internazionale", 39, Tour.STANDARDTOURLEVEL,"70.00", "90.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(117, "Hotel Mediterraneo", 39, Tour.FIRSTCLASSTOURLEVEL,"105.00", "145.00", 12, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(118, "Hotel de Santiago", 40, Tour.ECONOMYTOURLEVEL,"40.00", "48.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(119, "Hotel Sonesta", 40, Tour.STANDARDTOURLEVEL,"75.00", "80.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(120, "Hotel Conquistador", 40, Tour.FIRSTCLASSTOURLEVEL,"105.00", "150.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(121, "Hotel Itamarati", 41, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.FEBRUARY);
		rowsInserted += fullHotelEntry(122, "Sol Champs Elysees", 41, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.FEBRUARY);
		rowsInserted += fullHotelEntry(123, "Hotel Sao Paulo", 41, Tour.FIRSTCLASSTOURLEVEL,"145.00", "160.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.FEBRUARY);
		rowsInserted += fullHotelEntry(124, "Westin", 42, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10);
		rowsInserted += fullHotelEntry(125, "Jaychan Inn", 42, Tour.STANDARDTOURLEVEL,"70.00", "90.00", 10);
		rowsInserted += fullHotelEntry(126, "The Shilla", 42, Tour.FIRSTCLASSTOURLEVEL,"105.00", "115.00", 10);
		rowsInserted += fullHotelEntry(127, "Lan Sheng", 43, Tour.ECONOMYTOURLEVEL,"25.00", "33.00", 10, java.util.Calendar.APRIL, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(128, "Hilton", 43, Tour.STANDARDTOURLEVEL,"60.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(129, "Portman Shangri-La", 43, Tour.FIRSTCLASSTOURLEVEL,"105.00", "135.00", 10, java.util.Calendar.APRIL, java.util.Calendar.SEPTEMBER);
		rowsInserted += fullHotelEntry(130, "Inn of Sixth Hapiness", 44, Tour.ECONOMYTOURLEVEL,"35.00", "45.00", 10);
		rowsInserted += fullHotelEntry(131, "Hotel Concorde", 44, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10);
		rowsInserted += fullHotelEntry(132, "Shangri-La Rasa Sentosa Resort", 44, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10);
		rowsInserted += fullHotelEntry(133, "Hotel Arctia Hasselbacken", 45, Tour.ECONOMYTOURLEVEL,"65.00", "75.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(134, "Hotel Terminus", 45, Tour.STANDARDTOURLEVEL,"80.00", "95.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(135, "Hotel Ariadne", 45, Tour.FIRSTCLASSTOURLEVEL,"135.00", "175.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(136, "Pension Albergo", 46, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(137, "Hyatt Kingston", 46, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(138, "Wynward Vista", 46, Tour.FIRSTCLASSTOURLEVEL,"105.00", "135.00", 10, java.util.Calendar.OCTOBER, java.util.Calendar.MARCH);
		rowsInserted += fullHotelEntry(139, "Taipei Fortuna", 47, Tour.ECONOMYTOURLEVEL,"35.00", "40.00", 10);
		rowsInserted += fullHotelEntry(140, "Asiaworld Plaza", 47, Tour.STANDARDTOURLEVEL,"60.00", "75.00", 10);
		rowsInserted += fullHotelEntry(141, "Grand Formasa Regency", 47, Tour.FIRSTCLASSTOURLEVEL,"95.00", "135.00", 10);
		rowsInserted += fullHotelEntry(142, "Hotel Economy", 48, Tour.ECONOMYTOURLEVEL,"15.00", "20.00", 10);
		rowsInserted += fullHotelEntry(143, "Hotel standard", 48, Tour.STANDARDTOURLEVEL,"50.00", "65.00", 10);
		rowsInserted += fullHotelEntry(144, "Hotel first class", 48, Tour.FIRSTCLASSTOURLEVEL,"95.00", "110.00", 10);
		rowsInserted += fullHotelEntry(145, "Griza Tokyo", 49, Tour.ECONOMYTOURLEVEL,"85.00", "100.00", 10);
		rowsInserted += fullHotelEntry(146, "Hankyu Hotel", 49, Tour.STANDARDTOURLEVEL,"110.00", "130.00", 10);
		rowsInserted += fullHotelEntry(147, "Inter-Continental Keio Plaza", 49, Tour.FIRSTCLASSTOURLEVEL,"200.00", "235.00", 10);
		rowsInserted += fullHotelEntry(148, "Butternut House", 50, Tour.ECONOMYTOURLEVEL,"45.00", "55.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(149, "Royal York Hotel", 50, Tour.STANDARDTOURLEVEL,"75.00", "90.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(150, "Sutton Place", 50, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(151, "Hotel Saski", 51, Tour.ECONOMYTOURLEVEL,"35.00", "55.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(152, "Hotel Metropol", 51, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(153, "Hotel Inter-Continental Victoria", 51, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10, java.util.Calendar.MARCH, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(154, "Capitol Inn", 52, Tour.ECONOMYTOURLEVEL,"45.00", "60.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(155, "Bedford Inn", 52, Tour.STANDARDTOURLEVEL,"68.00", "74.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(156, "Albany Towers", 52, Tour.FIRSTCLASSTOURLEVEL,"95.00", "110.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(157, "Hotel Albuquerque", 53, Tour.ECONOMYTOURLEVEL,"42.00", "49.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(158, "Albuquerque Sheraton", 53, Tour.STANDARDTOURLEVEL,"65.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(159, "The Desert Resort of Albuquerque", 53, Tour.FIRSTCLASSTOURLEVEL,"95.00", "110.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(160, "Atlanta Motor Inn", 54, Tour.ECONOMYTOURLEVEL,"45.00", "70.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(161, "Hotel Ambassador", 54, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(162, "Atlanta Towers", 54, Tour.FIRSTCLASSTOURLEVEL,"125.00", "150.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(163, "Mountain Inn", 55, Tour.ECONOMYTOURLEVEL,"45.00", "70.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(164, "LakeFront Lodge", 55, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(165, "Boise Tranquility Resort", 55, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(166, "Hotel Paul Revere", 56, Tour.ECONOMYTOURLEVEL,"45.00", "60.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(167, "Sheraton Boston", 56, Tour.STANDARDTOURLEVEL,"75.00", "85.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(168, "The Mayflower Inn", 56, Tour.FIRSTCLASSTOURLEVEL,"115.00", "140.00", 5, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(169, "Charleston Lodge", 57, Tour.ECONOMYTOURLEVEL,"35.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(170, "Charleston Merritt Inn", 57, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(171, "The Bedford Inn", 57, Tour.FIRSTCLASSTOURLEVEL,"105.00", "145.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(172, "Economy Hotel of Chicago", 58, Tour.ECONOMYTOURLEVEL,"35.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(173, "Marriott Chicago", 58, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(174, "Plaza Chicago", 58, Tour.FIRSTCLASSTOURLEVEL,"105.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(175, "Hotel Cleveland", 59, Tour.ECONOMYTOURLEVEL,"45.00", "50.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(176, "Cleveland Miriam Hotel", 59, Tour.STANDARDTOURLEVEL,"70.00", "70.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(177, "Cleveland Royal Towers", 59, Tour.FIRSTCLASSTOURLEVEL,"105.00", "125.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(178, "Texas Motor Inn", 60, Tour.ECONOMYTOURLEVEL,"45.00", "50.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(179, "Bedford Inn", 60, Tour.STANDARDTOURLEVEL,"70.00", "75.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(180, "Grand Metropole", 60, Tour.FIRSTCLASSTOURLEVEL,"105.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(181, "The Mountain Inn", 61, Tour.ECONOMYTOURLEVEL,"35.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(182, "Ramada Hotel", 61, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(183, "The Bedford Inn of Denver", 61, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 5, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(184, "Hotel economy", 62, Tour.ECONOMYTOURLEVEL,"35.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(185, "Hotel standard", 62, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(186, "Hotel first class", 62, Tour.FIRSTCLASSTOURLEVEL,"105.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(187, "Hotel Pacific Rim", 63, Tour.ECONOMYTOURLEVEL,"55.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(188, "Hyatt Fairbanks", 63, Tour.STANDARDTOURLEVEL,"75.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(189, "Pacific Towers", 63, Tour.FIRSTCLASSTOURLEVEL,"135.00", "145.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(190, "Mountain Inn", 64, Tour.ECONOMYTOURLEVEL,"35.00", "55.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(191, "Bedford Inn", 64, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(192, "President Suites of Helena", 64, Tour.FIRSTCLASSTOURLEVEL,"105.00", "135.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(193, "Waikiki Ocean View Inn", 65, Tour.ECONOMYTOURLEVEL,"45.00", "65.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(194, "Waikiki Towers", 65, Tour.STANDARDTOURLEVEL,"90.00", "120.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(195, "The Resort on Waikiki", 65, Tour.FIRSTCLASSTOURLEVEL,"200.00", "250.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(196, "Houston Motor Inn", 66, Tour.ECONOMYTOURLEVEL,"55.00", "70.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(197, "Wyatt Lodge", 66, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(198, "Houston Ambassador", 66, Tour.FIRSTCLASSTOURLEVEL,"105.00", "130.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(199, "Alaska Inn", 67, Tour.ECONOMYTOURLEVEL,"55.00", "70.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(200, "Hotel Juneau", 67, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(201, "Juneau Sheraton", 67, Tour.FIRSTCLASSTOURLEVEL,"105.00", "150.00", 6, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(202, "Kansas City Motor Inn", 68, Tour.ECONOMYTOURLEVEL,"45.00", "55.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(203, "Sheraton", 68, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(204, "The Inn on the Park", 68, Tour.FIRSTCLASSTOURLEVEL,"105.00", "150.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(205, "Beach View Motor Inn", 69, Tour.ECONOMYTOURLEVEL,"75.00", "85.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(206, "Bedford Inn", 69, Tour.STANDARDTOURLEVEL,"85.00", "90.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(207, "Los Angeles Towers", 69, Tour.FIRSTCLASSTOURLEVEL,"155.00", "200.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(208, "Hotel Chez Elvis", 70, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(209, "Hotel Memphis", 70, Tour.STANDARDTOURLEVEL,"70.00", "90.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(210, "Memphis Towers", 70, Tour.FIRSTCLASSTOURLEVEL,"95.00", "110.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(211, "Ocean View Inn", 71, Tour.ECONOMYTOURLEVEL,"45.00", "65.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(212, "Hotel del Mar", 71, Tour.STANDARDTOURLEVEL,"75.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(213, "Miami Towers", 71, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(214, "Milwaukee Hotel", 72, Tour.ECONOMYTOURLEVEL,"35.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(215, "Hyatt Milwaukee", 72, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(216, "The Royal Milwaukee Inn", 72, Tour.FIRSTCLASSTOURLEVEL,"105.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(217, "Minneapolis Lodge", 73, Tour.ECONOMYTOURLEVEL,"45.00", "60.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(218, "Minneapolis Sheraton", 73, Tour.STANDARDTOURLEVEL,"60.00", "68.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(219, "Bedford Inn", 73, Tour.FIRSTCLASSTOURLEVEL,"95.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(220, "Opry Hotel", 74, Tour.ECONOMYTOURLEVEL,"48.00", "55.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(221, "Nashville Royal Inn", 74, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(222, "Hotel Quatre Etoiles", 74, Tour.FIRSTCLASSTOURLEVEL,"95.00", "120.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(223, "French Quarter Inn", 75, Tour.ECONOMYTOURLEVEL,"45.00", "80.00", 15, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(224, "Sheraton New Orleans", 75, Tour.STANDARDTOURLEVEL,"80.00", "95.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(225, "Hotel Champs Elysees", 75, Tour.FIRSTCLASSTOURLEVEL,"105.00", "150.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(226, "Economy Hotel of Manhattan", 76, Tour.ECONOMYTOURLEVEL,"60.00", "75.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(227, "New York Sheraton", 76, Tour.STANDARDTOURLEVEL,"100.00", "120.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(228, "The Plaza", 76, Tour.FIRSTCLASSTOURLEVEL,"200.00", "210.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(229, "Oklahoma City Motor Inn", 77, Tour.ECONOMYTOURLEVEL,"35.00", "42.50", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(230, "Hilton Hotel", 77, Tour.STANDARDTOURLEVEL,"60.00", "75.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(231, "Great Western Resort Hotel", 77, Tour.FIRSTCLASSTOURLEVEL,"95.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(232, "The Liberty Inn", 78, Tour.ECONOMYTOURLEVEL,"45.00", "65.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(233, "Bedford Inn", 78, Tour.STANDARDTOURLEVEL,"65.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(234, "Philadelphia Towers", 78, Tour.FIRSTCLASSTOURLEVEL,"95.00", "120.00", 6, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(235, "Desert Inn", 79, Tour.ECONOMYTOURLEVEL,"55.00", "60.00", 10);
		rowsInserted += fullHotelEntry(236, "Phoenix Ramada Hotel", 79, Tour.STANDARDTOURLEVEL,"75.00", "85.00", 10);
		rowsInserted += fullHotelEntry(237, "Ambassador Inn", 79, Tour.FIRSTCLASSTOURLEVEL,"125.00", "135.00", 10);
		rowsInserted += fullHotelEntry(238, "Peace Arch Inn", 80, Tour.ECONOMYTOURLEVEL,"45.00", "58.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(239, "Saint Louis Hilton", 80, Tour.STANDARDTOURLEVEL,"70.00", "85.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(240, "Saint Louis Towers", 80, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(241, "Salt Lake City Inn", 81, Tour.ECONOMYTOURLEVEL,"35.00", "50.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(242, "Bedford Inn Salt Lake City", 81, Tour.STANDARDTOURLEVEL,"60.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(243, "Hotel Metropole", 81, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(244, "Hotel the Alamo", 82, Tour.ECONOMYTOURLEVEL,"35.00", "60.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(245, "The San Antonio Lodge", 82, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(246, "San Antonio Towers", 82, Tour.FIRSTCLASSTOURLEVEL,"95.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(247, "Ocean View Motor Inn", 83, Tour.ECONOMYTOURLEVEL,"35.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(248, "San Diego Sheraton", 83, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(249, "San Diego Royal Inn", 83, Tour.FIRSTCLASSTOURLEVEL,"105.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(250, "The Inn", 84, Tour.ECONOMYTOURLEVEL,"80.00", "120.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(251, "The Franciscan", 84, Tour.STANDARDTOURLEVEL,"120.00", "140.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(252, "Hotel Mirabel", 84, Tour.FIRSTCLASSTOURLEVEL,"180.00", "250.00", 5, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(253, "Hotel de San Juan", 85, Tour.ECONOMYTOURLEVEL,"45.00", "60.00", 10);
		rowsInserted += fullHotelEntry(254, "Hotel San Juan", 85, Tour.STANDARDTOURLEVEL,"70.00", "80.00", 10);
		rowsInserted += fullHotelEntry(255, "Inter-Continental San Juan", 85, Tour.FIRSTCLASSTOURLEVEL,"85.00", "120.00", 10);
		rowsInserted += fullHotelEntry(256, "Hotel of Seattle", 86, Tour.ECONOMYTOURLEVEL,"55.00", "80.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(257, "The Inn at Seward Park", 86, Tour.STANDARDTOURLEVEL,"80.00", "110.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(258, "Elliot Bay Towers", 86, Tour.FIRSTCLASSTOURLEVEL,"105.00", "140.00", 3, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(259, "Capitol Inn", 87, Tour.ECONOMYTOURLEVEL,"50.00", "70.00", 10, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(260, "Hotel The President", 87, Tour.STANDARDTOURLEVEL,"70.00", "95.00", 9, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
		rowsInserted += fullHotelEntry(261, "Washington Towers", 87, Tour.FIRSTCLASSTOURLEVEL,"150.00", "200.00", 5, java.util.Calendar.APRIL, java.util.Calendar.OCTOBER);
        
		Util.println("");
        Util.println(rowsInserted + " rows inserted into HOTELS table");
        Util.println("");
		insert1.close();
		insert2.close();
		
		
        
		return true;
    }
	
	
    
	
	public boolean prepareStatements (Connection conn) throws SQLException {
		
		insert1 = conn.prepareStatement(insertString1);
		insert2 = conn.prepareStatement(insertString2);
		
		if (insert1 != null)
			return true;
		return false;
		
		
	}
	
    /**
     * Enters a single hotel into the database.
     *
     * 
     * @exception SQLException  Thrown if there is a SQL error.
     *
     */
	
	
    protected int fullHotelEntry (int id, String name, int cid,int level, String normalrate, String highseasonrate,
                                  int rooms, int highseasonbegin, int highseasonend) 
		 throws SQLException {
			 
			 insert1.setInt(1, id);
			 insert1.setString(2, name);
			 insert1.setInt(3, cid);
			 insert1.setShort(4, (short) level);
			 insert1.setObject(5, new java.math.BigDecimal(normalrate).setScale(2));
			 insert1.setObject(6, new java.math.BigDecimal(highseasonrate).setScale(2));
			 insert1.setInt(7, rooms);
			 insert1.setShort(8, (short) highseasonbegin);
			 insert1.setShort(9, (short) highseasonend);
			 
			 int j = insert1.executeUpdate(); 
			 
			 return j;
    }
	
	
    protected int fullHotelEntry (int id, String name, int cid,int level, String normalrate, String highseasonrate,
                                  int rooms) 
		 throws SQLException {
			 
			 insert2.setInt(1, id);
			 insert2.setString(2, name);
			 insert2.setInt(3, cid);
			 insert2.setShort(4, (short) level);
			 insert2.setObject(5, new java.math.BigDecimal(normalrate).setScale(2));
			 insert2.setObject(6, new java.math.BigDecimal(highseasonrate).setScale(2));
			 insert2.setInt(7, rooms);
			 //we don't need to set these (default) parameters, because these columns use a DEFAULT
			 // (Cloudscape handles the default)
			 //insert2.setShort(8, Hotel.NOHIGHSEASON);
			 //insert2.setShort(9, Hotel.NOHIGHSEASON);
			 
			 int j = insert2.executeUpdate(); 
			 
			 return j;
    }
	
	
	
	
	
	public void confirmInsert(Connection conn) throws SQLException {
		
        int count = 0;
        Statement s = conn.createStatement();
		
        Util.println("Show all the Hotel data inserted: ");
		
        ResultSet rs = s.executeQuery("SELECT hotel_id, hotel_name from hotels");
        while (rs.next()) {
			
			Util.println(rs.getInt(1) + ",  " + rs.getString(2));
			count++;
        }
        rs.close();
		
		
        Util.println();
        Util.println(count + " records retrieved from HOTELS table");
        Util.println();
		
		
        s.close();
		
	}
	
	
	
    /**
     * A home-made method for exporting data.
     *
     * @param    conn           the connection to the database
     *
     *
     * @exception SQLException  Thrown if there is a SQL error.
     *
     */
    public void extractDataForReInsert(Connection conn) throws SQLException {
        Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery("SELECT * FROM Hotels");
		
		
        while (rs.next()) {
            java.math.BigDecimal bigd1, bigd2;
            bigd1 = new java.math.BigDecimal(rs.getDouble(5)).setScale(2, java.math.BigDecimal.ROUND_HALF_DOWN);
            bigd2 = new java.math.BigDecimal(rs.getDouble(6)).setScale(2, java.math.BigDecimal.ROUND_HALF_DOWN);
			
            Util.println("rowsInserted += fullHotelEntry(" +
						 Util.wrapIntWithComma(rs.getInt(1)) +
						 Util.wrapAsStringWithComma(rs.getString(2)) +
						 Util.wrapIntWithComma(rs.getInt(3)) +
						 Util.wrapAsJavaExpressionWithComma(Tour.getJavaFieldForLevel(rs.getShort(4)))+
						 Util.wrapAsStringWithComma(rs.getBigDecimal(5, java.util.Calendar.MARCH).toString())+
						 Util.wrapAsStringWithComma(rs.getBigDecimal(6, java.util.Calendar.MARCH).toString()) +
						 Util.wrapIntWithComma(rs.getInt(7)) + 			       
						 Util.wrapShortWithComma(rs.getShort(8))+
						 rs.getShort(java.util.Calendar.OCTOBER) + ");"); 
		}
		
        
    }
	
	
	public boolean createSQLScript(Connection conn) throws SQLException {
		
		
		Statement s = conn.createStatement();
		ResultSet rs = s.executeQuery("SELECT * FROM Hotels");
		while (rs.next()) {
			
			Util.println("INSERT INTO Hotels VALUES(" +
						 Util.wrapIntWithComma(rs.getInt(1))+
						 Util.wrapAsStringWithCommaSQ(rs.getString(2))+
						 Util.wrapIntWithComma(rs.getInt(3))+
						 Util.wrapAsJavaExpressionWithComma(Tour.getSQLJFieldForLevel(rs.getShort(4)))+
						 rs.getBigDecimal(5, java.util.Calendar.MARCH) + ", " +
						 rs.getBigDecimal(6, java.util.Calendar.MARCH) + ", " +
						 Util.wrapIntWithComma(rs.getInt(7)) +
						 Util.wrapShortWithComma(rs.getShort(8))+
						 rs.getShort(java.util.Calendar.OCTOBER) + ");");
		}
		rs.close();
		s.close();
		return insertableAsSQL;	
	}
	
}
