package JBMSTours.inserters;

import java.sql.*;
import java.io.InputStream;
import java.io.IOException;
import JBMSTours.serializabletypes.Picture;
import JBMSTours.Util;

/**
 * Look at the <a href="../JBMSTours/InsertMaps.java">Source.</a><p>
 * InsertMaps is an "inserter" class for the <em>Maps</em> table.
 *
 */
public class InsertMaps implements Inserters  {

    private PreparedStatement insert;
    private String insertString;
    private int rowsInserted;
    private static int NUMMAPS=11;
    private boolean insertableAsSQL=false;
    private Picture[] mymaps;

    public InsertMaps ()   {
        insertString = "INSERT INTO Maps values(?, ?, ?, ?)";
        rowsInserted = 0;
    }


    public boolean insert (Connection conn) throws SQLException, Exception {

        // here we prepared the statement once
		if (!prepareStatements(conn))
		  return false;


      // and set the parameter values several times (in the makeEntry() method)

	  
		rowsInserted += makeEntry("IT", true, new Picture("maps/Italy.jpg", "Big map of Italy"),
								  "maps/Italytn.gif");
	  rowsInserted += makeEntry("BR", true, new Picture("maps/Brazil.jpg", "Big map of Brazil"),
								"maps/Braziltn.gif");
	  rowsInserted += makeEntry("FR", true, new Picture("maps/France.GIF", "Big map of France"),
								"maps/Francetn.gif");
	  rowsInserted += makeEntry("ZA", true, new Picture("maps/South_Africa.jpg", "Big map of South Africa"),
								  "maps/South_Africatn.gif");
        rowsInserted += makeEntry("MA", false, new Picture("maps/Morocco_sm97.gif", "Small map of Morocco"),
								  "maps/Morocco_smtn.gif");
        rowsInserted += makeEntry("IN", false, new Picture("maps/India_sm97.gif", "Small map of India"),
								  "maps/India_smtn.gif");
        rowsInserted += makeEntry("JP", false, new Picture("maps/Japan_sm97.gif", "Small map of Japan"),
								  "maps/Japan_smtn.gif");
        rowsInserted += makeEntry("CL", false, new Picture("maps/Chile_sm97.gif", "Small map of Chile"),
								  "maps/Chile_smtn.gif");
        rowsInserted += makeEntry("IT", false, new Picture("maps/Italy_sm97.gif", "Small map of Italy"),
								  "maps/Italy_smtn.gif");
        rowsInserted += makeEntry("BR", false, new Picture("maps/Brazil_sm97.gif", "Small map of Brazil"),
								  "maps/Brazil_smtn.gif");
        rowsInserted += makeEntry("FR", false, new Picture("maps/France_sm97.gif", "Small map of France"),
								  "maps/France_smtn.gif");

        
	Util.println("");
        Util.println(rowsInserted + " rows inserted into MAPS table");
        Util.println("");
	insert.close();
        if (rowsInserted == NUMMAPS) 
            return true;
	    /* if the wrong number of rows inserted, roll back*/
        else 
	  return false;
	


    }



  public boolean prepareStatements(Connection conn) throws SQLException {
        insert = conn.prepareStatement(insertString);
	if (insert != null)
	  return true;
	return false;

  }

    private int makeEntry(String a, boolean b, Picture c, String tn) throws SQLException, IOException {
        insert.setString(1, a);
        insert.setBoolean(2, b);
        insert.setObject(3, c);
		if (!(tn == null || tn.equals("null"))) {
			tn = "/" + tn;
			InputStream in = tn.getClass().getResourceAsStream(tn);
			if (in == null)
				System.out.println(tn + " not found");
			int contentLength = in.available();
			byte[] content = new byte[contentLength];
			in.read(content);
			in.close();
		
			insert.setBytes(4, content);
		}

		else
			insert.setBytes(4, null);
        int n = insert.executeUpdate();
        return n;
    }  


    public void confirmInsert (Connection conn) throws SQLException {
        int count = 0;
        Statement s = conn.createStatement();

        Util.println("Show all the Map data inserted: ");

        ResultSet rs = s.executeQuery("SELECT map.getPictureName(), country_iso_code, mapIsBig " +
                                      "FROM Maps ORDER BY country_ISO_code, mapIsBig");
        while (rs.next()) {

              Util.println(rs.getString(1));
              count++;
        }
        rs.close();
        s.close();

        Util.println();
        Util.println(count + " records retrieved from MAP table");
        Util.println();
    } 

    public void extractDataForReInsert (Connection conn) throws SQLException {

        Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery("SELECT * FROM Maps");
        Picture pic;
        while (rs.next()) {
			pic = (Picture) rs.getObject(3);
			
			System.out.println("mymaps = new Picture(" +
							   Util.wrapAsStringWithComma(pic.getName()) +
							   Util.wrapAsString(pic.getPictureName()) +
							   ");");
			System.out.println("rowsInserted += makeEntry(" +
							   Util.wrapAsStringWithComma(rs.getString(1)) +
							   rs.getBoolean(2) +
							   ", mymaps," +
							   Util.wrapAsString("null") + 
							   ");");
			
        }
        stmt.close();
		
    }
	
	
	
    public boolean createSQLScript (Connection conn) throws SQLException {
		
        Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery("SELECT * FROM Maps ORDER BY 1,2");
        Picture pic;
        while (rs.next()) {
			
			pic = (Picture) rs.getObject(3);
			Util.println("INSERT INTO MAPS "+
						 "VALUES (" +
						 Util.wrapAsStringWithCommaSQ(rs.getString(1)) +
						 rs.getBoolean(2) + 
						 ", new Picture(" +
						 Util.wrapAsStringWithCommaSQ(pic.getName()) +
						 Util.wrapAsStringSQ(pic.getPictureName()) +
						 "));");
			
        }
        stmt.close();
		return insertableAsSQL;
		
	}
	
}
