package JBMSTours.inserters;
import java.sql.*;

/**
 *   An interface for the various classes that insert data into the database.
 *  
 */  
public interface Inserters {

  /** 
   * Should insert the data and return the number of rows inserted.
   * @param conn     Connection to the database.
   *
   * @return    boolean  if insert was successful.
   *
   * @exception Exception a error occurred.
   *
   *
   */
  public boolean insert(Connection conn) throws Exception;


  /** 
   * Prepares the statements used in the inserts.
   * @param Conn     Connection to the database.
   *
   * @return    boolean  if statement preparation was successful.
   *
   * @exception SQLException an error occurred.
   *
 *
 */
  boolean prepareStatements(Connection conn) throws SQLException;




  /** 
   * Confirms the insert by doing a System.out of the data.
   *
   * @param conn     Connection to the database.
   *
   * @exception SQLException if an error occurred.
   *
   */
  void confirmInsert(Connection conn) throws SQLException;


  /** 
   * Extracts current data in the table to generate a file to re-produce
   * what happens in the insert method.
   *
   * @param conn     Connection to the database.
   *
   * @exception SQLException if an error occurred.
   *
   *
   */
  void extractDataForReInsert(Connection conn) throws SQLException;


  /** 
   * If possible, does a System.out to create a script file that can be run
   * as an SQL script from ij or Cloudview. Returns a false if this isn't possible
   * because of complexity of object.
   *
   * @param conn     Connection to the database.
   *
   * @return    boolean  if script generation possiblel.
   *
   * @exception SQLException if an SQL error occurred.
   *
 *
 */
  boolean createSQLScript(Connection conn) throws SQLException;

}













