package JBMSTours.serializabletypes;

import java.io.Externalizable;
import java.io.ObjectOutput;
import java.io.ObjectInput;
import java.io.IOException;
import JBMSTours.Util;
import JBMSTours.JCalendar;


/**
 * Look at the <a href="../JBMSTours/serializabletypes/Adult.java">Source</a>.<p>
 *
 * An Adult is a subclass of a Person. Persons are members of groups.
 * This class illustrates how you can store a subclass--you can store any subclass
 * of Person in the People table.
 * This is a highly simplified example of a an object. Normally, if data is this
 * simple, store it as relational data.<p>
 * Use INSTANCEOF CLASS.JBMSTours.serializabletypes.Adult to select only members of the subclass.
 * Persons get stored in the People Table.
 * BuildATour constructs the People objects.
 *
 * @see JBMSTours.BuildATour
 * @see JBMSTours.Group
 * @see Person
 * @see Child
 */
public class Adult extends Person implements Externalizable {

    private String passportNumber = "unknown";
    private static final int currentClassVersion = 1;
    static final long serialVersionUID = -7932935155346092660L;

    public Adult () {
    }

    /**
     * Constructor.
     * Takes a first name and a last name.
     *
     * @param first    the first name.
     * @param last     the last name.
     */
    public Adult (String first, String last) {
        super(first, last);

    }

    /**
     * Constructor.
     * Takes a first name, a last name, and a middle initial.
     * @param first     thefirst name.
     * @param last     the last name.
     * @param a        the middle initial.
     */
    public Adult (String first, String last, char a) {
        super(first, last, a);
    }

    /**
     * Sets the passport number for main person in group only.
     *
     * @param number    the passportNumber
     */

    public void setPassportNumber (String number) {
        passportNumber = number;
    }

    /**
     * Sets the passport number for main person in group only, returns Object (for use in
     * update statements). For example, with this method, you can do an
     * update like this:
     * <P>Update people SET person = CAST (person AS CLASS JBMSTours.serializabletypes.Adult).setPassportNumberReturnSelf('ABCD') WHERE person_id = 2
     *
     * @param number    the passportNumber
     */

    public Person setPassportNumberReturnSelf (String number) {
        passportNumber = number;
	return this;
    }

    /**
     * Gets the passport number.
     *
	 * @returns the passport number, if the person has one. Otherwise returns unknown.
     */

    public String getPassportNumber () {
        return passportNumber;
    }

    /* Externalizable interface */
	/**
	 * 
	 *  @exception IOException if failure to read
	 */
    public void writeExternal(ObjectOutput out) throws IOException {
        out.writeInt(currentClassVersion);
        super.writeExternal(out);
        out.writeUTF(passportNumber);
    }
	
	/**
        @exception IOException thrown on failure to read
        @exception ClassNotFoundException thrown on failure to convert
     */
    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        int    version = in.readInt();
        if (version != currentClassVersion) {
            throw new IOException(
                "Expected class version " + 
                currentClassVersion +
                " when reading Person, but got class version "
                + version);
        }

        super.readExternal(in);
        passportNumber = in.readUTF();
    }

}
