package JBMSTours.serializabletypes;

import java.io.Externalizable;
import java.io.ObjectOutput;
import java.io.ObjectInput;
import java.io.IOException;
import java.sql.SQLException;
import java.sql.Connection;


/**
  * Look at the <a href="../JBMSTours/serializabletypes/Child.java">Source</a>.<p>
  * A Child is a subclass of a Person. Persons are members of groups.
  * Persons get stored in the People Table.
  * This class illustrates how you can store a subclass in a table.
  * BuildATour constructs the People objects.
  *
  * @see JBMSTours.BuildATour
  * @see JBMSTours.Group
  * @see Person
  * @see Adult
  *
  */
public class Child extends Person implements Externalizable {

    private int parentid;
    private static final int currentClassVersion = 1;
    static final long serialVersionUID = 459657398593095863L; 

    public Child () {
    }

    /**
     * Constructor.
     * Takes a first name and a last name.
     *
     * @param first    the first name.
     * @param last     the last name.
     */
    public Child (String first, String last) {
        super(first, last);
    }

    /**
     * Constructor.
     * Takes a first name, a last name, and a middle initial.
     * @param first     thefirst name.
     * @param last      the last name.
     * @param a         the middle initial.
     */
    public Child (String first, String last, char a) {
        super(first, last, a);
        middleInitial = a;
    }

	    /**
     * Constructor.
     * Takes a first name, a last name, a middle initial, and parentid.
     * @param first     thefirst name.
     * @param last      the last name.
	 * @param pid       the parent's id
     */
    public Child (String first, String last, int pid) {
        super(first, last);
		this.setParent(pid);
    }

    /**
     * Sets the id number child's parent.
         *
     * @param pid       id number of parent.
     */
    public void setParent(int pid) {
        parentid = pid;
		
    }

    /**
     * Gets the id number of the parent in the group.
         *
     */
    public int getParent() {
        return parentid;
    }

    /**
     * Is the child's parent already in the table? Can be used in a check
	 * constraint. If you want to ensure that a Child's parent exists
	 * in the table when inserting the Child. Note, however, that this
	 * won't prevent you from deleting the Parent later on. (A foreign key
	 * constraint would prevent you from doing that.)
	 *
     *
     * @param     conn       Connection 
     *
     * @return    boolean     if parent is in table.
     *
     * @exception SQLException  Thrown if there is an SQL error.
     */
    public boolean parentInTable(Connection conn)
		 throws SQLException {

			 if (findPerson(conn, getParent()) == null)
				 return false;
			 else
				 return true;
    }

	
    /* Externalizable interface */
    /**
        @exception IOException from write failures
     */
    public void writeExternal(ObjectOutput out) throws IOException {
        out.writeInt(currentClassVersion);
        super.writeExternal(out);
        out.writeInt(parentid);
    }
 
    /**
        @exception IOException from read failures
        @exception ClassNotFoundException from conversion failures
     */
    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        int    version = in.readInt();
        if (version != currentClassVersion) {
            throw new IOException(
                "Expected class version " +
                currentClassVersion +
                " when reading Person, but got class version "
                + version);
        }

        super.readExternal(in);
        parentid = in.readInt();
    }

}

