package JBMSTours.serializabletypes;

import java.awt.*;
import java.awt.event.*;
import java.io.InputStream;
import JBMSTours.Util;
import JBMSTours.JCalendar;
import JBMSTours.PictureFrame;

/**
 * Look at the <a href="../JBMSTours/serializabletypes/Picture.java">Source</a>.<p>
 * Defines a class containing a picture.
 * When the class is instantiated,
 * it tries to open a resource and store it as a byte array in the content
 * field.
 * See PictureURL for an example of doing the same thing with a URL,
 * not a resource.
 */
public class Picture implements java.io.Serializable
{
    /**
     *   Name of resource file.
     **/
    public String resourceName;

    /**
     *    User's name for picture.
     **/
    public String pictureName;

    /**
     *  Size of content.
     **/
    public int contentLength = -1;

    /**
     *   Actual content.
     **/
    public byte[] content;

    /**
     *   For serialization compatability.
     **/
    static final long serialVersionUID = -1089558736680067627L;

    /**
     * Instantiates the object. Most of the work is done in setContent.
     *
     * @param rname      resourcename for the source resource
     * @param pname      your name for the picture
     *
     * @exception    Exception  if there is  a problem reading the source
     *
     */
    public Picture(String rname, String pname) throws Exception
    {
        pictureName = pname;
        if(rname != null)
        {
            resourceName = rname;
            setContent();
        }
    }

    /**
     * Opens the resource and checks its size.  If the resource is below
     * MAXSIZE, it reads
     * the contents directly into the class.  If the object is being
     * instantiated within Cloudscape, this has the effect of storing the URL
     * content along with the rest of the object in the database.
     *
     * @exception    Exception  if there is  a problem reading the source
     *
     */
    protected void setContent() throws Exception
    {

		if (resourceName.indexOf("/")!=0)
			resourceName = "/" + resourceName;
		
        InputStream in = resourceName.getClass().getResourceAsStream(resourceName);
        if(in == null)
            Util.println("No resource with this resourceName!(" + resourceName +")");
        contentLength = in.available();
        int count = 0;
        int totalBytesRead = 0;
        int bytesRead = 0;
        int bytelength = 0;
        content = new byte[contentLength];
        while(bytesRead > -1 && count < 20)
        {
            bytelength = in.available();
            bytesRead = in.read(content,totalBytesRead,bytelength);
            count++;
            totalBytesRead += bytesRead;
        }
        Util.println("Read " + totalBytesRead + " of " + 
                contentLength + " bytes");
        contentLength = totalBytesRead;
        in.close();
    }

    /**
     * Returns the resourceName.
     */
    public String getName()
    {
        return resourceName;
    }

    /**
     * Returns the name of the picture.
     */
    public String getPictureName()
    {
        return pictureName;
    }

    /**
     * Returns the content.  If the content is local, this method simply returns
     * the array reference.  If not, we open the URL and read from it.  Notice
     * that this stores the content in memory, so that if someone asks for it
     * again we already have it.
     */
    public byte[] getContent()
    {
        // Content is not available, we try to read it.
        /* if (content == null)
           {
           try
           {
           URL url = new URL(URLName);
           URLConnection conn = url.openConnection();
           InputStream in = conn.getInputStream();
           content = new byte[in.available()];
           in.read(content);
           in.close();
           }
           // If there is an exception, just set content to null.
           catch (Exception e)
           {
           content = null;
           }
           }*/
        // Return whatever is in content.
        return content;
    }

    /**
     * Returns the length of the content.
     */
    public int getContentLength()
    {
        return contentLength;
    }

    /**
     * displaying a picture consists of displaying it in a frame.
     *
     * @exception Exception    If there is an error.
     */
    public void display() throws Exception
    {
        Frame f;
        f = new PictureFrame(getPictureName(),getContent());
    }

}

