package JBMSTours.serializabletypes;
import java.sql.*;
import java.math.BigDecimal;
import JBMSTours.Util;
import JBMSTours.JCalendar;


/**
  * Look at the <a href="../JBMSTours/serializabletypes/TransferFlight.java">Source</a>.<p>
  *
  * Definition of a flight with one transfer.
  *
  */ 

public class TransferFlight        extends        OneStopFlight
                                implements     java.io.Serializable
{
    /////////////////////////////////////////////////////////////////////////
    //
    //    STATE
    //
    /////////////////////////////////////////////////////////////////////////

 
    public String segment2ID;
    static final long serialVersionUID = -5368761672272161563L;


    /////////////////////////////////////////////////////////////////////////
    //
    //    CONSTRUCTORS
    //
    /////////////////////////////////////////////////////////////////////////

 
    /**
     * Default niladic constructor for a flight with one transfer.
     *
     */
    public TransferFlight() {
        super();

        segment2ID = "000000";
    }


    /**
     * Constructs a TransferFlight flight from its two legs.
     *
     * @param segone     Flight object for first flight.
     * @param segtwo     Flight object for second flight.
     *
     */
    public TransferFlight (Flight segone, Flight segtwo) {
        super( segone, segtwo );

        segment2ID = segtwo.flight_id;

    }


    /////////////////////////////////////////////////////////////////////////
    //
    //    SHADOW OBJECT METHODS
    //
    /////////////////////////////////////////////////////////////////////////

    /**
     * Prints out this object.
     *
     */
    public String toString() {
        return getType()  +
               ", " + flight_id + " and " + segment2ID + 
               ", " + orig_airport + " to " + dest_airport +
               ", with a transfer at " + stop_airport;
    }



    /////////////////////////////////////////////////////////////////////////
    //
    //    ACCESSORS
    //
    /////////////////////////////////////////////////////////////////////////

 

    ///////////////////////////////
    //                           //
    //    SHADOW FLIGHT ACCESSORS  //
    //                           //
    ///////////////////////////////


    /**
      *    Get the flight id of the second leg.
      *
      *    @return    flight id of the second leg.
      */
    public String getAltFlightId() { 
        return segment2ID; 
    }
 
    /**
      *    Get the flight type.
      *
      *    @return    flight type.
      */
    public String getType() { 
        return "Transfer flight"; 
    }  


  public String getUniqueId() {
  
    return getFlightId() + getAltFlightId() + orig_airport + stop_airport + dest_airport;
  }

    /////////////////////////////////////////////////////////////////////////
    //
    //    SHADOW OTHER FLIGHT METHODS
    //
    /////////////////////////////////////////////////////////////////////////


    /**
     * "Books" the flight by extracting the pertinent information to 
     * a separate table (FlightBookings). This is the information 
     * that eventually goes to the airline.
     *
     * @param conn        Connection 
     * @param gid         The group_id
     * @param travelDate  Date that travel begins.
     * @param numberSeats number of seats reserved
     * @param fixedRate   the rate for those seats
     * @param     The level of the tour. See the static variables in Tour.java.
     * @return    > 0 if FlightBookings table successfully updated.
     *    
     * @exception SQLException in case anything goes wrong during a SQL operation
     */

    public int storeBookingInfoForAirline
    (
        Connection    conn,
        int         gid,
        Date        travelDate,
        int         numberSeats,
        BigDecimal    fixedRate,
        short         level
    )
        throws SQLException
    {

       prepareStatements(conn);
   
        insert_stop_flight_bookings.setString(1, flight_id);
        insert_stop_flight_bookings.setInt(2, getSegmentNumber());
        insert_stop_flight_bookings.setInt(3, gid);
        insert_stop_flight_bookings.setDate(4, travelDate);
        insert_stop_flight_bookings.setString(5, segment2ID);
        insert_stop_flight_bookings.setInt(6, segment2Number);
        insert_stop_flight_bookings.setInt(7, numberSeats);
        insert_stop_flight_bookings.setObject(8, fixedRate);
        insert_stop_flight_bookings.setString(9, checkLevel(level));

        int n = insert_stop_flight_bookings.executeUpdate();
   
        return n;
    }

    /**
     * Checks whether the flight is available on the specified date 
     * for the specified number of seats.
     *
     * Called by CustomerFlight.checkAvailability().
     *
     * @param conn           Connection 
     * @param travel         The date flying.
     * @param kindOfSeats    the name of the column in FlightAvailability to select from
     * @param numberSeats    number of seats needed
     * @return true, if the flight is available
     * @exception SQLException in case anything goes wrong during a SQL operation
     */



    public boolean checkSegmentAvailability
    (
        Connection    conn,
        Date         travel,
        short         kindOfSeats,
        int            numberOfSeatsNeeded
    )
        throws SQLException
    {

      PreparedStatement check_segment_availability = prepareAvailabilityQuery(conn, kindOfSeats);

        check_segment_availability.setString(1, airline);
        check_segment_availability.setString(2, flight_id);
        check_segment_availability.setInt(3, getSegmentNumber());    
        check_segment_availability.setDate(4, travel);

        ResultSet rs = check_segment_availability.executeQuery();

        rs.next();
        int availableSeats = rs.getInt(1);
       
        if (!(availableSeats >=numberOfSeatsNeeded))
            return false;


        check_segment_availability.setString(1, airline);
        check_segment_availability.setString(2, getAltFlightId());
        check_segment_availability.setInt(3, getAltSegmentNumber());    
        check_segment_availability.setDate(4, travel);

        rs = check_segment_availability.executeQuery();
        rs.next();
        availableSeats = rs.getInt(1);
        check_segment_availability.close();
        if (!(availableSeats >=numberOfSeatsNeeded))
            return false;

        else return true;
        
    }

}









