package JBMSTours.serializabletypes;

import java.awt.*;
import java.awt.event.*;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.io.File;
import java.io.InputStream;
import JBMSTours.Util;
import JBMSTours.JCalendar;
import JBMSTours.PictureFrame;


/**
 * Look at the <a href="../JBMSTours/serializabletypes/URLPicture.java">Source</a>.<p>
 * Defines a Picture that is obtained from a URL. If the picture is larger
 * than a certain size, store only the URL. If smaller, store the entire
 * content. Can display picture regardless of whether content was stored.
 * Demonstrates some optional way to store media such as pictures, sounds,
 * movies, etc., from the internet--in the database, or as references only.
   
 */
public class URLPicture extends Picture 
{
    /**
     *    Mime type
     **/
    public String contentType;

    /**
     *   Whether the contents are stored. 
     *   True if contents are locally stored
     **/
    public boolean isLocal = false;

    /**
     *   If an image is larger than MAXSIZE, store only a reference.
     **/
    public static final int MAXSIZE = 62000;

    /**
     *   For serialization compatability.
     **/
    static final long serialVersionUID = -6828384716257835220L;

    /**
     * Instantiates the picture. Most of the work is cone in setContent.
     *
     * @param  URLName   URL for the source picture
     * @param  name      your name for the picture
     *
     * @exception    Exception  if there is  a problem reading the source
     *
     */
    public URLPicture(String URLName, String name) throws Exception
    {
        super(null,name);
        super.resourceName = URLName;
        setContent();
    }

    /**
     * Opens the URL and checks its size.  If the URL is below MAXSIZE, 
     * it reads
     * the contents directly into the class.  If the object is being
     * instantiated within Cloudscape, this has the effect of storing the URL
     * content along with the rest of the object in the database.
     *
     * @exception    Exception  if there is  a problem reading the source
     *
     */
    protected void setContent() throws Exception
    {
        // Now open up the URL to get information about it.
        URL url = new URL(resourceName);
        URLConnection conn = url.openConnection();
        // Fill in the content length and type.
        super.contentLength = conn.getContentLength();
        contentType = conn.getContentType();
        // If the content length is less than 62000 bytes, read the
        // data now and hold it in this instance.
        if(contentLength < MAXSIZE)
        {
            int count = 0;
            int totalBytesRead = 0;
            int bytesRead = 0;
            int bytelength = 0;
            InputStream in = conn.getInputStream();
            super.content = new byte[contentLength];
            while(totalBytesRead < super.contentLength 
                    && bytesRead > -1 && count < 20)
            {
                bytelength = in.available();
                bytesRead = in.read(super.content,totalBytesRead,bytelength);
                Thread.sleep(500);
                count++;
                totalBytesRead += bytesRead;
            }
            Util.println("Read " + totalBytesRead + " of " + 
                    super.contentLength + " bytes");
            in.close();
            this.isLocal = true;
            if(totalBytesRead < contentLength)
            {
                this.isLocal = false;
                content = null;
            }
        }
        else
            isLocal = false;
        if(isLocal)
            Util.println("Image stored in db.");
        else
            Util.println("Image not stored in db, only a URL reference.");
    }

    /**
     * Returns the URL name.
     */
    public String getURLName()
    {
        return super.resourceName;
    }

    /**
     * Returns the content.  If the content is local, 
     * this method simply returns
     * the array reference.  If not, we open the URL and read from it.  
     * Notice
     * that this stores the content in memory, so that if someone asks for it
     * again we already have it.
     */
    public byte[] getContent()
    {
        // Content is not available, we try to read it.
        if(content == null)
        {
            try
            {
                URL url = new URL(resourceName);
                URLConnection conn = url.openConnection();
                InputStream in = conn.getInputStream();
                content = new byte[in.available()];
                in.read(content);
                in.close();
            }
            // If there is an exception, just set content to null.
            catch(Exception e)
            {
                content = null;
            }
        }
        return content;
    }

    /**
     * displaying a picture consists of displaying it in a frame.
     *
     * @exception Exception    If there is an error.
     */
    public void display() throws Exception
    {
        Frame f;
        if(this.isLocal)
            f = new PictureFrame(getPictureName(),getContent());
        else
            f = new PictureFrame(getPictureName(),getURLName());
    }

}

