package JBMSTours.servlets;
import java.lang.*;
import java.io.*;
import java.net.*;
import javax.servlet.*;
import javax.servlet.http.*;
import java.sql.DriverManager;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringBufferInputStream;
import java.io.ByteArrayOutputStream;
import JBMSTours.serializabletypes.Tour;
import JBMSTours.Hotel;
import java.text.SimpleDateFormat;

  
     
/**
 * A servlet that presents a table that is generated by a query; this
 * query is setn to the servlet by the OpeningServlet servlet.
 *
 * @see OpeningServlet
 *
 */
public class GetHotelsForCity extends HttpServlet 
//implements SingleThreadModel
{
    private static final boolean verboseMode = true;

    // The only connection to Cloudscape. (To allow multiple connections, use
    // a connection pool.)
    private java.sql.Connection singleConnection = null;

    private Boolean singleAccess = new Boolean(true);

    //for this URL to work, cloudscape.system.home must be set to the location of toursDB.
	//To use the pre-built version, set cloudscape.system.home
	//to %cloudscape_install%/demo/databases
    String initialConnectionURL = "jdbc:cloudscape:toursDB;autocommit=true";

    /**
     * init, starts the servlet.
	 *
	 * @exception ServletException if there is a servlet problem.
     */

    public void init(ServletConfig conf) throws ServletException
    {
        super.init(conf);
        logIt("GetHotelsForCity.initialize: enter");
        try
        {
            // We do only connect once in this demo and keep the
            // connection opened and process incoming requests synchronously.
            // We didn't want to have to connect to Cloudscape for each incoming
            // statement to process.
            // Ideally, a connection pool should be created during init() and
            // connections could be grabbed on demand when a new request comes
            // in. A Servlet is a multi-threaded component, therefore one should
            // synchronize on data that could be accessed simultaneously by
            // multiple threads.
            //
            logIt("starting the driver  ...\n");

            Class.forName("COM.cloudscape.core.JDBCDriver").newInstance();
        }
        catch(Throwable ex)
        {
            handleException((Throwable)ex,null);
        }
    }

    /**
     * what the servlet does
	 *
	 * @exception ServletException if there is a servlet problem.
	 * @exception IOException if there is an IO problem
     */

    public void service(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException
    {
        // send the query to Cloudscape and return results back to client
        // Let's single-thread access to the database as we only have
        // 1 connection to use for this demo.
        //
        synchronized(singleAccess)
        {
            try
            {
                processInput(req,res);
            }
            catch(Throwable ex)
            {
                handleException((Throwable)ex,res);
            }
        }
    }

    public String getServletInfo()
    {
        return ("This is GetHotelsForCity!");
    }

    //
    // Connect to Cloudscape which is running embedded in the Servlet
    //
    private java.sql.Connection connectToCloudscape() throws Exception
    {
        if(singleConnection != null)
        {
            // we just fake it as if we had connection pool and were going
            // to grab a connection from the pool and return it to the
            // caller
            //
            // NOTE: if we had connection pool, then we should grab/request
            // a connection from the pool - (enhancement)
            logIt("there's already a connection!");
            return (singleConnection);
        }
        String connectionURL = initialConnectionURL;
        logIt("Connecting to Cloudscape (first time) using url [" + connectionURL + "]\n");
        // do actual Cloudscape server connection
        // We do only have 1 connection for now - Connection pool
        // should be added to enhance this example
        // (i.e. free list of Connections objects that can be grabbed
        //  upon new client request)
        singleConnection = DriverManager.getConnection(connectionURL);
        if(singleConnection == null)
        {
            throw new Exception("ERROR: Failed to connect to Cloudscape ...\n");
        }
        logIt("Connected to Cloudscape ... Yeeha! \n");
        return (singleConnection);
    }

    // process the user's input
    private synchronized void processInput(HttpServletRequest req, 
                                           HttpServletResponse res) throws Exception
    {
        connectToCloudscape();
        String hotelQuery = "SELECT NEW Hotel(hotel_id, hotel_name, city_id, " + 
            "tour_level, normal_rate, high_season_rate, number_rooms_in_block, " + 
            "high_season_begin, high_season_end) FROM hotels where city_id = ?";
        String cityNameQuery = "SELECT city.getName() from Cities where city_id = ?";
        logIt("Retrieving Value of cityId paramters...");
        int cityId = 84;
        String idstring = req.getParameter("cityId");
        logIt("id = [" + idstring + "]\n");
        cityId = new java.lang.Integer(idstring).intValue();
        int year1 = 1998;
        String yearstring = req.getParameter("YEAR1");
        logIt("year = [" + yearstring + "]\n");
        year1 = new java.lang.Integer(yearstring).intValue();
        year1 = year1 - 1900;
        int month1 = 0;
        String monthstring = req.getParameter("MONTH1");
        logIt("month1 = [" + monthstring + "]\n");
        month1 = new java.lang.Integer(monthstring).intValue();
        int date1 = 1;
        String datestring = req.getParameter("DATE1");
        logIt("date1 = [" + datestring + "]\n");
        date1 = new java.lang.Integer(datestring).intValue();
        int year2 = 1998;
        yearstring = req.getParameter("YEAR2");
        logIt("year2 = [" + yearstring + "]\n");
        year2 = new java.lang.Integer(yearstring).intValue();
        year2 = year2 - 1900;
        int month2 = 0;
        monthstring = req.getParameter("MONTH2");
        logIt("month2 = [" + monthstring + "]\n");
        month2 = new java.lang.Integer(monthstring).intValue();
        int date2 = 1;
        datestring = req.getParameter("DATE2");
        logIt("date2 = [" + datestring + "]\n");
        date2 = new java.lang.Integer(datestring).intValue();
        java.sql.Date d1 = new java.sql.Date(year1,month1,date1);
        java.sql.Date d2 = new java.sql.Date(year2,month2,date2);
        java.sql.PreparedStatement stmt1 = singleConnection.prepareStatement(hotelQuery);
        stmt1.setInt(1,cityId);
        java.sql.PreparedStatement stmt2 = singleConnection.prepareStatement(cityNameQuery);
        stmt2.setInt(1,cityId);
        // send query statement to JBMS
		singleConnection.setAutoCommit(false);
		
        ResultSet rs1 = stmt1.executeQuery();
        ResultSet rs2 = stmt2.executeQuery();
        logIt("Processing results...\n");
        // just a Byte array output stream to output data
        ByteArrayOutputStream aByteOutStream = new ByteArrayOutputStream();
        PrintWriter thePrintWriter = new PrintWriter(aByteOutStream);
        // reset byte stream
        aByteOutStream.reset();
        createResultTable(thePrintWriter,rs1,rs2,d1,d2);
        thePrintWriter.flush();
        // Write to the Servlet output stream
        // We could also use the sendResp() method here
        //
        logIt("Sending results back...\n");
        PrintWriter pout = new PrintWriter(res.getOutputStream());
        pout.println(aByteOutStream.toString());
        pout.flush();
        // we can close the statement now
        stmt1.close();
        stmt2.close();
		singleConnection.commit();
		singleConnection.setAutoCommit(true);
    }

    protected void handleException(Throwable ex, HttpServletResponse res)
    {
        if(ex instanceof SQLException)
        {
            printSQLError((SQLException)ex,res);
        }
        else
        {
            String errString = "Got Non SQL Exception: \n" + "*** Exception: " + ex.toString();
            sendError(res,errString);
            ex.printStackTrace();
        }
    }

    protected void printSQLError(SQLException ex, HttpServletResponse res)
    {
        StringBuffer errString = new StringBuffer();
        while(ex != null)
        {
            errString.append("\n" + ex.toString() + "\n");
            ex = ex.getNextException();
        }
        sendError(res,errString.toString());
    }

    protected void sendError(HttpServletResponse res, String error)
    {
        try
        {
            PrintWriter pout = null;
            if(res != null)
                pout = new PrintWriter(res.getOutputStream());
            else
                pout = new PrintWriter(System.err);
            pout.println("-ERROR " + error + "\n");
            pout.flush();
            pout.close();
            logIt(error);
        }
        catch(IOException e)
        {
        // Silently ignore failure to send.  For now.
        }
    }

    protected void sendResp(HttpServletResponse res, String resp)
    {
        try
        {
            PrintWriter pout = new PrintWriter(res.getOutputStream());
            pout.println(resp);
            pout.flush();
            pout.close();
        }
        catch(IOException e)
        {
        // Silently ignore failure to send.  For now.
        }
    }

    private void logIt(String msgToLog)
    {
        if(verboseMode)
            // print a timeStamped msg to std output
            System.out.println(new java.util.Date().toString() + ": [CS] " + msgToLog);
    }

    private void createResultTable(PrintWriter out, ResultSet rs1, 
                                         ResultSet rs2, 
                                         java.sql.Date d1, java.sql.Date d2) throws SQLException
    {
        boolean hd = true;
        String cityName = "Unknown City";
        rs2.next();
        cityName = rs2.getString(1);
        rs2.close();
        StringBuffer buf = new StringBuffer(HTMLUtil.beginHtmlPage(
            "Hotels and Availability for " + cityName));
        buf.append(HTMLUtil.beginOutputTable());
        String[] s = new String[4];
        s[0] = "Hotel";
        s[1] = "Level";
		SimpleDateFormat formatter = new SimpleDateFormat("MMMM d, yyyy");
        s[2] = "Cost from " + formatter.format(d1) + " to " + formatter.format(d2);
        s[3] = "Available?";
        buf.append(HTMLUtil.formatAsHTMLRow(s,4,hd));
        while(rs1.next())
        {
            Hotel h = (Hotel)rs1.getObject(1);
            buf.append(formatHotelAsHTMLRow(h,d1,d2));
        }
        rs1.close();
        buf.append(HTMLUtil.endOutputTable());
		buf.append(HTMLUtil.formatAsParagraph(
		    HTMLUtil.formatAsLink("OpeningServlet", "Choose another city or date.")));
        buf.append(HTMLUtil.endHtmlPage());
        out.println(buf);
    }

	
    private String formatHotelAsHTMLRow(Hotel h, 
                                        java.sql.Date d1, 
                                        java.sql.Date d2) throws SQLException
    {
        java.math.BigDecimal rate;
        String[] s = new String[4];
        s[0] = h.getName();
        s[1] = Tour.getStringForLevel(h.getLevel());
        if(h.isHigh(d1,d2))
            rate = h.getHighRate();
        else
            rate = h.getNormalRate();
        s[2] = rate.toString() + " per day";
        s[3] = new Boolean(h.isAvailable(singleConnection,d1,d2,2)).toString();
        return HTMLUtil.formatAsHTMLRow(s,4);
    }

}

