package JBMSTours.servlets;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import java.sql.DriverManager;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringBufferInputStream;
import java.io.ByteArrayOutputStream;
import JBMSTours.JCalendar;
import java.text.DateFormatSymbols;

/**
 * A servlet that generates an HTML page with a form with drop-down menus
 * generated by querying the Cities table in the database.
 *
 * @see GetHotelsForCity
 *
 */

public class OpeningServlet extends HttpServlet 
//implements SingleThreadModel
{
    private static final boolean verboseMode = true;

    // The only connection to Cloudscape. Building a connection
    // pool instead is a good idea.
    private java.sql.Connection singleConnection = null;

    private Boolean singleAccess = new Boolean(true);

    // connection URL known upon Servlet startup?
    // Same as above.
    String initialConnectionURL = "jdbc:cloudscape:toursDB";

    /**
     * init, starts the servlet.
	 *
	 * @exception ServletException if there is a servlet problem.
     */


    public void init(ServletConfig conf) throws ServletException
    {
        super.init(conf);
        logIt("OpeningServlet.initialize: enter");
        // Start Cloudscape and connect to it
        //
        try
        {
            // We connect only once in this demo and keep the
            // connection opened and process incoming requests synchronously.
            // We didn't want to have to connect to Cloudscape for each incoming
            // statement to process.
            // Ideally, a connection pool should be created during init() and
            // connections could be grabbed on demand when a new request comes
            // in.
			// A servlet is a multi-threaded component, so you should
            // synchronize on data that could be accessed simultaneously by
            // multiple threads.
            //
            logIt("starting the driver  ...\n");
			System.out.println(System.getProperty("cloudscape.system.home", System.getProperty("user.dir")));
            Class.forName("COM.cloudscape.core.JDBCDriver").newInstance();
        }
        catch(Throwable ex)
        {
            handleException((Throwable)ex,null);
        }
    }
    /**
     * what the servlet does
	 *
	 * @exception ServletException if there is a servlet problem.
	 * @exception IOException if there is an IO problem
     */

    public void service(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException
    {
        // send the query to Cloudscape and return results back to client
        // Let's single-thread access to the database as we only have
        // 1 connection to use for this demo.
        //
        synchronized(singleAccess)
        {
            try
            {
                processQuery(req,res);
            }
            catch(Throwable ex)
            {
                handleException((Throwable)ex,res);
            }
        }
    }

    public String getServletInfo()
    {
        return ("This is OpeningServlet!");
    }

    //
    // Connect to Cloudscape which may be running embedded in the Servlet
    // or we could also connect to Cloudscape running remotely in a Server
    // application.
    // This methods accepts specification of a runtime connection url
    // if any.
    //
    private java.sql.Connection connectToCloudscape() throws Exception
    {
        logIt("Making Cloudscape connection request...\n");
        if(singleConnection != null)
        {
            // we just fake it as if we had connection pool and were going
            // to grab a connection from the pool and return it to the
            // caller
            //
            // NOTE: if we had connection pool, then we should grab/request
            // a connection from the pool - (enhancement)
            return (singleConnection);
        }
        // We don't have a connection opened with the database yet;
        // therefore this must be the first invocation and we should
        // open a connection.
        // Retrieve connectionURL passed-in parameter to connect to remote
        // Cloudscape server. If none were passed, then we would have been told the
        // connection url to use at Servlet init() time...if not, this is an
        // error.
        //
        String connectionURL = initialConnectionURL;
        logIt("Connecting to Cloudscape (first time) using url [" + connectionURL + "]\n");
        // connect
        // We do only have 1 connection for now - Connection pool
        // should be added to enhance this example
        // (i.e. free list of Connections objects that can be grabbed
        //  upon new client request)
        singleConnection = DriverManager.getConnection(connectionURL);
        if(singleConnection == null)
        {
            throw new Exception("ERROR: Failed to connect to Cloudscape ...\n");
        }
        logIt("Connected to Cloudscape! \n");
        return (singleConnection);
    }

    // connect to embedded Cloudscape engine
    private synchronized void processQuery(HttpServletRequest req, HttpServletResponse res) throws Exception
    {
        String query = "SELECT city_id, city.getName() FROM Cities";
        java.sql.Connection conn = connectToCloudscape();
        // Create a Statement
        java.sql.Statement stmt = conn.createStatement();
        ResultSet rs = stmt.executeQuery(query);
        logIt("Querying database for cities ...\n");
        // just a Byte array output stream to output data
        ByteArrayOutputStream aByteOutStream = new ByteArrayOutputStream();
        PrintWriter thePrintWriter = new PrintWriter(aByteOutStream);
        // reset byte stream
        aByteOutStream.reset();
        formatCitiesAsHTMLTable(thePrintWriter,rs,conn);
        thePrintWriter.flush();
        // Write to the Servlet output stream
        // We could also use the sendResp() method here
        //
        logIt("Sending results back...\n");
        PrintWriter pout = new PrintWriter(res.getOutputStream());
        pout.println(aByteOutStream.toString());
        pout.flush();
        // we can close the statement now
        stmt.close();
		//statement is automatically committed
    }

    protected void handleException(Throwable ex, HttpServletResponse res)
    {
        if(ex instanceof SQLException)
        {
            printSQLError((SQLException)ex,res);
        }
        else
        {
            String errString = "Got Non SQL Exception: \n" + "*** Exception: " + ex.toString();
            sendError(res,errString);
            ex.printStackTrace();
        }
    }

    protected void printSQLError(SQLException ex, HttpServletResponse res)
    {
        StringBuffer errString = new StringBuffer();
        while(ex != null)
        {
            errString.append("\n" + ex.toString() + "\n");
            ex = ex.getNextException();
        }
        sendError(res,errString.toString());
    }

    protected void sendError(HttpServletResponse res, String error)
    {
        try
        {
            PrintWriter pout = null;
            if(res != null)
                pout = new PrintWriter(res.getOutputStream());
            else
                pout = new PrintWriter(System.err);
            pout.println("-ERROR " + error + "\n");
            pout.flush();
            pout.close();
            logIt(error);
        }
        catch(IOException e)
        {
        // Silently ignore failure to send.  For now.
        }
    }

    protected void sendResp(HttpServletResponse res, String resp)
    {
        try
        {
            PrintWriter pout = new PrintWriter(res.getOutputStream());
            pout.println(resp);
            pout.flush();
            pout.close();
        }
        catch(IOException e)
        {
        // Silently ignore failure to send.  For now.
        }
    }

    private void logIt(String msgToLog)
    {
        if(verboseMode)
            // print a timeStamped msg to std output
            System.out.println(new java.util.Date().toString() + ": [CS] " + msgToLog);
    }

    private void formatCitiesAsHTMLTable(PrintWriter out, ResultSet rs, Connection conn) throws SQLException
    {
        StringBuffer buf;
        StringBuffer miniBuf;
        buf = new StringBuffer(HTMLUtil.beginHtmlPage("Select a City and Range of Dates"));
        buf.append(HTMLUtil.formatAsParagraph("Select a city and a range of dates for a potential visit. " + 
            "The servlet will return information about hotels in the city " + 
            "you specify and their availability for that time period"));
        buf.append("<FORM METHOD=GET ACTION=\"GetHotelsForCity\">");
        buf.append(HTMLUtil.beginOutputTable());
        String[] s = new String[2];
        s[0] = "Select a City";
        s[1] = populateCityOptionList(rs);
        buf.append(HTMLUtil.formatAsHTMLRow(s,2));
        s = new String[2];
        s[0] = "Select a Start Date";
        miniBuf = new StringBuffer("");
        miniBuf.append(populateYearOptionList("YEAR1"));
        miniBuf.append(populateMonthOptionList("MONTH1"));
        miniBuf.append(populateDateOptionList("DATE1"));
        s[1] = miniBuf.toString();
        buf.append(HTMLUtil.formatAsHTMLRow(s,2));
        s[0] = "Select an End Date";
        miniBuf = new StringBuffer("");
        miniBuf.append(populateYearOptionList("YEAR2"));
        miniBuf.append(populateMonthOptionList("MONTH2"));
        miniBuf.append(populateDateOptionList("DATE2"));
        s[1] = miniBuf.toString();
        buf.append(HTMLUtil.formatAsHTMLRow(s,2));
        buf.append(HTMLUtil.endOutputTable());
        buf.append("<INPUT TYPE=\"submit\"> <INPUT TYPE=\"reset\" VALUE=\"Clear Form\">");
        buf.append("</FORM>");
        buf.append(HTMLUtil.endHtmlPage());
        out.println(buf);
    }

    private static String populateYearOptionList(String name)
    {
		int thisyear = JCalendar.getYear(JCalendar.getToday());
		int nextyear = thisyear+1;
        StringBuffer buf = new StringBuffer("");
        buf.append("<SELECT NAME=");
        buf.append(name);
        buf.append(">");
        buf.append("<OPTION>" + thisyear + "\r\n");
        buf.append("<OPTION>" + nextyear + "\r\n");
        buf.append("</SELECT>\r\n");
        return buf.toString();
    }

    private static String populateMonthOptionList(String name)
    {
		int thismonth = JCalendar.getMonth(JCalendar.getToday());
		String[] months = new DateFormatSymbols().getMonths();
        String[] value = new String[12];
        String[] show = new String[12];
        int j = thismonth;
		for (int i = 0; i < 12; i++) {
			value[i] = new Integer(j).toString();
			show[i] = months[j];
			j++;
			if (j>=12)
				j = 0;
		}
        return HTMLUtil.formatAsHtmlOptionList(name,value,show);
    }

    private static String populateDateOptionList(String name)
    {
        String show[] = new String[31];
		int thisday = JCalendar.getDate(JCalendar.getToday());
		int j = thisday;
        for(int i = 0;i < 31;i++)
        {
            show[i] = new Integer(j).toString();
			j++;
			if (j > 31)
				j = 1;
        }
        return HTMLUtil.formatAsHtmlOptionList(name,show);
    }

    private static String populateCityOptionList(ResultSet rs) throws SQLException
    {
        StringBuffer buf = new StringBuffer("");
        buf.append("<SELECT NAME=cityId>");
        while(rs.next())
        {
            buf.append("<OPTION VALUE=\"");
            buf.append(rs.getInt(1));
            buf.append("\">");
            buf.append(rs.getString(2) + "\r\n");
        }
        buf.append("\r\n</SELECT>\r\n");
        rs.close();
        return buf.toString();
    }

}

