package JBMSTours.triggers;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Date;
import java.sql.SQLException;
import java.sql.DriverManager;

import java.math.BigDecimal;

import COM.cloudscape.database.TriggerExecutionContext;
import COM.cloudscape.database.Factory;

import JBMSTours.AvailabilityException;
import JBMSTours.BudgetException;

import JBMSTours.Util;
import JBMSTours.Hotel;
import JBMSTours.serializabletypes.HotelStay;
import JBMSTours.serializabletypes.Tour;
import JBMSTours.serializabletypes.City;

//if you have the extension library, you can alter
// the program so that it actually sends
// you mail.
//import javax.mail.*;



public class TriggerActions {
	
    /**
     *  This trigger action is called by the trigger
	 *  "HotelsCascadingDelete2 in toursDB".
     * 
     * <p>This is a very complex action. If a hotel is deleted, check to see
	 * if there are any future bookings for that hotel. If so, automatically
	 * rebook those tours for a different (valid) hotel before deleting the hotel.
	 *
     * @param conn    Current connection to the database.
	 * @param today   The current date (date of the delete).
     *
     *
     * @exception     SQLException      if database error
     *
     **/
	
	public static void deleteOrRedoHotelBooking(Connection conn, Date today)
		 throws SQLException  {
		
			 PreparedStatement getBadBookings = conn.prepareStatement("EXECUTE STATEMENT badBookingsCursor");
			 Statement deleteCursor = conn.createStatement();
			 // this server-side construct allows us to access the row being deleted.
			 // the trigger that calls this method is a ROW trigger, and so this method gets
			 // called once for every row being deleted.
			 ResultSet deletedRow = Factory.getTriggerExecutionContext().getOldRow();
			 int hotel_id = 0;
			 int group_id = 0;
			 int city_id = 0;
			 Date arrival = null;
			 BigDecimal total_cost = new BigDecimal(0);
			 HotelStay hs = null;
			 hotel_id = deletedRow.getInt(1);
			 city_id = deletedRow.getInt(3);
			 deletedRow.close();
			 getBadBookings.setInt(1, hotel_id);
			 ResultSet badBookings = getBadBookings.executeQuery();
			 int j = 1;
			 
			 while (badBookings.next()) {
				 arrival = badBookings.getDate(3);
				 deleteCursor.executeUpdate("DELETE FROM HOTELBookings WHERE CURRENT OF " + badBookings.getCursorName());
				 //if the hotelstay has not already occured, you'll need to change the tour
				 if (arrival.after(today)) {
					 Util.println("Updating now invalid booking.");
					 // get the information about the booking so that we can make a new one.
					 hotel_id = badBookings.getInt(1);
					 group_id = badBookings.getInt(2);
					 total_cost=badBookings.getBigDecimal(6,2);
					 Tour t = null;
					 //now retrieve the tour so that we can update it.
					 PreparedStatement retrieveTour = conn.prepareStatement("SELECT customized_tour "+
																			"FROM CustomizedTours WHERE group_id =?");
					 retrieveTour.setInt(1, group_id);
					 ResultSet retrievedTour = retrieveTour.executeQuery();
					 while (retrievedTour.next()) {
						 // get the Tour object associated with the group that booked the hotel
						 t = (Tour) retrievedTour.getObject(1);
					 }
					 retrievedTour.close();
					 retrieveTour.close();
					 // now get and book a new hotel for this tour object
					 // pass in the old hotel_id so you don't try to book a stay at the hotel being deleted
					 // (since this is a "Before" trigger, the row is still in the table)
					 // also pass in the cost of the old stay so that the this amount can be deducted
					 // from the tour's "running total"
					 try {
						 t.findANewHotelStay(conn, hotel_id, total_cost);
					 }
					 
					 // if we can't book a new tour, throw an SQLException with error number 38001 (unable to
					 // rebook tour). Can't delete a hotel until you can rebook tours. 
					 catch (Exception e) {
						 if (! (e instanceof AvailabilityException || e instanceof AvailabilityException))
							 throw (SQLException) e;
						 else {
							 throw new SQLException("Unable to delete hotel of id " + hotel_id + " because: "+ e.getMessage(), "38001", COM.cloudscape.types.JBMSExceptionSeverity.STATEMENT_SEVERITY);
						 }
					 }
					 //store the updated tour object
					 
					 PreparedStatement storeNewTourObject = conn.prepareStatement("UPDATE CustomizedTours " +
																				  "SET customized_tour = ? WHERE group_id = ?");
					 storeNewTourObject.setObject(1, t);
					 storeNewTourObject.setInt(2, group_id);
					 storeNewTourObject.executeUpdate();
					 storeNewTourObject.close();
				 }
			
				 
			 }
			 badBookings.close();
			 getBadBookings.close();
			 deleteCursor.close();
			 return;
	}
	
	
	
    /* 
	 * Demonstrate using the TriggerExecutionContext to reference
	 * the old values for the row being changed.
	 * <p>
	 * You could execute this trigger action in a trigger such as the
	 * following:<p>
	 * 
	 * <code>CREATE TRIGGER DeletedRelatedHotels4<br>
	 * BEFORE DELETE<br>
	 * ON Cities
	 * FOR EACH STATEMENT CALL TriggerActions.deleteRelatedHotels(getCurrentConnection())
	 * </code>
	 *
     * @param conn    Current connection to the database.
	 */ 
    public static void deleteRelatedHotels(Connection conn) throws Throwable 
    { 
        TriggerExecutionContext context =
			Factory.getTriggerExecutionContext(); 
        PreparedStatement ps = conn.prepareStatement(
													 "DELETE FROM hotels WHERE city_id = ?"); 
        /* 
        ** Here we iterate through all the rows that have 
        ** been deleted. 
        ** We obtain the deleted rows from the trigger 
        ** execution context. 
        */ 
		ResultSet oldRows = context.getOldRowSet(); 
		while (oldRows.next()) 
		{ 
			ps.setString(1, oldRows.getString("city_id")); 
			ps.executeUpdate(); 
		}
		oldRows.close();
		ps.close();
	}
	
	/* 
	 * Use the TriggerOldTransitionRows VTI to do a cascading delete
	 * in one fell swoop.<p>
	 *
	 * You could call this action in a trigger such as:<p>
	 *
	 * <code>CREATE TRIGGER DeleteRelatedHotels5
	 * BEFORE DELETE
	 * ON Cities
	 * FOR EACH STATEMENT CALL TriggerActions.deleteRelatedHotels2(getCurrentConnection(), CURRENT_USER)
	 * </code>
	 *
     * @param conn    Current connection to the database.
	 */ 
	public static void deleteRelatedHotels2(Connection conn) throws Throwable 
	{
		
		PreparedStatement ps = conn.prepareStatement(
													 "DELETE FROM hotels WHERE city_id IN "+ 
													 "(SELECT city_id FROM NEW TriggerOldTransitionRows() AS OLDROWS)");
		
		ps.executeUpdate();
		ps.close();
	}

	
	/* 
	 * Use the TriggerNewTransitionRowsVTI from the body of the method,
	 * not from the trigger definition. Use it to
	 * do a system out of rows inserted into the HotelBookings table.
	 *
	 * You could call this action in a trigger such as:<p>
	 *
	 * <code>CREATE TRIGGER ShowNewBookings
	 * AFTER INSERT
	 * ON HotelBookings
	 * FOR EACH STATEMENT CALL TriggerActions.showNewBookings(getCurrentConnection())
	 * </code>
	 *
	 */ 

	public static void showNewBookings(Connection conn) throws SQLException 
	{
        Statement s = conn.createStatement();
        Util.println("New hotel bookings:");
		ResultSet rs = s.executeQuery("SELECT * FROM new TriggerNewTransitionRows() AS EQ");
		while (rs.next()) {

			Util.println(rs.getInt(1) + " " + rs.getDate(3) + " " + rs.getDate(4));
		}
		rs.close();
		s.close();
	}

	
	
	/* 
	 * Get a connection to the History database,
	 * which we are using as kind of an audit database, 
	 * insert a row for each city that is deleted.
	 * Also, send email for each deleted city. <p>
	 * Could be used in a trigger such as the following:<p>
	 * <code>CREATE TRIGGER AuditCities<br>
	 * AFTER DELETE<br>
	 * ON Cities<br>
	 * FOR EACH STATEMENT CALL TriggerActions.auditCities(getCurrentConnection(), CURRENT_USER)
     *
	 * @param conn    Current connection to the database
     * @param user    Current user of the database.
	 */ 
	public static void auditCities(Connection conn1, String user) throws Throwable 
	{ 
		Connection conn2=null; 
		try 
			{
				// the statement querying the special vti must be against the original connection
				Statement s = conn1.createStatement();
				
				ResultSet deletedRows = s.executeQuery("SELECT city FROM NEW TriggerOldTransitionRows() " +
													   "AS oldCities");
				// make a new connection to the History database for storing the
				// audit information
				conn2 = DriverManager.getConnection("jdbc:cloudscape:History");
				PreparedStatement ps = conn2.prepareStatement("insert into deletedCities values (?, ?)"); 
				ps.setString(1, user);
				
				
				while (deletedRows.next()) 
				{ 	 
					
					City city = (City)deletedRows.getObject("CITY"); 
					sendMsg("deleted city "+  city.getName()); 
					ps.setObject(2, city); 
					ps.execute(); 
				}
				deletedRows.close();
				ps.close();
				s.close();
			} 
		finally 
			{ 
				if (conn2 != null) 
					conn2.close(); 
			} 
	} 
	private static void sendMsg(String message) throws Throwable 
	{
		//this part not implemented. . .
		//Message msgs = new MimeMessage(session); 
		//msg.setSubject("")
		// . . .
		//Transport.send(msg);
		Util.println(message);
	}
	
	/* 
	 * Demonstrate doing a join with a triggers transition tables, send mail based on result
	 *<p>
	 * You could use this method in a trigger such as: <p>
	 * <code>CREATE TRIGGER hotelsAltered<br>
	 * AFTER UPDATE OF normal_rate, high_season_rate<br>
	 * ON Hotels<br>
	 * FOR EACH STATEMENT<br>
	 * CALL TriggerActions.hotelChanged(getCurrentConnection())
	 * </code>
	 * @param conn    Current connection
     * @param user    Current user of the database.
	 */ 
	public static void hotelChanged(Connection conn) throws Throwable 
	{
		
		Statement s = conn.createStatement();
		ResultSet rs = s.executeQuery("SELECT NewHotels.hotel_name, OldHotels.normal_rate, " +
									  "OldHotels.high_season_rate, "+
									  "NewHotels.normal_rate, NewHotels.high_season_rate " +
									  "FROM NEW TriggerNewTransitionRows() AS NewHotels, " +
									  "NEW TriggerOldTransitionRows() AS OldHotels " +
									  "WHERE NewHotels.hotel_id = OldHotels.hotel_id");
		while (rs.next()) {
			sendMsg(rs.getString(1) + "'s rates have changed: from $" +
					rs.getBigDecimal(2, 2) + " and $" + rs.getBigDecimal(3, 2) +
					" to $" + rs.getBigDecimal(4, 2) + " and $" + rs.getBigDecimal(5,2));
		}
		s.close();
	}
	
	/* 
	 * Demonstrate referencing the TriggerExecutionContext to find out
	 * information other than before or after values.<p>
	 * Could be used in a trigger such as:<p>
	 * <code>CREATE TRIGGER alterCity<br>
	 * AFTER UPDATE<br>
	 * ON Cities<br>
	 * FOR EACH ROW<br>
	 * CALL TriggerActions.cityChanged()
	 */ 
	public static void cityChanged() throws Throwable 
	{ 
		TriggerExecutionContext context = Factory.getTriggerExecutionContext(); 
		// don't let anyone change the CITY_ID
		if (context.wasColumnModified("CITY_ID")) 
		{ 
			// this exception will cause the update statement
			//to be rolled back 
			throw new SQLException(
								   "changes to CITY_ID are prohibited", "38001"); 
		} 
	}
	
}
