package JBMSTours.vti.jdbc2_0;

import COM.cloudscape.vti20.VTITemplate;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Types;

import java.math.BigDecimal;

/**
 * Wrapper class for an updatable ResultSet against table in an
 * Informix database. Supports only simple data types.
 * We need the wrapper because we need to be able to explicitly commit
 * the connection (or rollback, if an error occured)
 * every time the ResultSet is closed.
 *
 * DO NOT compile or run this class in a JDK1.1 environment. It
 * require JDK 1.2 or above.
 */

public class EITResult extends VTITemplate {
	private Connection              conn;
	private PreparedStatement		ps;
	private ResultSet				rs;
	private boolean                 error=false;
   

	/**
	 * Constructs the ResultSet by executing the query.
	 *
	 * @param conn  The connection to the Informix database
	 * @param ps    The PreparedStatement querying the table
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */

	public EITResult(Connection conn, PreparedStatement ps)
		throws SQLException {
		this.conn=conn;
		this.ps=ps;
		rs=ps.executeQuery();
	}

	/**
	 * get the metadata from this query.
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public ResultSetMetaData getMetaData() throws SQLException {
		
		
		return rs.getMetaData();
	}

	/**
	 * Closes the ResultSet. We also use the method to commit the transaction.
	 * We keep track of whether an error occured in insertRow() or deleteRow().
	 * If an error occurred, we call rollback instead.<p>
	 * Cloudscape calls this method when it has finished executing the SQL-J
	 * statement that uses the VTI class.
	 * 
 	 * @exception SQLException on unexpected JDBC error
	 */
	public void close() throws SQLException {
		// Release all resources
		if (ps != null) {
			ps.close();
			ps = null;
		}
		if (conn != null) {
			if (error) {
				conn.rollback();
			}

			else {
				conn.commit();
			}
			conn.close();
			conn = null;
		}
		
	}

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
	public boolean next() throws SQLException {
		// Get the next row from the cursor.
		

		return rs.next();

	}


	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
	public void moveToInsertRow() throws SQLException {
		rs.moveToInsertRow();
	}

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
	public void updateObject(int columnIndex, Object x) throws SQLException {

		rs.updateObject(columnIndex, x);
	}

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
	public void insertRow() throws SQLException {
		try {
			rs.insertRow();
		}
		catch (SQLException e) {

			error=true;
			throw e;
			
		}
	}

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
	public void deleteRow() throws SQLException {
		try {
			rs.deleteRow();
		}

		catch (SQLException e) {
			error=true;
			throw e;

		}
		
	}

	// Methods of ResultSet dispatched directly to the select ResultSet.

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public boolean wasNull() throws SQLException {
		
        return rs.wasNull();
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public String getString(int columnIndex) throws SQLException {
		
        return rs.getString(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public boolean getBoolean(int columnIndex) throws SQLException {
        return rs.getBoolean(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public byte getByte(int columnIndex) throws SQLException {
        return rs.getByte(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public short getShort(int columnIndex) throws SQLException {
        return rs.getShort(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public int getInt(int columnIndex) throws SQLException {
		
        return rs.getInt(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public long getLong(int columnIndex) throws SQLException {
        return rs.getLong(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
   public float getFloat(int columnIndex) throws SQLException {
        return rs.getFloat(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public double getDouble(int columnIndex) throws SQLException {
        return rs.getDouble(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public BigDecimal getBigDecimal(int columnIndex) throws SQLException {
        return rs.getBigDecimal(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public byte[] getBytes(int columnIndex) throws SQLException {
        return rs.getBytes(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public java.sql.Date getDate(int columnIndex) throws SQLException {
		
        return rs.getDate(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public java.sql.Time getTime(int columnIndex) throws SQLException {
        return rs.getTime(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public java.sql.Timestamp getTimestamp(int columnIndex) throws SQLException {
        return rs.getTimestamp(columnIndex);
    }

	
	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public String getString(String columnName) throws SQLException {
		
        return rs.getString(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public boolean getBoolean(String columnName) throws SQLException {
        return rs.getBoolean(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public byte getByte(String columnName) throws SQLException {
        return rs.getByte(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public short getShort(String columnName) throws SQLException {
        return rs.getShort(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public int getInt(String columnName) throws SQLException {
        return rs.getInt(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public long getLong(String columnName) throws SQLException {
        return rs.getLong(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public float getFloat(String columnName) throws SQLException {
        return rs.getFloat(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public double getDouble(String columnName) throws SQLException {
        return rs.getDouble(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public BigDecimal getBigDecimal(String columnName) throws SQLException {
        return rs.getBigDecimal(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public byte[] getBytes(String columnName) throws SQLException {
        return rs.getBytes(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public java.sql.Date getDate(String columnName) throws SQLException {
		
        return rs.getDate(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public java.sql.Time getTime(String columnName) throws SQLException {
        return rs.getTime(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public java.sql.Timestamp getTimestamp(String columnName) throws SQLException {
        return rs.getTimestamp(columnName);
    }


	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public SQLWarning getWarnings() throws SQLException {
        return rs.getWarnings();
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public void clearWarnings() throws SQLException {
        rs.clearWarnings();
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public String getCursorName() throws SQLException {
        return rs.getCursorName();
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public Object getObject(int columnIndex) throws SQLException {
		
        return rs.getObject(columnIndex);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public Object getObject(String columnName) throws SQLException {
		
        return rs.getObject(columnName);
    }

	/**
	 * 
	 *
 	 * @exception SQLException on unexpected JDBC error
	 */
    public int findColumn(String columnName) throws SQLException {
		
        return rs.findColumn(columnName);
    }

	/**
	 * Must return ResultSet.CONCUR_UPDATABLE
	 * 
 	 * @exception SQLException on unexpected JDBC error
	 */

	public int getConcurrency() throws SQLException {

		return rs.getConcurrency();

	}

	/**
	 *  
 	 * @exception SQLException on unexpected JDBC error
	 */
    public BigDecimal getBigDecimal(int columnIndex, int scale) throws SQLException {
		return rs.getBigDecimal(columnIndex, scale);
    }


	
}
